-- -*- sql -*-
--
-- Sample DDL to create Explain tables for Version 2.1
-- 
--   -> assumes db2start issued
--   -> assumes connection to a database exists
--   -> assumes called by "db2 -tf EXPLAIN.DDL"
--

--
-- To remind users how to use this file!
--
ECHO
ECHO ******* IMPORTANT **********
ECHO
ECHO USAGE: db2 -tf EXPLAIN.DDL
ECHO
ECHO ******* IMPORTANT **********
ECHO
ECHO;
--
--
-- Set autocommit off
--
UPDATE COMMAND OPTIONS USING C OFF;
--
--  EXPLAIN INSTANCE
--
--  (must be defined first due to referential integrity defintiions)
--
CREATE TABLE EXPLAIN_INSTANCE ( EXPLAIN_REQUESTER CHAR(8)   NOT NULL,
                                EXPLAIN_TIME      TIMESTAMP NOT NULL,
                                SOURCE_NAME       CHAR(8)   NOT NULL,
                                SOURCE_SCHEMA     CHAR(8)   NOT NULL,
                                EXPLAIN_OPTION    CHAR(1)   NOT NULL,
                                SNAPSHOT_TAKEN    CHAR(1)   NOT NULL,
                                DB2_VERSION       CHAR(7)   NOT NULL,
                                SQL_TYPE          CHAR(1)   NOT NULL,
                                QUERYOPT          INTEGER   NOT NULL,
                                BLOCK             CHAR(1)   NOT NULL,
                                ISOLATION         CHAR(2)   NOT NULL,
                                BUFFPAGE          INTEGER   NOT NULL,
                                AVG_APPLS         INTEGER   NOT NULL,
                                SORTHEAP          INTEGER   NOT NULL,
                                LOCKLIST          INTEGER   NOT NULL,
                                MAXLOCKS          SMALLINT  NOT NULL,
                                LOCKS_AVAIL       INTEGER   NOT NULL,
                                CPU_SPEED         DOUBLE    NOT NULL,
                                REMARKS           VARCHAR(254),
                                    PRIMARY KEY (EXPLAIN_REQUESTER,
                                                 EXPLAIN_TIME,
                                                 SOURCE_NAME,
                                                 SOURCE_SCHEMA));
--
-- EXPLAIN_STATEMENT      
--
CREATE TABLE EXPLAIN_STATEMENT ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                                 EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                                 SOURCE_NAME       CHAR(8)     NOT NULL,
                                 SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                                 EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                                 STMTNO            SMALLINT    NOT NULL,
                                 SECTNO            SMALLINT    NOT NULL,
                                 QUERYNO           INTEGER     NOT NULL,
                                 QUERYTAG          CHAR(20)    NOT NULL,
                                 STATEMENT_TYPE    CHAR(2)     NOT NULL,
                                 UPDATABLE         CHAR(1)     NOT NULL,
                                 DELETABLE         CHAR(1)     NOT NULL,
                                 TOTAL_COST        DOUBLE      NOT NULL,
                                 STATEMENT_TEXT    CLOB(64K)   NOT NULL,
                                 SNAPSHOT          BLOB(10M),
                                    PRIMARY KEY (EXPLAIN_REQUESTER,
                                                 EXPLAIN_TIME,
                                                 SOURCE_NAME,
                                                 SOURCE_SCHEMA,
                                                 EXPLAIN_LEVEL,
                                                 STMTNO,
                                                 SECTNO),
                                     FOREIGN KEY (EXPLAIN_REQUESTER,
                                                  EXPLAIN_TIME,
                                                  SOURCE_NAME,
                                                  SOURCE_SCHEMA)
                                     REFERENCES EXPLAIN_INSTANCE
                                     ON DELETE CASCADE);
--
-- EXPLAIN_ARGUMENTS
--
CREATE TABLE EXPLAIN_ARGUMENT ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                                EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                                SOURCE_NAME       CHAR(8)     NOT NULL,
                                SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                                EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                                STMTNO            SMALLINT    NOT NULL,
                                SECTNO            SMALLINT    NOT NULL,
                                OPERATOR_ID       SMALLINT    NOT NULL,
                                ARGUMENT_TYPE     CHAR(8)     NOT NULL,
                                ARGUMENT_VALUE    VARCHAR(30) NOT NULL,
                                   FOREIGN KEY (EXPLAIN_REQUESTER,
                                                EXPLAIN_TIME,
                                                SOURCE_NAME,
                                                SOURCE_SCHEMA,
                                                EXPLAIN_LEVEL,
                                                STMTNO,
                                                SECTNO)
                                   REFERENCES EXPLAIN_STATEMENT
                                   ON DELETE CASCADE);
--
-- EXPLAIN_OBJECT
--
CREATE TABLE EXPLAIN_OBJECT ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                              EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                              SOURCE_NAME       CHAR(8)     NOT NULL,
                              SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                              EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                              STMTNO            SMALLINT    NOT NULL,
                              SECTNO            SMALLINT    NOT NULL,
                              OBJECT_SCHEMA     CHAR(8)     NOT NULL,
                              OBJECT_NAME       VARCHAR(18) NOT NULL,
                              OBJECT_TYPE       CHAR(2)     NOT NULL,
                              CREATE_TIME       TIMESTAMP,
                              STATISTICS_TIME   TIMESTAMP,
                              COLUMN_COUNT      SMALLINT    NOT NULL,
                              ROW_COUNT         INTEGER     NOT NULL,
                              WIDTH             INTEGER     NOT NULL,
                              PAGES             INTEGER     NOT NULL,
                              DISTINCT          CHAR(1)     NOT NULL,
                              TABLESPACE_NAME   VARCHAR(18),
                              OVERHEAD          DOUBLE      NOT NULL,
                              TRANSFER_RATE     DOUBLE      NOT NULL,
                              PREFETCHSIZE      INTEGER     NOT NULL,
                              EXTENTSIZE        INTEGER     NOT NULL,
                              CLUSTER           DOUBLE      NOT NULL,
                              NLEAF             INTEGER     NOT NULL,
                              NLEVELS           INTEGER     NOT NULL,
                              FULLKEYCARD       INTEGER     NOT NULL,
                              OVERFLOW          INTEGER     NOT NULL,
                                   FOREIGN KEY (EXPLAIN_REQUESTER,
                                                EXPLAIN_TIME,
                                                SOURCE_NAME,
                                                SOURCE_SCHEMA,
                                                EXPLAIN_LEVEL,
                                                STMTNO,
                                                SECTNO)
                                   REFERENCES EXPLAIN_STATEMENT
                                   ON DELETE CASCADE);
--
-- EXPLAIN_OPERATOR
--
CREATE TABLE EXPLAIN_OPERATOR ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                                EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                                SOURCE_NAME       CHAR(8)     NOT NULL,
                                SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                                EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                                STMTNO            SMALLINT    NOT NULL,
                                SECTNO            SMALLINT    NOT NULL,
                                OPERATOR_ID       SMALLINT    NOT NULL,
                                OPERATOR_TYPE     CHAR(6)     NOT NULL,
                                TOTAL_COST        DOUBLE      NOT NULL,
                                IO_COST           DOUBLE      NOT NULL,
                                CPU_COST          DOUBLE      NOT NULL,
                                FIRST_ROW_COST    DOUBLE      NOT NULL,
                                   FOREIGN KEY (EXPLAIN_REQUESTER,
                                                EXPLAIN_TIME,
                                                SOURCE_NAME,
                                                SOURCE_SCHEMA,
                                                EXPLAIN_LEVEL,
                                                STMTNO,
                                                SECTNO)
                                   REFERENCES EXPLAIN_STATEMENT
                                   ON DELETE CASCADE);
--
-- EXPLAIN_PREDICATE
--
CREATE TABLE EXPLAIN_PREDICATE ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                                 EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                                 SOURCE_NAME       CHAR(8)     NOT NULL,
                                 SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                                 EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                                 STMTNO            SMALLINT    NOT NULL,
                                 SECTNO            SMALLINT    NOT NULL,
                                 OPERATOR_ID       SMALLINT    NOT NULL,
                                 PREDICATE_ID      SMALLINT    NOT NULL,
                                 HOW_APPLIED       CHAR(5)     NOT NULL,
                                 WHEN_EVALUATED    CHAR(3)     NOT NULL,
                                 RELOP_TYPE        CHAR(2)     NOT NULL,
                                 SUBQUERY          CHAR(1)     NOT NULL,
                                 FILTER_FACTOR     DOUBLE      NOT NULL,
                                 PREDICATE_TEXT    CLOB(64K),
                                   FOREIGN KEY (EXPLAIN_REQUESTER,
                                                EXPLAIN_TIME,
                                                SOURCE_NAME,
                                                SOURCE_SCHEMA,
                                                EXPLAIN_LEVEL,
                                                STMTNO,
                                                SECTNO)
                                   REFERENCES EXPLAIN_STATEMENT
                                   ON DELETE CASCADE);
--
-- EXPLAIN_STREAM
--
CREATE TABLE EXPLAIN_STREAM ( EXPLAIN_REQUESTER CHAR(8)     NOT NULL,
                              EXPLAIN_TIME      TIMESTAMP   NOT NULL,
                              SOURCE_NAME       CHAR(8)     NOT NULL,
                              SOURCE_SCHEMA     CHAR(8)     NOT NULL,
                              EXPLAIN_LEVEL     CHAR(1)     NOT NULL,
                              STMTNO            SMALLINT    NOT NULL,
                              SECTNO            SMALLINT    NOT NULL,
                              STREAM_ID         SMALLINT    NOT NULL,
                              SOURCE_TYPE       CHAR(1)     NOT NULL,
                              SOURCE_ID         SMALLINT    NOT NULL,
                              TARGET_TYPE       CHAR(1)     NOT NULL,
                              TARGET_ID         SMALLINT    NOT NULL,
                              OBJECT_SCHEMA     CHAR(8),
                              OBJECT_NAME       VARCHAR(18),
                              STREAM_COUNT      DOUBLE      NOT NULL,
                              COLUMN_COUNT      SMALLINT    NOT NULL,
                              PREDICATE_ID      SMALLINT    NOT NULL,
                              COLUMN_NAMES      CLOB(64K),
                                   FOREIGN KEY (EXPLAIN_REQUESTER,
                                                EXPLAIN_TIME,
                                                SOURCE_NAME,
                                                SOURCE_SCHEMA,
                                                EXPLAIN_LEVEL,
                                                STMTNO,
                                                SECTNO)
                                   REFERENCES EXPLAIN_STATEMENT
                                   ON DELETE CASCADE);
--
-- Commit work
--
COMMIT WORK;
