/******************************************************************************
 *
 * Source File Name = SQLCLI1.H
 *
 * (C) COPYRIGHT International Business Machines Corp. 1993, 1995
 * All Rights Reserved
 * Licensed Materials - Property of IBM
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * Function = Include File defining:
 *              DB2 CLI Interface - Constants
 *              DB2 CLI Interface - Function Prototypes
 *
 * Operating System = Common C Include File
 *
 *****************************************************************************/

#ifndef SQL_H_SQLCLI1
   #define SQL_H_SQLCLI1           /* Permit duplicate Includes */


#ifdef __cplusplus
extern "C" {
#endif

#include "sqlsystm.h"              /* System dependent defines  */


#if defined(DB2WIN) || defined(DB2NT)
#include <windows.h>
#endif
#ifdef DB2OS2
#define INCL_WIN
#define INCL_DOS
#include <os2.h>
#endif

#include    "sqlca.h"
#include    "sqlcli.h"

/* generally useful constants */
#define SQL_MAX_OPTION_STRING_LENGTH    256

/* Access modes */
#define SQL_MODE_READ_WRITE             0
#define SQL_MODE_READ_ONLY              1

/* Special return values for SQLFetch/SQLExtendedFetch/SQLGetData */
#define SQL_NO_TOTAL                   (-4)

/* SQLGetFunction defines  - supported functions */
#define  SQL_API_ALL_FUNCTIONS          0
#define  SQL_API_SQLALLOCCONNECT        1
#define  SQL_API_SQLALLOCENV            2
#define  SQL_API_SQLALLOCSTMT           3
#define  SQL_API_SQLBINDCOL             4
#define  SQL_API_SQLCANCEL              5
#define  SQL_API_SQLCOLATTRIBUTES       6
#define  SQL_API_SQLCONNECT             7
#define  SQL_API_SQLDESCRIBECOL         8
#define  SQL_API_SQLDISCONNECT          9
#define  SQL_API_SQLERROR              10
#define  SQL_API_SQLEXECDIRECT         11
#define  SQL_API_SQLEXECUTE            12
#define  SQL_API_SQLFETCH              13
#define  SQL_API_SQLFREECONNECT        14
#define  SQL_API_SQLFREEENV            15
#define  SQL_API_SQLFREESTMT           16
#define  SQL_API_SQLGETCURSORNAME      17
#define  SQL_API_SQLNUMRESULTCOLS      18
#define  SQL_API_SQLPREPARE            19
#define  SQL_API_SQLROWCOUNT           20
#define  SQL_API_SQLSETCURSORNAME      21
#define  SQL_API_SQLSETPARAM           22
#define  SQL_API_SQLTRANSACT           23

#define  SQL_API_SQLCOLUMNS            40
#define  SQL_API_SQLDRIVERCONNECT      41
#define  SQL_API_SQLGETCONNECTOPTION   42
#define  SQL_API_SQLGETDATA            43
#define  SQL_API_SQLGETFUNCTIONS       44
#define  SQL_API_SQLGETINFO            45
#define  SQL_API_SQLGETSTMTOPTION      46
#define  SQL_API_SQLGETTYPEINFO        47
#define  SQL_API_SQLPARAMDATA          48
#define  SQL_API_SQLPUTDATA            49
#define  SQL_API_SQLSETCONNECTOPTION   50
#define  SQL_API_SQLSETSTMTOPTION      51
#define  SQL_API_SQLSPECIALCOLUMNS     52
#define  SQL_API_SQLSTATISTICS         53
#define  SQL_API_SQLTABLES             54
#define  SQL_API_SQLCOLUMNPRIVILEGES   56
#define  SQL_API_SQLDATASOURCES        57
#define  SQL_API_SQLEXTENDEDFETCH      59
#define  SQL_API_SQLFOREIGNKEYS        60
#define  SQL_API_SQLMORERESULTS        61
#define  SQL_API_SQLNATIVESQL          62
#define  SQL_API_SQLNUMPARAMS          63
#define  SQL_API_SQLPARAMOPTIONS       64
#define  SQL_API_SQLPRIMARYKEYS        65
#define  SQL_API_SQLPROCEDURECOLUMNS   66
#define  SQL_API_SQLPROCEDURES         67
#define  SQL_API_SQLSETSCROLLOPTIONS   69
#define  SQL_API_SQLTABLEPRIVILEGES    70
#define  SQL_API_SQLBINDPARAMETER      72

#define  SQL_API_SQLBINDFILETOCOL      1250
#define  SQL_API_SQLBINDFILETOPARAM    1251
#define  SQL_API_SQLSETCOLATTRIBUTES   1252
#define  SQL_API_SQLGETSQLCA           1253

#define  SQL_API_SQLGETLENGTH          1022
#define  SQL_API_SQLGETPOSITION        1023
#define  SQL_API_SQLGETSUBSTRING       1024

#define  SQL_API_SQLGETENVATTR         1012
#define  SQL_API_SQLSETENVATTR         1019
#define  SQL_API_SQLSETCONNECTION      1254

/* SQLGetFunction defines  - unsupported functions */
#define  SQL_API_SQLBROWSECONNECT      55
#define  SQL_API_SQLDESCRIBEPARAM      58
#define  SQL_API_SQLSETPOS             68
#define  SQL_API_SQLDRIVERS            71
#define  SQL_EXT_API_LAST              SQL_API_SQLBINDPARAMETER


/* SQLGetInfo defines  - Info Type */
#define  SQL_ACTIVE_CONNECTIONS                0
#define  SQL_ACTIVE_STATEMENTS                 1
#define  SQL_DATA_SOURCE_NAME                  2
#define  SQL_DRIVER_HDBC                       3
#define  SQL_DRIVER_HENV                       4
#define  SQL_DRIVER_HSTMT                      5
#define  SQL_DRIVER_NAME                       6
#define  SQL_DRIVER_VER                        7
#define  SQL_FETCH_DIRECTION                   8
#define  SQL_ODBC_API_CONFORMANCE              9
#define  SQL_ODBC_VER                         10
#define  SQL_ROW_UPDATES                      11
#define  SQL_ODBC_SAG_CLI_CONFORMANCE         12
#define  SQL_SERVER_NAME                      13
#define  SQL_SEARCH_PATTERN_ESCAPE            14
#define  SQL_ODBC_SQL_CONFORMANCE             15
#define  SQL_DATABASE_NAME                    16
#define  SQL_DBMS_NAME                        17
#define  SQL_DBMS_VER                         18
#define  SQL_ACCESSIBLE_TABLES                19
#define  SQL_ACCESSIBLE_PROCEDURES            20
#define  SQL_PROCEDURES                       21
#define  SQL_CONCAT_NULL_BEHAVIOR             22
#define  SQL_CURSOR_COMMIT_BEHAVIOR           23
#define  SQL_CURSOR_ROLLBACK_BEHAVIOR         24
#define  SQL_DATA_SOURCE_READ_ONLY            25
#define  SQL_DEFAULT_TXN_ISOLATION            26
#define  SQL_EXPRESSIONS_IN_ORDERBY           27
#define  SQL_IDENTIFIER_CASE                  28
#define  SQL_IDENTIFIER_QUOTE_CHAR            29
#define  SQL_MAX_COLUMN_NAME_LEN              30
#define  SQL_MAX_CURSOR_NAME_LEN              31
#define  SQL_MAX_OWNER_NAME_LEN               32
#define  SQL_MAX_PROCEDURE_NAME_LEN           33
#define  SQL_MAX_QUALIFIER_NAME_LEN           34
#define  SQL_MAX_TABLE_NAME_LEN               35
#define  SQL_MULT_RESULT_SETS                 36
#define  SQL_MULTIPLE_ACTIVE_TXN              37
#define  SQL_OUTER_JOINS                      38
#define  SQL_OWNER_TERM                       39
#define  SQL_PROCEDURE_TERM                   40
#define  SQL_QUALIFIER_NAME_SEPARATOR         41
#define  SQL_QUALIFIER_TERM                   42
#define  SQL_SCROLL_CONCURRENCY               43
#define  SQL_SCROLL_OPTIONS                   44
#define  SQL_TABLE_TERM                       45
#define  SQL_TXN_CAPABLE                      46
#define  SQL_USER_NAME                        47
#define  SQL_CONVERT_FUNCTIONS                48
#define  SQL_NUMERIC_FUNCTIONS                49
#define  SQL_STRING_FUNCTIONS                 50
#define  SQL_SYSTEM_FUNCTIONS                 51
#define  SQL_TIMEDATE_FUNCTIONS               52
#define  SQL_CONVERT_BIGINT                   53
#define  SQL_CONVERT_BINARY                   54
#define  SQL_CONVERT_BIT                      55
#define  SQL_CONVERT_CHAR                     56
#define  SQL_CONVERT_DATE                     57
#define  SQL_CONVERT_DECIMAL                  58
#define  SQL_CONVERT_DOUBLE                   59
#define  SQL_CONVERT_FLOAT                    60
#define  SQL_CONVERT_INTEGER                  61
#define  SQL_CONVERT_LONGVARCHAR              62
#define  SQL_CONVERT_NUMERIC                  63
#define  SQL_CONVERT_REAL                     64
#define  SQL_CONVERT_SMALLINT                 65
#define  SQL_CONVERT_TIME                     66
#define  SQL_CONVERT_TIMESTAMP                67
#define  SQL_CONVERT_TINYINT                  68
#define  SQL_CONVERT_VARBINARY                69
#define  SQL_CONVERT_VARCHAR                  70
#define  SQL_CONVERT_LONGVARBINARY            71
#define  SQL_TXN_ISOLATION_OPTION             72
#define  SQL_ODBC_SQL_OPT_IEF                 73
#define  SQL_CORRELATION_NAME                 74
#define  SQL_NON_NULLABLE_COLUMNS             75
#define  SQL_DRIVER_HLIB                      76
#define  SQL_DRIVER_ODBC_VER                  77
#define  SQL_LOCK_TYPES                       78
#define  SQL_POS_OPERATIONS                   79
#define  SQL_POSITIONED_STATEMENTS            80
#define  SQL_GETDATA_EXTENSIONS               81
#define  SQL_BOOKMARK_PERSISTENCE             82
#define  SQL_STATIC_SENSITIVITY               83
#define  SQL_FILE_USAGE                       84
#define  SQL_NULL_COLLATION                   85
#define  SQL_ALTER_TABLE                      86
#define  SQL_COLUMN_ALIAS                     87
#define  SQL_GROUP_BY                         88
#define  SQL_KEYWORDS                         89
#define  SQL_ORDER_BY_COLUMNS_IN_SELECT       90
#define  SQL_OWNER_USAGE                      91
#define  SQL_QUALIFIER_USAGE                  92
#define  SQL_QUOTED_IDENTIFIER_CASE           93
#define  SQL_SPECIAL_CHARACTERS               94
#define  SQL_SUBQUERIES                       95
#define  SQL_UNION                            96
#define  SQL_MAX_COLUMNS_IN_GROUP_BY          97
#define  SQL_MAX_COLUMNS_IN_INDEX             98
#define  SQL_MAX_COLUMNS_IN_ORDER_BY          99
#define  SQL_MAX_COLUMNS_IN_SELECT           100
#define  SQL_MAX_COLUMNS_IN_TABLE            101
#define  SQL_MAX_INDEX_SIZE                  102
#define  SQL_MAX_ROW_SIZE_INCLUDES_LONG      103
#define  SQL_MAX_ROW_SIZE                    104
#define  SQL_MAX_STATEMENT_LEN               105
#define  SQL_MAX_TABLES_IN_SELECT            106
#define  SQL_MAX_USER_NAME_LEN               107
#define  SQL_MAX_CHAR_LITERAL_LEN            108
#define  SQL_TIMEDATE_ADD_INTERVALS          109
#define  SQL_TIMEDATE_DIFF_INTERVALS         110
#define  SQL_NEED_LONG_DATA_LEN              111
#define  SQL_MAX_BINARY_LITERAL_LEN          112
#define  SQL_LIKE_ESCAPE_CLAUSE              113
#define  SQL_QUALIFIER_LOCATION              114
#define  SQL_OJ_CAPABILITIES               65003  /* Temporary value */
#define  SQL_MAX_SCHEMA_NAME_LEN             SQL_MAX_OWNER_NAME_LEN
#define  SQL_MAX_CATALOG_NAME_LEN            SQL_MAX_QUALIFIER_NAME_LEN


#define SQL_INFO_LAST                         SQL_QUALIFIER_LOCATION
#define SQL_INFO_DRIVER_START                 1000

/* SQL_CONVERT_*  return value bitmasks - for use with SQLGetInfo */
#define  SQL_CVT_CHAR                 0x00000001L
#define  SQL_CVT_NUMERIC              0x00000002L
#define  SQL_CVT_DECIMAL              0x00000004L
#define  SQL_CVT_INTEGER              0x00000008L
#define  SQL_CVT_SMALLINT             0x00000010L
#define  SQL_CVT_FLOAT                0x00000020L
#define  SQL_CVT_REAL                 0x00000040L
#define  SQL_CVT_DOUBLE               0x00000080L
#define  SQL_CVT_VARCHAR              0x00000100L
#define  SQL_CVT_LONGVARCHAR          0x00000200L
#define  SQL_CVT_BINARY               0x00000400L
#define  SQL_CVT_VARBINARY            0x00000800L
#define  SQL_CVT_BIT                  0x00001000L
#define  SQL_CVT_TINYINT              0x00002000L
#define  SQL_CVT_BIGINT               0x00004000L
#define  SQL_CVT_DATE                 0x00008000L
#define  SQL_CVT_TIME                 0x00010000L
#define  SQL_CVT_TIMESTAMP            0x00020000L
#define  SQL_CVT_LONGVARBINARY        0x00040000L

/* SQL_CONVERT_FUNCTIONS functions - for use with SQLGetInfo */
#define  SQL_FN_CVT_CONVERT           0x00000001L

/* SQL_STRING_FUNCTIONS Bit Masks  - for use with SQLGetInfo */
#define  SQL_FN_STR_CONCAT            0x00000001L
#define  SQL_FN_STR_INSERT            0x00000002L
#define  SQL_FN_STR_LEFT              0x00000004L
#define  SQL_FN_STR_LTRIM             0x00000008L
#define  SQL_FN_STR_LENGTH            0x00000010L
#define  SQL_FN_STR_LOCATE            0x00000020L
#define  SQL_FN_STR_LCASE             0x00000040L
#define  SQL_FN_STR_REPEAT            0x00000080L
#define  SQL_FN_STR_REPLACE           0x00000100L
#define  SQL_FN_STR_RIGHT             0x00000200L
#define  SQL_FN_STR_RTRIM             0x00000400L
#define  SQL_FN_STR_SUBSTRING         0x00000800L
#define  SQL_FN_STR_UCASE             0x00001000L
#define  SQL_FN_STR_ASCII             0x00002000L
#define  SQL_FN_STR_CHAR              0x00004000L
#define  SQL_FN_STR_DIFFERENCE        0x00008000L
#define  SQL_FN_STR_LOCATE_2          0x00010000L
#define  SQL_FN_STR_SOUNDEX           0x00020000L
#define  SQL_FN_STR_SPACE             0x00040000L

/* SQL_NUMERIC_FUNCTIONS Bit Masks - for use with SQLGetInfo */
#define  SQL_FN_NUM_ABS               0x00000001L
#define  SQL_FN_NUM_ACOS              0x00000002L
#define  SQL_FN_NUM_ASIN              0x00000004L
#define  SQL_FN_NUM_ATAN              0x00000008L
#define  SQL_FN_NUM_ATAN2             0x00000010L
#define  SQL_FN_NUM_CEILING           0x00000020L
#define  SQL_FN_NUM_COS               0x00000040L
#define  SQL_FN_NUM_COT               0x00000080L
#define  SQL_FN_NUM_EXP               0x00000100L
#define  SQL_FN_NUM_FLOOR             0x00000200L
#define  SQL_FN_NUM_LOG               0x00000400L
#define  SQL_FN_NUM_MOD               0x00000800L
#define  SQL_FN_NUM_SIGN              0x00001000L
#define  SQL_FN_NUM_SIN               0x00002000L
#define  SQL_FN_NUM_SQRT              0x00004000L
#define  SQL_FN_NUM_TAN               0x00008000L
#define  SQL_FN_NUM_PI                0x00010000L
#define  SQL_FN_NUM_RAND              0x00020000L
#define  SQL_FN_NUM_DEGREES           0x00040000L
#define  SQL_FN_NUM_LOG10             0x00080000L
#define  SQL_FN_NUM_POWER             0x00100000L
#define  SQL_FN_NUM_RADIANS           0x00200000L
#define  SQL_FN_NUM_ROUND             0x00400000L
#define  SQL_FN_NUM_TRUNCATE          0x00800000L

/* SQL_TIMEDATE_FUNCTIONS Bit Masks - for use with SQLGetInfo */
#define  SQL_FN_TD_NOW                0x00000001L
#define  SQL_FN_TD_CURDATE            0x00000002L
#define  SQL_FN_TD_DAYOFMONTH         0x00000004L
#define  SQL_FN_TD_DAYOFWEEK          0x00000008L
#define  SQL_FN_TD_DAYOFYEAR          0x00000010L
#define  SQL_FN_TD_MONTH              0x00000020L
#define  SQL_FN_TD_QUARTER            0x00000040L
#define  SQL_FN_TD_WEEK               0x00000080L
#define  SQL_FN_TD_YEAR               0x00000100L
#define  SQL_FN_TD_CURTIME            0x00000200L
#define  SQL_FN_TD_HOUR               0x00000400L
#define  SQL_FN_TD_MINUTE             0x00000800L
#define  SQL_FN_TD_SECOND             0x00001000L
#define  SQL_FN_TD_TIMESTAMPADD       0x00002000L
#define  SQL_FN_TD_TIMESTAMPDIFF      0x00004000L
#define  SQL_FN_TD_DAYNAME            0x00008000L
#define  SQL_FN_TD_MONTHNAME          0x00010000L
#define  SQL_FN_TD_SECONDS_SINCE_MIDNIGHT 0x00020000L
#define  SQL_FN_TD_JULIAN_DAY         0x00040000L

/* SQL_SYSTEM_FUNCTIONS Bit Masks - for use with SQLGetInfo */
#define  SQL_FN_SYS_USERNAME          0x00000001L
#define  SQL_FN_SYS_DBNAME            0x00000002L
#define  SQL_FN_SYS_IFNULL            0x00000004L

/* SQL_TIMEDATE_ADD_INTERVALS and SQL_TIMEDATE_DIFF_INTERVALS Bit Masks
 * - for use with SQLGetInfo
 */
#define SQL_FN_TSI_FRAC_SECOND        0x00000001L
#define SQL_FN_TSI_SECOND             0x00000002L
#define SQL_FN_TSI_MINUTE             0x00000004L
#define SQL_FN_TSI_HOUR               0x00000008L
#define SQL_FN_TSI_DAY                0x00000010L
#define SQL_FN_TSI_WEEK               0x00000020L
#define SQL_FN_TSI_MONTH              0x00000040L
#define SQL_FN_TSI_QUARTER            0x00000080L
#define SQL_FN_TSI_YEAR               0x00000100L


/* SQL_ODBC_API_CONFORMANCE values */
#define SQL_OAC_NONE                  0x0000
#define SQL_OAC_LEVEL1                0x0001
#define SQL_OAC_LEVEL2                0x0002


/* SQL_ODBC_SAG_CLI_CONFORMANCE values */

#define SQL_OSCC_NOT_COMPLIANT        0x0000
#define SQL_OSCC_COMPLIANT            0x0001

/* SQL_ODBC_SQL_CONFORMANCE values */

#define SQL_OSC_MINIMUM               0x0000
#define SQL_OSC_CORE                  0x0001
#define SQL_OSC_EXTENDED              0x0002

/* SQL_CONCAT_NULL_BEHAVIOR values */

#define SQL_CB_NULL                   0x0000
#define SQL_CB_NON_NULL               0x0001

/* SQL_CURSOR_COMMIT_BEHAVIOR and SQL_CURSOR_ROLLBACK_BEHAVIOR values */

#define SQL_CB_DELETE                 0x0000
#define SQL_CB_CLOSE                  0x0001
#define SQL_CB_PRESERVE               0x0002

/* SQL_IDENTIFIER_CASE values */

#define SQL_IC_UPPER                  0x0001
#define SQL_IC_LOWER                  0x0002
#define SQL_IC_SENSITIVE              0x0003
#define SQL_IC_MIXED                  0x0004

/* SQL_TXN_CAPABLE values */

#define SQL_TC_NONE                   0x0000
#define SQL_TC_DML                    0x0001
#define SQL_TC_ALL                    0x0002
#define SQL_TC_DDL_COMMIT             0x0003
#define SQL_TC_DDL_IGNORE             0x0004

/* SQL_SCROLL_OPTIONS masks */

#define SQL_SO_FORWARD_ONLY           0x00000001L
#define SQL_SO_KEYSET_DRIVEN          0x00000002L
#define SQL_SO_DYNAMIC                0x00000004L
#define SQL_SO_MIXED                  0x00000008L
#define SQL_SO_STATIC                 0x00000010L

/* SQL_SCROLL_CONCURRENCY masks */

#define SQL_SCCO_READ_ONLY            0x00000001L
#define SQL_SCCO_LOCK                 0x00000002L
#define SQL_SCCO_OPT_ROWVER           0x00000004L
#define SQL_SCCO_OPT_VALUES           0x00000008L
#define SQL_SCCO_OPT_TIMESTAMP        SQL_SCCO_OPT_ROWVER   /* deprecated */

/* SQL_FETCH_DIRECTION masks */

#define  SQL_FD_FETCH_NEXT            0x00000001L
#define  SQL_FD_FETCH_FIRST           0x00000002L
#define  SQL_FD_FETCH_LAST            0x00000004L
#define  SQL_FD_FETCH_PREV            0x00000008L
#define  SQL_FD_FETCH_ABSOLUTE        0x00000010L
#define  SQL_FD_FETCH_RELATIVE        0x00000020L
#define  SQL_FD_FETCH_RESUME          0x00000040L
#define  SQL_FD_FETCH_BOOKMARK        0x00000080L

/* SQL_TXN_ISOLATION_OPTION masks */
#define  SQL_TXN_READ_UNCOMMITTED     0x00000001L
#define  SQL_TXN_READ_COMMITTED       0x00000002L
#define  SQL_TXN_REPEATABLE_READ      0x00000004L
#define  SQL_TXN_SERIALIZABLE         0x00000008L
#define  SQL_TXN_VERSIONING           0x00000010L
#define  SQL_TXN_NOCOMMIT             0x00000020L

/* SQL_CORRELATION_NAME values */

#define SQL_CN_NONE                   0x0000
#define SQL_CN_DIFFERENT              0x0001
#define SQL_CN_ANY                    0x0002

/* SQL_NON_NULLABLE_COLUMNS values */

#define SQL_NNC_NULL                  0x0000
#define SQL_NNC_NON_NULL              0x0001

/* SQL_NULL_COLLATION values */

#define SQL_NC_HIGH                   0x0000
#define SQL_NC_LOW                    0x0001
#define SQL_NC_START                  0x0002
#define SQL_NC_END                    0x0040

/* SQL_FILE_USAGE values */

#define SQL_FILE_NOT_SUPPORTED        0x0000
#define SQL_FILE_TABLE                0x0001
#define SQL_FILE_QUALIFIER            0x0002

/* SQL_GETDATA_EXTENSIONS values */

#define SQL_GD_ANY_COLUMN             0x00000001L
#define SQL_GD_ANY_ORDER              0x00000002L
#define SQL_GD_BLOCK                  0x00000004L
#define SQL_GD_BOUND                  0x00000008L

/* SQL_ALTER_TABLE values */

#define SQL_AT_ADD_COLUMN             0x00000001L
#define SQL_AT_DROP_COLUMN            0x00000002L

/* SQL_POSITIONED_STATEMENTS masks */

#define SQL_PS_POSITIONED_DELETE      0x00000001L
#define SQL_PS_POSITIONED_UPDATE      0x00000002L
#define SQL_PS_SELECT_FOR_UPDATE      0x00000004L

/* SQL_GROUP_BY values */

#define SQL_GB_NOT_SUPPORTED            0x0000
#define SQL_GB_GROUP_BY_EQUALS_SELECT   0x0001
#define SQL_GB_GROUP_BY_CONTAINS_SELECT 0x0002
#define SQL_GB_NO_RELATION              0x0003

/* SQL_OWNER_USAGE masks */

#define SQL_OU_DML_STATEMENTS         0x00000001L
#define SQL_OU_PROCEDURE_INVOCATION   0x00000002L
#define SQL_OU_TABLE_DEFINITION       0x00000004L
#define SQL_OU_INDEX_DEFINITION       0x00000008L
#define SQL_OU_PRIVILEGE_DEFINITION   0x00000010L

/* SQL_QUALIFIER_USAGE masks */

#define SQL_QU_DML_STATEMENTS         0x00000001L
#define SQL_QU_PROCEDURE_INVOCATION   0x00000002L
#define SQL_QU_TABLE_DEFINITION       0x00000004L
#define SQL_QU_INDEX_DEFINITION       0x00000008L
#define SQL_QU_PRIVILEGE_DEFINITION   0x00000010L

/* SQL_SUBQUERIES masks */

#define SQL_SQ_COMPARISON             0x00000001L
#define SQL_SQ_EXISTS                 0x00000002L
#define SQL_SQ_IN                     0x00000004L
#define SQL_SQ_QUANTIFIED             0x00000008L
#define SQL_SQ_CORRELATED_SUBQUERIES  0x00000010L

/* SQL_UNION masks */

#define SQL_U_UNION                   0x00000001L
#define SQL_U_UNION_ALL               0x00000002L

/* SQL_BOOKMARK_PERSISTENCE values */

#define SQL_BP_CLOSE                  0x00000001L
#define SQL_BP_DELETE                 0x00000002L
#define SQL_BP_DROP                   0x00000004L
#define SQL_BP_TRANSACTION            0x00000008L
#define SQL_BP_UPDATE                 0x00000010L
#define SQL_BP_OTHER_HSTMT            0x00000020L
#define SQL_BP_SCROLL                 0x00000040L

/* SQL_STATIC_SENSITIVITY values */

#define SQL_SS_ADDITIONS              0x00000001L
#define SQL_SS_DELETIONS              0x00000002L
#define SQL_SS_UPDATES                0x00000004L

/* SQL_LOCK_TYPES masks */

#define SQL_LCK_NO_CHANGE             0x00000001L
#define SQL_LCK_EXCLUSIVE             0x00000002L
#define SQL_LCK_UNLOCK                0x00000004L

/* SQL_POS_OPERATIONS masks */

#define SQL_POS_POSITION              0x00000001L
#define SQL_POS_REFRESH               0x00000002L
#define SQL_POS_UPDATE                0x00000004L
#define SQL_POS_DELETE                0x00000008L
#define SQL_POS_ADD                   0x00000010L

/* SQL_QUALIFIER_LOCATION values */

#define SQL_QL_START                  0x0001L
#define SQL_QL_END                    0x0002L

/* SQL_OJ_CAPABILITIES values */

#define SQL_OJ_LEFT                   0x00000001L
#define SQL_OJ_RIGHT                  0x00000002L
#define SQL_OJ_FULL                   0x00000004L
#define SQL_OJ_NESTED                 0x00000008L
#define SQL_OJ_NOT_ORDERED            0x00000010L
#define SQL_OJ_INNER                  0x00000020L
#define SQL_OJ_ALL_COMPARISON_OPS     0x00000040L


/* SQLGetTypeInfo define */
#define  SQL_ALL_TYPES                0

/* Options for SQLGetStmtOption/SQLSetStmtOption */
#define  SQL_QUERY_TIMEOUT      0
#define  SQL_MAX_ROWS           1
#define  SQL_NOSCAN             2
#define  SQL_MAX_LENGTH         3
#define  SQL_ASYNC_ENABLE       4
#define  SQL_BIND_TYPE          5
#define  SQL_CURSOR_TYPE        6
#define  SQL_CONCURRENCY        7
#define  SQL_KEYSET_SIZE        8
#define  SQL_ROWSET_SIZE        9
#define  SQL_SIMULATE_CURSOR    10
#define  SQL_RETRIEVE_DATA      11
#define  SQL_USE_BOOKMARKS      12
#define  SQL_GET_BOOKMARK       13
#define  SQL_ROW_NUMBER         14

/* Options for SQLGetStmtOption/SQLSetStmtOption extensions */
#define  SQL_CURSOR_HOLD        1250
#define  SQL_NODESCRIBE_OUTPUT  1251

#define  SQL_NODESCRIBE_INPUT   1264
#define  SQL_NODESCRIBE         SQL_NODESCRIBE_OUTPUT
#define  SQL_CLOSE_BEHAVIOR     1257

/* SQL_CLOSE_BEHAVIOR values.                  */

#define SQL_CC_NO_RELEASE             0
#define SQL_CC_RELEASE                1
#define SQL_CC_DEFAULT                SQL_CC_NO_RELEASE

/* CLI attribute/option values */
#define SQL_FALSE               0
#define SQL_TRUE                1

/* Options for SQL_CURSOR_HOLD */
#define SQL_CURSOR_HOLD_ON        1
#define SQL_CURSOR_HOLD_OFF       0
#define SQL_CURSOR_HOLD_DEFAULT   SQL_CURSOR_HOLD_ON


/* Options for SQL_NODESCRIBE_INPUT/SQL_NODESCRIBE_OUTPUT */
#define SQL_NODESCRIBE_ON          1
#define SQL_NODESCRIBE_OFF         0
#define SQL_NODESCRIBE_DEFAULT     SQL_NODESCRIBE_OFF

/* SQL_QUERY_TIMEOUT options */
#define SQL_QUERY_TIMEOUT_DEFAULT  0

/* SQL_MAX_ROWS options */
#define SQL_MAX_ROWS_DEFAULT       0

/* SQL_NOSCAN options */
#define SQL_NOSCAN_OFF             0
#define SQL_NOSCAN_ON              1
#define SQL_NOSCAN_DEFAULT         SQL_NOSCAN_OFF

/* SQL_MAX_LENGTH options */
#define SQL_MAX_LENGTH_DEFAULT     0

/* SQL_ASYNC_ENABLE options */
#define SQL_ASYNC_ENABLE_OFF       0
#define SQL_ASYNC_ENABLE_ON        1
#define SQL_ASYNC_ENABLE_DEFAULT   SQL_ASYNC_ENABLE_OFF

/* SQL_BIND_TYPE options */
#define SQL_BIND_BY_COLUMN         0
#define SQL_BIND_TYPE_DEFAULT      SQL_BIND_BY_COLUMN

/* SQL_CONCURRENCY options */
#define SQL_CONCUR_READ_ONLY       1
#define SQL_CONCUR_LOCK            2
#define SQL_CONCUR_ROWVER          3
#define SQL_CONCUR_VALUES          4
#define SQL_CONCUR_DEFAULT         SQL_CONCUR_READ_ONLY

/* SQL_CURSOR_TYPE options */
#define SQL_CURSOR_FORWARD_ONLY    0
#define SQL_CURSOR_KEYSET_DRIVEN   1
#define SQL_CURSOR_DYNAMIC         2
#define SQL_CURSOR_STATIC          3
#define SQL_CURSOR_TYPE_DEFAULT    SQL_CURSOR_FORWARD_ONLY

/* SQL_ROWSET_SIZE options */
#define SQL_ROWSET_SIZE_DEFAULT    1

/* SQL_KEYSET_SIZE options */
#define SQL_KEYSET_SIZE_DEFAULT    0

/* SQL_SIMULATE_CURSOR options */
#define SQL_SC_NON_UNIQUE          0
#define SQL_SC_TRY_UNIQUE          1
#define SQL_SC_UNIQUE              2

/* SQL_RETRIEVE_DATA options */
#define SQL_RD_OFF                 0
#define SQL_RD_ON                  1
#define SQL_RD_DEFAULT             SQL_RD_ON

/* SQL_USE_BOOKMARKS options */
#define SQL_UB_OFF                 0
#define SQL_UB_ON                  1
#define SQL_UB_DEFAULT             SQL_UB_OFF

/* Options for SQLSetConnectOption/SQLGetConnectOption */
#define SQL_ACCESS_MODE              101
#define SQL_AUTOCOMMIT               102
#define SQL_LOGIN_TIMEOUT            103
#define SQL_OPT_TRACE                104
#define SQL_OPT_TRACEFILE            105
#define SQL_TRANSLATE_DLL            106
#define SQL_TRANSLATE_OPTION         107
#define SQL_TXN_ISOLATION            108
#define SQL_CURRENT_QUALIFIER        109
#define SQL_ODBC_CURSORS             110
#define SQL_QUIET_MODE               111
#define SQL_PACKET_SIZE              112
#define SQL_CONNECT_OPT_DRVR_START   1000

/* Options for SQLGetConnectOption/SQLSetConnectOption extensions */
#define SQL_WCHARTYPE                1252
#define SQL_LONGDATA_COMPAT          1253
#define SQL_CURRENT_SCHEMA           1254
#define SQL_DB2EXPLAIN               1258
#define SQL_DB2ESTIMATE              1259
#define SQL_PARAMOPT_ATOMIC          1260
#define SQL_STMTTXN_ISOLATION        1261
#define SQL_MAXCONN                  1262

/* Options for SQLSetConnectOption, SQLSetEnvAttr */
#define SQL_CONNECTTYPE              1255
#define SQL_SYNC_POINT               1256
#define SQL_MINMEMORY_USAGE          1263

/* Options for SQL_LONGDATA_COMPAT */
#define SQL_LD_COMPAT_YES            1
#define SQL_LD_COMPAT_NO             0
#define SQL_LD_COMPAT_DEFAULT        SQL_LD_COMPAT_NO

/*
 *  Options for SQL_PARAMOPT_ATOMIC
 */

#define SQL_ATOMIC_YES               1
#define SQL_ATOMIC_NO                0
#define SQL_ATOMIC_DEFAULT           SQL_ATOMIC_YES

/* Options for SQL_CONNECT_TYPE */
#define SQL_CONCURRENT_TRANS         1
#define SQL_COORDINATED_TRANS        2
#define SQL_CONNECTTYPE_DEFAULT      SQL_CONCURRENT_TRANS

/* Options for SQL_SYNCPOINT */
#define SQL_ONEPHASE                 1
#define SQL_TWOPHASE                 2
#define SQL_SYNCPOINT_DEFAULT        SQL_ONEPHASE

/* Options for SQL_DB2ESTIMATE */
#define SQL_DB2ESTIMATE_ON           1
#define SQL_DB2ESTIMATE_OFF          0
#define SQL_DB2ESTIMATE_DEFAULT      SQL_DB2ESTIMATE_OFF

/* Options for SQL_DB2EXPLAIN */
#define SQL_DB2EXPLAIN_OFF              0x00000000L
#define SQL_DB2EXPLAIN_SNAPSHOT_ON      0x00000001L
#define SQL_DB2EXPLAIN_MODE_ON          0x00000002L
#define SQL_DB2EXPLAIN_SNAPSHOT_MODE_ON SQL_DB2EXPLAIN_SNAPSHOT_ON+SQL_DB2EXPLAIN_MODE_ON
#define SQL_DB2EXPLAIN_ON               SQL_DB2EXPLAIN_SNAPSHOT_ON
#define SQL_DB2EXPLAIN_DEFAULT          SQL_DB2EXPLAIN_OFF

/* Options for SQL_WCHARTYPE
 * Note that you can only specify SQL_WCHARTYPE_CONVERT if you have an
 * external compile flag SQL_WCHART_CONVERT defined
 */
#ifdef SQL_WCHART_CONVERT
#define SQL_WCHARTYPE_CONVERT        1
#endif
#define SQL_WCHARTYPE_NOCONVERT      0
#define SQL_WCHARTYPE_DEFAULT        SQL_WCHARTYPE_NOCONVERT

/* SQL_ACCESS_MODE options */
#define SQL_MODE_READ_WRITE          0
#define SQL_MODE_READ_ONLY           1
#define SQL_MODE_DEFAULT             SQL_MODE_READ_WRITE

/* SQL_AUTOCOMMIT options */
#define SQL_AUTOCOMMIT_OFF           0
#define SQL_AUTOCOMMIT_ON            1
#define SQL_AUTOCOMMIT_DEFAULT       SQL_AUTOCOMMIT_ON

/* SQL_LOGIN_TIMEOUT options */
#define SQL_LOGIN_TIMEOUT_DEFAULT    0

/* Column types and scopes in SQLSpecialColumns */
#define SQL_BEST_ROWID               1
#define SQL_ROWVER                   2

#define SQL_SCOPE_CURROW             0
#define SQL_SCOPE_TRANSACTION        1
#define SQL_SCOPE_SESSION            2

/* Defines for SQLStatistics */
#define SQL_INDEX_UNIQUE             0
#define SQL_INDEX_ALL                1

#define SQL_QUICK                    0
#define SQL_ENSURE                   1

/* Defines for SQLStatistics (returned in the result set) */
#define SQL_TABLE_STAT               0
#define SQL_INDEX_CLUSTERED          1
#define SQL_INDEX_HASHED             2
#define SQL_INDEX_OTHER              3

/* Defines for SQLSpecialColumns (returned in the result set) */
#define SQL_PC_UNKNOWN               0
#define SQL_PC_NOT_PSEUDO            1
#define SQL_PC_PSEUDO                2

/* SQLDataSources "fDirection" values, also used on SQLExtendedFetch() */
/* See sqlext.h for additional SQLExtendedFetch fetch direction defines */
#define  SQL_FETCH_NEXT              1
#define  SQL_FETCH_FIRST             2


/*
 * Environment attributes; note SQL_CONNECTTYPE, SQL_SYNC_POINT are also
 * environment attributes that are settable at the connection level
 */
#define SQL_ATTR_OUTPUT_NTS          10001


/*  LOB file reference options */
#ifndef SQL_H_SQL                     /* if sql.h is not included, then...  */
#define SQL_FILE_READ              2  /* Input file to read from            */
#define SQL_FILE_CREATE            8  /* Output file - new file to be       */
                                      /* created                            */
#define SQL_FILE_OVERWRITE        16  /* Output file - overwrite existing   */
                                      /* file or create a new file if it    */
                                      /* doesn't exist                      */
#define SQL_FILE_APPEND           32  /* Output file - append to an         */
                                      /* existing file or create a new file */
                                      /* if it doesn't exist                */
#endif

/*
 *  Source of string for SQLGetLength(), SQLGetPosition(),
 *  and SQLGetSubstring().
 */
#define SQL_FROM_LOCATOR           2
#define SQL_FROM_LITERAL           3



/*
 *  Function definitions of APIs in both X/Open CLI and ODBC
 */

SQLRETURN SQL_API_FN  SQLColumns       (SQLHSTMT          hstmt,
                                        SQLCHAR     FAR   *szCatalogName,
                                        SQLSMALLINT       cbCatalogName,
                                        SQLCHAR     FAR   *szSchemaName,
                                        SQLSMALLINT       cbSchemaName,
                                        SQLCHAR     FAR   *szTableName,
                                        SQLSMALLINT       cbTableName,
                                        SQLCHAR     FAR   *szColumnName,
                                        SQLSMALLINT       cbColumnName);

SQLRETURN SQL_API_FN  SQLDataSources   (SQLHENV           henv,
                                        SQLUSMALLINT      fDirection,
                                        SQLCHAR     FAR   *szDSN,
                                        SQLSMALLINT       cbDSNMax,
                                        SQLSMALLINT FAR   *pcbDSN,
                                        SQLCHAR     FAR   *szDescription,
                                        SQLSMALLINT       cbDescriptionMax,
                                        SQLSMALLINT FAR   *pcbDescription);

SQLRETURN SQL_API_FN  SQLGetConnectOption (
                                        SQLHDBC           hdbc,
                                        SQLUSMALLINT      fOption,
                                        SQLPOINTER        pvParam);

SQLRETURN SQL_API_FN  SQLGetFunctions  (SQLHDBC           hdbc,
                                        SQLUSMALLINT      fFunction,
                                        SQLUSMALLINT FAR  *pfExists);

SQLRETURN SQL_API_FN  SQLGetInfo       (SQLHDBC           hdbc,
                                        SQLUSMALLINT      fInfoType,
                                        SQLPOINTER        rgbInfoValue,
                                        SQLSMALLINT       cbInfoValueMax,
                                        SQLSMALLINT FAR   *pcbInfoValue);

SQLRETURN SQL_API_FN  SQLGetStmtOption (SQLHSTMT          hstmt,
                                        SQLUSMALLINT      fOption,
                                        SQLPOINTER        pvParam);

SQLRETURN SQL_API_FN  SQLGetTypeInfo   (SQLHSTMT          hstmt,
                                        SQLSMALLINT       fSqlType);

SQLRETURN SQL_API_FN  SQLParamData     (SQLHSTMT          hstmt,
                                        SQLPOINTER  FAR   *prgbValue);

SQLRETURN SQL_API_FN  SQLPutData       (SQLHSTMT          hstmt,
                                        SQLPOINTER        rgbValue,
                                        SQLINTEGER        cbValue);

SQLRETURN SQL_API_FN  SQLSetConnectOption(
                                        SQLHDBC           hdbc,
                                        SQLUSMALLINT      fOption,
                                        SQLUINTEGER       vParam);

SQLRETURN SQL_API_FN  SQLSetStmtOption (SQLHSTMT          hstmt,
                                        SQLUSMALLINT      fOption,
                                        SQLUINTEGER       vParam);

SQLRETURN SQL_API_FN  SQLSpecialColumns(SQLHSTMT          hstmt,
                                        SQLUSMALLINT      fColType,
                                        SQLCHAR     FAR   *szCatalogName,
                                        SQLSMALLINT       cbCatalogName,
                                        SQLCHAR     FAR   *szSchemaName,
                                        SQLSMALLINT       cbSchemaName,
                                        SQLCHAR     FAR   *szTableName,
                                        SQLSMALLINT       cbTableName,
                                        SQLUSMALLINT      fScope,
                                        SQLUSMALLINT      fNullable);

SQLRETURN SQL_API_FN  SQLStatistics    (SQLHSTMT          hstmt,
                                        SQLCHAR     FAR   *szCatalogName,
                                        SQLSMALLINT       cbCatalogName,
                                        SQLCHAR     FAR   *szSchemaName,
                                        SQLSMALLINT       cbSchemaName,
                                        SQLCHAR     FAR   *szTableName,
                                        SQLSMALLINT       cbTableName,
                                        SQLUSMALLINT      fUnique,
                                        SQLUSMALLINT      fAccuracy);

SQLRETURN SQL_API_FN  SQLTables        (SQLHSTMT          hstmt,
                                        SQLCHAR     FAR   *szCatalogName,
                                        SQLSMALLINT       cbCatalogName,
                                        SQLCHAR     FAR   *szSchemaName,
                                        SQLSMALLINT       cbSchemaName,
                                        SQLCHAR     FAR   *szTableName,
                                        SQLSMALLINT       cbTableName,
                                        SQLCHAR     FAR   *szTableType,
                                        SQLSMALLINT       cbTableType);


/*
 * DB2 specific CLI APIs
 */

SQLRETURN SQL_API_FN SQLBindFileToCol  (SQLHSTMT          hstmt,
                                        SQLUSMALLINT      icol,
                                        SQLCHAR     FAR   *FileName,
                                        SQLSMALLINT FAR   *FileNameLength,
                                        SQLUINTEGER FAR   *FileOptions,
                                        SQLSMALLINT       MaxFileNameLength,
                                        SQLINTEGER  FAR   *StringLength,
                                        SQLINTEGER  FAR   *IndicatorValue);

SQLRETURN SQL_API_FN SQLBindFileToParam(SQLHSTMT          hstmt,
                                        SQLUSMALLINT      ipar,
                                        SQLSMALLINT       fSqlType,
                                        SQLCHAR     FAR   *FileName,
                                        SQLSMALLINT FAR   *FileNameLength,
                                        SQLUINTEGER FAR   *FileOptions,
                                        SQLSMALLINT       MaxFileNameLength,
                                        SQLINTEGER  FAR   *IndicatorValue);

SQLRETURN SQL_API_FN SQLGetLength      (SQLHSTMT          hstmt,
                                        SQLSMALLINT       LocatorCType,
                                        SQLINTEGER        Locator,
                                        SQLINTEGER  FAR   *StringLength,
                                        SQLINTEGER  FAR   *IndicatorValue);

SQLRETURN SQL_API_FN SQLGetPosition    (SQLHSTMT          hstmt,
                                        SQLSMALLINT       LocatorCType,
                                        SQLINTEGER        SourceLocator,
                                        SQLINTEGER        SearchLocator,
                                        SQLCHAR     FAR   *SearchLiteral,
                                        SQLINTEGER        SearchLiteralLength,
                                        SQLUINTEGER       FromPosition,
                                        SQLUINTEGER FAR   *LocatedAt,
                                        SQLINTEGER  FAR   *IndicatorValue);


SQLRETURN SQL_API_FN SQLGetSQLCA       (SQLHENV           henv,
                                        SQLHDBC           hdbc,
                                        SQLHSTMT          hstmt,
                                        struct sqlca FAR  *pSqlca );

SQLRETURN SQL_API_FN SQLGetSubString   (SQLHSTMT          hstmt,
                                        SQLSMALLINT       LocatorCType,
                                        SQLINTEGER        SourceLocator,
                                        SQLUINTEGER       FromPosition,
                                        SQLUINTEGER       ForLength,
                                        SQLSMALLINT       TargetCType,
                                        SQLPOINTER        rgbValue,
                                        SQLINTEGER        cbValueMax,
                                        SQLINTEGER  FAR   *StringLength,
                                        SQLINTEGER  FAR   *IndicatorValue);

SQLRETURN SQL_API_FN SQLSetColAttributes (SQLHSTMT        hstmt,
                                        SQLUSMALLINT      icol,
                                        SQLCHAR     FAR   *pszColName,
                                        SQLSMALLINT       cbColName,
                                        SQLSMALLINT       fSQLType,
                                        SQLUINTEGER       cbColDef,
                                        SQLSMALLINT       ibScale,
                                        SQLSMALLINT       fNullable);

/*
 *  Set active connection API, for use in conjunction with embedded
 *  SQL programming only.
 */
SQLRETURN SQL_API_FN SQLSetConnection  (SQLHDBC           hdbc);

/*
 * APIs defined only by X/Open CLI
 */

SQLRETURN SQL_API_FN SQLGetEnvAttr     (SQLHENV           henv,
                                        SQLINTEGER        Attribute,
                                        SQLPOINTER        Value,
                                        SQLINTEGER        BufferLength,
                                        SQLINTEGER  FAR   *StringLength);

SQLRETURN SQL_API_FN SQLSetEnvAttr     (SQLHENV           henv,
                                        SQLINTEGER        Attribute,
                                        SQLPOINTER        Value,
                                        SQLINTEGER        StringLength);




#ifdef __cplusplus
}
#endif

/*
 * Include ODBC Version 2.50 header files for ODBC Level 1 and Level 2
 * functions that are not specified in the X/Open Call Level Interface.
 * This is included with permission from Microsoft.
 * Do not modify (i.e. must not add, remove, rearrange) any part of the
 * contents of sqlext.h
 * Note: SQLBrowseConnect(), SQLDescribeParam(), SQLDrivers, and SQLSetPos()
 *       in sqlext.h are not supported by the current version of DB2 CLI.
 */
#ifndef __SQL
#define __SQL
#define ODBCVER 0x0250
#endif
#include "sqlext.h"

#endif /* SQL_H_SQLCLI1 */
