/******************************************************************************
 *
 * Source File Name = SQLMON.H
 *
 * (C) COPYRIGHT International Business Machines Corp. 1993, 1995
 * All Rights Reserved
 * Licensed Materials - Property of IBM
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * Function = Include File defining:
 *              Database Monitor - Constants
 *              Database Monitor - Structures
 *              Database Monitor - Function Prototypes
 *
 * Operating System: Common C Include File
 *
 *****************************************************************************/

#ifndef  SQL_H_SQLMON
   #define SQL_H_SQLMON            /* Permit duplicate Includes */

#ifdef __cplusplus
extern "C" {
#endif

#include "sqlsystm.h"              /* System dependent defines     */
#include "sqlca.h"                 /* SQL API - Communication Area */
#include "sqlenv.h"                /* DB2 Environment commands     */

#if (defined(DB2OS2) || defined(DB2NT))
#pragma pack(4)
#elif (defined(DB2WIN))
#pragma pack(2)
#elif (defined(DB2MAC))
#if (defined(DB2PPC))
#pragma align 4
#elif (defined(DB268K))
#pragma align 2
#endif
#elif (defined(DB2HP) || defined(DB2SNI))

#elif (defined(DB2SUN))
#pragma options align=natural
#elif (defined(DB2AIX))
#pragma options align=power
#endif

/******************************************************************************/
/* Database Monitor Version Constant                                          */
/******************************************************************************/

#define SQLM_DBMON_VERSION1  1
#define SQLM_DBMON_VERSION2  2

/******************************************************************************/
/* Snapshot Monitor Collected Information types                               */
/* Structure identifier in Snapshot buffer (info_type element)                */
/******************************************************************************/

#define SQLM_DB2_SS                '1'   /* DB2 information                   */
#define SQLM_DBASE_SS              '2'   /* Database information              */
#define SQLM_APPL_SS               '3'   /* Application information           */
#define SQLM_APPLINFO_SS           '4'   /* Summary Application information   */
#define SQLM_TABLE_HEADER_SS       '5'   /* Table Header information          */
#define SQLM_TABLE_SS              '6'   /* Table information                 */
#define SQLM_DBASE_LOCK_SS         '7'   /* Database Lock information         */
#define SQLM_APPL_LOCK_SS          '8'   /* Application Lock information      */
#define SQLM_LOCK_SS               '9'   /* Lock information                  */
#define SQLM_DCS_APPLINFO_SS       'A'   /* DCS Application info              */
#define SQLM_TABLESPACE_HEADER_SS  'B'   /* Tablespace Header information     */
#define SQLM_TABLESPACE_SS         'C'   /* Tablespace information            */

/******************************************************************************/
/* level of data to collect                                                   */
/******************************************************************************/

#define SQLMA_DB2                 1      /* DB2 related information           */
#define SQLMA_DBASE               2      /* database related information      */
#define SQLMA_APPL                3      /* appl info - by appl_id            */
#define SQLMA_AGENT_ID            4      /* appl info by agentid              */
#define SQLMA_DBASE_TABLES        5      /* table related info for a database */
#define SQLMA_DBASE_APPLS         6      /* appl related info for a database  */
#define SQLMA_DBASE_APPLINFO      7      /* appl related info for a database  */
#define SQLMA_DBASE_LOCKS         8      /* lock related info for a database  */
#define SQLMA_DBASE_ALL           9      /* db info for all database in DB2   */
#define SQLMA_APPL_ALL           10      /* appl info for all apps            */
#define SQLMA_APPLINFO_ALL       11      /* summary appl info for all appls   */
#define SQLMA_DCS_APPLINFO_ALL   12      /* summary appl info for all appls   */
#define SQLMA_DBASE_TABLESPACES  13      /* tablespace related info for dbase */

/******************************************************************************/
/* size definitions                                                           */
/******************************************************************************/

#define SQLM_APPLID_SZ        32          /* size of the application id       */
#define SQLM_SEQ_SZ            4          /* sequence number size             */
#define SQLM_SH_IDENT_SZ       8          /* Small identifier size            */
#define SQLM_IDENT_SZ         20          /* General identifier size          */
#define SQLM_OBJECT_SZ        36          /* object size in sqlma structure   */
#define SQLM_RESERVED_SZ      32          /* Reserved space size              */
#define SQLM_DBPATH_SZ       256          /* Database Path size               */

/******************************************************************************/
/* Information group state switches                                           */
/******************************************************************************/

#define SQLM_OFF    0              /* Turn monitoring group OFF               */
#define SQLM_ON     1              /* Turn monitoring group ON                */
#define SQLM_HOLD   2              /* leave monitoring group in current state */

/******************************************************************************/
/* Information groups array indexes                                           */
/******************************************************************************/

#define SQLM_UOW_SW          0           /* Select Unit of Work information   */
#define SQLM_STATEMENT_SW    1           /* Select Statement information      */
#define SQLM_TABLE_SW        2           /* Select Table information          */
#define SQLM_BUFFER_POOL_SW  3           /* Select Buffer Pool information    */
#define SQLM_LOCK_SW         4           /* Select Lock information           */
#define SQLM_SORT_SW         5           /* Select Sort information           */

#define SQLM_NUM_GROUPS      6           /* number of monitor groups          */

/******************************************************************************/
/* Statement Types                                                            */
/******************************************************************************/
#define SQLM_STATIC            1         /* Static statement                  */
#define SQLM_DYNAMIC           2         /* Dynamic statement                 */
#define SQLM_NON_STMT          3         /* Operation other than an SQL stmt  */
#define SQLM_STMT_TYPE_UNKNOWN 4         /* Unknown statement type            */

/******************************************************************************/
/* Statement Operation Types                                                  */
/******************************************************************************/
#define SQLM_PREPARE            1        /* Prepare operation                 */
#define SQLM_EXECUTE            2        /* Execute operation                 */
#define SQLM_EXECUTE_IMMEDIATE  3        /* Execute Immediate operation       */
#define SQLM_OPEN               4        /* Open operation                    */
#define SQLM_FETCH              5        /* Fetch operation                   */
#define SQLM_CLOSE              6        /* Close operation                   */
#define SQLM_DESCRIBE           7        /* Describe operation                */
#define SQLM_STATIC_COMMIT      8        /* Static Commit operation           */
#define SQLM_STATIC_ROLLBACK    9        /* Static Rollback operation         */
#define SQLM_FREE_LOCATOR      10        /* Free Locator operation            */

/******************************************************************************/
/* Table Types                                                                */
/******************************************************************************/
#define SQLM_USER_TABLE      1           /* User table                        */
#define SQLM_DROPPED_TABLE   2           /* Dropped user table                */
#define SQLM_TEMP_TABLE      3           /* Temporary table                   */
#define SQLM_CATALOG_TABLE   4           /* System Catalog table              */
#define SQLM_REORG_TABLE     5           /* Reorg table                       */

/******************************************************************************/
/* lock modes                                                                 */
/******************************************************************************/

#define SQLM_LNON  0                  /*  No Lock                             */
#define SQLM_LOIS  1                  /*  Intention Share Lock                */
#define SQLM_LOIX  2                  /*  Intention Exclusive Lock            */
#define SQLM_LOOS  3                  /*  Share Lock                          */
#define SQLM_LSIX  4                  /*  Share with Intention Exclusive Lock */
#define SQLM_LOOX  5                  /*  Exclusive Lock                      */
#define SQLM_LOIN  6                  /*  Intent None (For Dirty Read)        */
#define SQLM_LOOZ  7                  /*  Super Exclusive Lock                */
#define SQLM_LOOU  8                  /*  Update Lock                         */

/******************************************************************************/
/* application status                                                         */
/******************************************************************************/

#define SQLM_CONNECTPEND          1            /* connect pending             */
#define SQLM_CONNECTED            2            /* connect completed           */
#define SQLM_UOWEXEC              3            /* UOW executing               */
#define SQLM_UOWWAIT              4            /* UOW waiting                 */
#define SQLM_LOCKWAIT             5            /* lock wait                   */
#define SQLM_COMMIT_ACT           6            /* commit active               */
#define SQLM_ROLLBACK_ACT         7            /* rollback active             */
#define SQLM_RECOMP               8            /* recompiling a plan          */
#define SQLM_COMP                 9            /* compiling a SQL statement   */
#define SQLM_INTR                10            /* request interrupted         */
#define SQLM_DISCONNECTPEND      11            /* disconnect pending          */
#define SQLM_TPREP               12            /* Prepared transaction        */
#define SQLM_THCOMT              13            /* heuristically committed     */
#define SQLM_THABRT              14            /* heuristically rolled back   */
#define SQLM_TEND                15            /* Transaction ended           */
#define SQLM_CREATE_DB           16            /* Creating Database           */
#define SQLM_RESTART             17            /* Restarting a Database       */
#define SQLM_RESTORE             18            /* Restoring a Database        */
#define SQLM_BACKUP              19            /* Performing a Backup         */
#define SQLM_LOAD                20            /* Performing a fast load      */
#define SQLM_UNLOAD              21            /* Performing a fast unload    */
#define SQLM_IOERROR_WAIT        22            /* Wait to disable tablespace  */
#define SQLM_QUIESCE_TABLESPACE  23            /* Quiescing a tablespace      */

/******************************************************************************/
/* database status                                                            */
/******************************************************************************/

#define SQLM_DB_ACTIVE          0              /* Database is active          */
#define SQLM_DB_QUIESCE_PEND    1              /* Quiesce is pending for DB   */
#define SQLM_DB_QUIESCED        2              /* Database has been quiesced  */

/******************************************************************************/
/* database manager status                                                    */
/******************************************************************************/

#define SQLM_DB2_ACTIVE          0             /* DB2 is active               */
#define SQLM_DB2_QUIESCE_PEND    1             /* Quiesce is pending for DB2  */
#define SQLM_DB2_QUIESCED        2             /* DB2 has been quiesced       */

/******************************************************************************/
/* UOW completion status                                                      */
/******************************************************************************/

#define SQLM_UOWCOMMIT       1       /* UOW issued a commit                   */
#define SQLM_UOWROLLBACK     2       /* UOW issued a rollback                 */
#define SQLM_UOWDEADLOCK     3       /* UOW was rolled back due to a deadlock */
#define SQLM_UOWABEND        4       /* UOW was rolled back due to an abend   */
#define SQLM_APPL_END        5       /* application normal termination        */
#define SQLM_UOWLOCKTIMEOUT  6       /* UOW was rolled back from lock timeout */

/******************************************************************************/
/* lock object type                                                           */
/******************************************************************************/

#define SQLM_TABLE_LOCK       1          /* table lock type                   */
#define SQLM_ROW_LOCK         2          /* table row lock type               */
#define SQLM_INTERNAL_LOCK    3          /* Internal lock type                */
#define SQLM_TABLESPACE_LOCK  4          /* Tablespace lock type              */

/******************************************************************************/
/* lock status                                                                */
/******************************************************************************/

#define SQLM_LRBGRNT      1                     /*  Granted State             */
#define SQLM_LRBCONV      2                     /*  Converting state          */

/******************************************************************************/
/* client communications protocols                                            */
/******************************************************************************/
#define SQLM_PROT_APPC         SQL_PROTOCOL_APPC    /* appc                   */
#define SQLM_PROT_NETBIOS      SQL_PROTOCOL_NETB    /* netbios                */
#define SQLM_PROT_APPN         SQL_PROTOCOL_APPN    /* appn                   */
#define SQLM_PROT_TCPIP        SQL_PROTOCOL_TCPIP   /* tcp/ip                 */
#define SQLM_PROT_CPIC         SQL_PROTOCOL_CPIC    /* APPC using CPIC        */
#define SQLM_PROT_IPXSPX       SQL_PROTOCOL_IPXSPX  /* ipx/spx                */
#define SQLM_PROT_LOCAL        SQL_PROTOCOL_LOCAL   /* local client           */
#define SQLM_PROT_NPIPE        SQL_PROTOCOL_NPIPE   /* Named pipe             */


/******************************************************************************/
/* client platforms                                                           */
/******************************************************************************/
#define SQLM_PLATFORM_UNKNOWN         0         /* Unknown client platform    */
#define SQLM_PLATFORM_OS2             1         /* OS/2 client                */
#define SQLM_PLATFORM_DOS             2         /* DOS client                 */
#define SQLM_PLATFORM_WINDOWS         3         /* Windows client             */
#define SQLM_PLATFORM_AIX             4         /* AIX client                 */
#define SQLM_PLATFORM_NT              5         /* NT client                  */
#define SQLM_PLATFORM_HP              6         /* HP client                  */
#define SQLM_PLATFORM_SUN             7         /* Sun client                 */
#define SQLM_PLATFORM_MVS_DRDA        8         /* MVS client via DRDA        */
#define SQLM_PLATFORM_AS400_DRDA      9         /* AS400 client via DRDA      */
#define SQLM_PLATFORM_VM_DRDA        10         /* VM client via DRDA         */
#define SQLM_PLATFORM_VSE_DRDA       11         /* VSE client via DRDA        */
#define SQLM_PLATFORM_UNKNOWN_DRDA   12         /* Unknown DRDA Client        */
#define SQLM_PLATFORM_SNI            13         /* Siemens Nixdorf            */
#define SQLM_PLATFORM_MAC            14         /* Macintosh Client           */
#define SQLM_PLATFORM_WINDOWS95      15         /* Windows 95                 */
#define SQLM_PLATFORM_SCO            16         /* SCO                        */
#define SQLM_PLATFORM_SGI            17         /* Silicon Graphic            */


/******************************************************************************/
/* Event Monitor Type Identifiers                                             */
/******************************************************************************/
#define SQLM_EVENT_DB               1  /* Database Event                      */
#define SQLM_EVENT_CONN             2  /* Connection Event                    */
#define SQLM_EVENT_TABLE            3  /* Table Event                         */
#define SQLM_EVENT_STMT             4  /* Statement Event                     */
#define SQLM_EVENT_STMTTEXT         5  /* Dynamic Statement Text Event        */
#define SQLM_EVENT_XACT             6  /* Transaction Event                   */
#define SQLM_EVENT_DEADLOCK         7  /* Deadlock Event                      */
#define SQLM_EVENT_DLCONN           8  /* Deadlock Connection Event           */
#define SQLM_EVENT_TABLESPACE       9  /* Tablespace Event                    */
#define SQLM_EVENT_DBHEADER        10  /* Database Header Event               */
#define SQLM_EVENT_START           11  /* Event monitor start Event           */
#define SQLM_EVENT_CONNHEADER      12  /* Connection Header Event             */
#define SQLM_EVENT_OVERFLOW        13  /* Overflow Event                      */

/******************************************************************************/
/* Event Monitor Byte Order Identifiers                                       */
/******************************************************************************/
#define SQLM_LITTLE_ENDIAN      0         /* Little endian server             */
#define SQLM_BIG_ENDIAN        -1         /* Big endian server                */

/******************************************************************************/
/* Database Monitor Error Constants                                           */
/******************************************************************************/

#define SQLM_RC_INV_PTR         -1601 /* Parameter is a NULL pointer          */
#define SQLM_RC_INV_OBJ_TYPE    -1602 /* invalid obj_type in sqlma struct     */
#define SQLM_RC_NOT_SPECIFIED   -1603 /* dbname/appl_id not specified in sqlma*/
#define SQLM_RC_NOT_NULL_TERM   -1604 /* dbname/appl_id not NULL terminated   */
#define SQLM_RC_DBNOACT         +1605 /* database is not active               */
#define SQLM_RC_BUFFER_FULL     +1606 /* DBMON buffer area is full            */
#define SQLM_RC_NOMEM           -1607 /* not enough working memory for DBMON  */
#define SQLM_RC_DUPLICATE_DB    +1608 /* duplicate database aliases           */
#define SQLM_RC_REMOTE_DB       -1609 /* cannot monitor remote databases      */
#define SQLM_RC_INV_VALUE       -1610 /* invalid value for input parameter    */
#define SQLM_RC_NO_DATA         +1611 /* No data returned by Database Monitor */
#define SQLM_RC_TOO_MANY_OBJECTS -1623/* Too many objects for this request.   */
#define SQLM_RC_MULTIPLE_NODES  -1624 /* Databases in a sqlmonsz or sqlmonss  */
                                      /* call reside at different nodes.      */

/******************************************************************************/
/* Database Monitor Snapshot Data Structures                                  */
/******************************************************************************/

/******************************************************************************/
/*  SQL Monitor Area object definition                                        */
/******************************************************************************/

typedef struct sqlm_obj_struct
{
   unsigned long agent_id;                        /* agent id                 */
   unsigned long obj_type;                        /* type of object           */
   _SQLOLDCHAR   object[SQLM_OBJECT_SZ];          /* object name              */
}sqlm_obj_struct;

/******************************************************************************/
/*  SQL Monitor Area                                                          */
/******************************************************************************/
typedef struct sqlma
{
   unsigned long obj_num;                         /* number obj_vars elements */
   sqlm_obj_struct obj_var[1];                    /* object details           */
}sqlma;

/******************************************************************************/
/* macro for estimating SQLMA size                                            */
/******************************************************************************/

#define SQLMASIZE(n) (sizeof(struct sqlma)+(n-1)*(sizeof(struct sqlm_obj_struct)) )

/******************************************************************************/
/* time stamp data structure                                                  */
/******************************************************************************/

typedef struct sqlm_timestamp
{
  unsigned long seconds;          /* time in seconds since Jan.1,1970         */
  unsigned long microsec;         /* microseconds, range 0 to 999999          */
}sqlm_timestamp;

/******************************************************************************/
/* Elpased time stamp data structure (for CPU times)                          */
/******************************************************************************/

typedef struct sqlm_time
{
  unsigned long seconds;           /* elpsed seconds                          */
  unsigned long microsec;          /* elpased microseconds, range 0 to 999999 */
}sqlm_time;


/******************************************************************************/
/* State information for each monitor group                                   */
/******************************************************************************/
typedef struct sqlm_recording_group
{
  unsigned long  input_state;        /* input state to set group              */
  unsigned long  output_state;       /* returned current state                */
  sqlm_timestamp start_time;         /* monitor group start time              */
}sqlm_recording_group;

/******************************************************************************/
/* collection count data structure returned from get monitor info             */
/******************************************************************************/

typedef struct sqlm_collected
{
  unsigned long  size;            /* size of sqlm_collected                   */
  unsigned long  db2;             /* 1 if db2 info collected, 0 otherwise     */
  unsigned long  databases;       /* # databases for which info was collected */
  unsigned long  table_databases; /* # databases for which table info was     */
                                  /* collected                                */
  unsigned long  lock_databases;  /* # databases for which lock info was      */
                                  /* collected                                */
  unsigned long  applications;    /* # appls for which info was collected     */
  unsigned long  applinfos;       /* # appls for which summary info was coll. */
  unsigned long  dcs_applinfos;   /* # DDCS appls for which info was collected*/
  unsigned long  server_db2_type; /* Server DB2 Type                          */
  sqlm_timestamp time_stamp;      /* time stamp when Snapshot was taken       */
  sqlm_recording_group group_states[SQLM_NUM_GROUPS];
                                              /* current group states         */
  _SQLOLDCHAR    server_prdid[SQLM_IDENT_SZ]; /* product/version on server    */
  _SQLOLDCHAR    server_nname[SQLM_IDENT_SZ]; /* Config NNAME of server       */
  _SQLOLDCHAR    server_instance_name[SQLM_IDENT_SZ]; /*instance name of DB2  */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  unsigned long  tablespace_databases; /* # dbases for which tblspace info col*/
                                     /* was collected                         */
  unsigned long  server_version;       /* Version of server returning data    */
}sqlm_collected;

/******************************************************************************/
/* Application Identification Information                                     */
/******************************************************************************/

typedef struct sqlm_appl_id_info
{
  unsigned long  agent_id;                   /* agent id                      */
  unsigned long  appl_status;                /* Application Status            */
  unsigned long  codepage_id;                /* codepage/CCSID at node        */
                                             /* where app started             */
  sqlm_timestamp status_change_time;         /* last appl status change time  */
  _SQLOLDCHAR    appl_name[SQLM_IDENT_SZ];   /* Application Program Name      */
  _SQLOLDCHAR    appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  _SQLOLDCHAR    sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  _SQLOLDCHAR    auth_id[SQLM_IDENT_SZ];     /* Authorization Id              */
  _SQLOLDCHAR    client_nname[SQLM_IDENT_SZ]; /* Config NNAME of client       */
  _SQLOLDCHAR    client_prdid[SQLM_IDENT_SZ]; /* product/version on client    */
  _SQLOLDCHAR    input_db_alias[SQLM_IDENT_SZ]; /* Input Database Alias       */
  _SQLOLDCHAR    client_db_alias[SQLM_IDENT_SZ]; /* Client Database Alias     */
  _SQLOLDCHAR    db_name[SQLM_IDENT_SZ];     /* Database name                 */
  _SQLOLDCHAR    db_path[SQLM_DBPATH_SZ];    /* Database Path                 */
}sqlm_appl_id_info;

/******************************************************************************/
/* Application Id Information data structutre                                 */
/******************************************************************************/


typedef struct sqlm_applinfo
{
  unsigned long  size;                       /* size of sqlm_applinfo         */
  _SQLOLDCHAR    info_type;                  /* collected information type    */
  _SQLOLDCHAR    pad[3];                     /* padding for 4 byte alignment  */
  sqlm_appl_id_info   id_info;               /* Identification information    */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ]; /* reserved for future use       */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Client Identification Information                   */
  /****************************************************************************/
  char           execution_id[SQLM_IDENT_SZ]; /* login ID */
  char           corr_token[SQLM_APPLID_SZ];  /* DRDA AS Correlation Token    */
  unsigned long  client_pid;           /* Process ID of client application    */
  unsigned short client_platform;      /* Platform of client application      */
  unsigned short client_protocol;      /* Communications protocol of client   */
  unsigned short country_code;         /* Country code of client application  */
  char           pad2[2];              /* Padding for 4 byte alignment        */
}sqlm_applinfo;

/******************************************************************************/
/* DCS Application Identification Information                                 */
/******************************************************************************/

typedef struct sqlm_dcs_applinfo
{
  unsigned long  size;                       /* size of sqlm_dcs_applinfo     */
  _SQLOLDCHAR    info_type;                  /* collected information type    */
  _SQLOLDCHAR    pad[3];                     /* padding for 4 byte alignment  */
  unsigned long  agent_id;                   /* agent id                      */
  unsigned long  codepage_id;                /* codepage/CCSID at node        */
                                             /* where app started             */
  _SQLOLDCHAR    appl_name[SQLM_IDENT_SZ];   /* Application Program Name      */
  _SQLOLDCHAR    appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  _SQLOLDCHAR    sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  _SQLOLDCHAR    auth_id[SQLM_IDENT_SZ];     /* Authorization Id              */
  _SQLOLDCHAR    client_nname[SQLM_IDENT_SZ]; /* Config NNAME of client       */
  _SQLOLDCHAR    client_prdid[SQLM_IDENT_SZ]; /* product/version on client    */
  _SQLOLDCHAR    client_db_alias[SQLM_IDENT_SZ]; /* Client Database Alias     */
  _SQLOLDCHAR    db_name[SQLM_IDENT_SZ];     /* Host Database name            */
  _SQLOLDCHAR    host_prdid[SQLM_IDENT_SZ];  /* Host Product id               */
  _SQLOLDCHAR    outbound_appl_id[SQLM_APPLID_SZ];   /* Outbound LUWID        */
  _SQLOLDCHAR    outbound_sequence_no[SQLM_SEQ_SZ];  /* Outbound sequence #   */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ]; /* reserved for future use       */
}sqlm_dcs_applinfo;


/******************************************************************************/
/* DB2 Related Snapshot Information                                           */
/******************************************************************************/

typedef struct sqlm_db2
{
  unsigned long  size;                  /* size of sqlm_db2                   */
  _SQLOLDCHAR    info_type;             /* collected information type         */
  _SQLOLDCHAR    pad1[3];               /* padding for 4 byte alignment       */

  /****************************************************************************/
  /* Sorting Information                                                      */
  /****************************************************************************/
  unsigned long  sort_heap_allocated;   /* Sort heap currently allocated      */
  unsigned long  post_threshold_sorts;  /* # sorts started after heap         */
                                        /* threshold exceeded                 */
  unsigned long  piped_sorts_requested; /* # of piped sorts requested         */
                                        /* by RDS to SLS                      */
  unsigned long  piped_sorts_accepted;  /* # of piped sorts accepted by SLS   */

  /****************************************************************************/
  /* Timestamps                                                               */
  /****************************************************************************/
  sqlm_timestamp db2start_time;          /* DB2START timestamp                */
  sqlm_timestamp last_reset;             /* Date/Time of Last Reset           */

  /****************************************************************************/
  /* Connection Information                                                   */
  /****************************************************************************/
  unsigned long  rem_cons_in;           /* Remote connects to target DB2      */
  unsigned long  rem_cons_in_exec;      /* Remote connects to target exec DB2 */
  unsigned long  local_cons;            /* Current Local Connections          */
  unsigned long  local_cons_in_exec;    /* Local connects curr exec in DB2    */
  unsigned long  con_local_dbases;      /* Local databases w/current connects */
  unsigned long  agents_registered;     /* Number of agents registered in DB2 */
  unsigned long  agents_waiting_on_token;   /* # of agents waiting on a token */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  DB2 Instance Status                                 */
  /****************************************************************************/
  unsigned long  db2_status;            /* status of the DB2 instance         */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  High Water Marks                                    */
  /****************************************************************************/
  unsigned long  agents_registered_top; /* agents_registered high water mark  */
  unsigned long  agents_waiting_top;    /* agents_waiting high water mark     */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  DB2 Instance Memory Usage Information               */
  /****************************************************************************/
  unsigned long  comm_private_mem;      /* Committed Private Memory           */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Agent Information                                   */
  /****************************************************************************/
  unsigned long idle_agents;            /* number of unassigned agents in pool*/

}sqlm_db2;

/******************************************************************************/
/* Database Related Snapshot Information                                      */
/******************************************************************************/

typedef struct sqlm_dbase
{
  unsigned long  size;                  /* size of sqlm_dbase                 */
  _SQLOLDCHAR    info_type;             /* collected information type         */
  _SQLOLDCHAR    pad1[3];               /* padding for 4 byte alignment       */
  _SQLOLDCHAR    input_db_alias[SQLM_IDENT_SZ]; /* Input Database Alias       */
  _SQLOLDCHAR    db_name[SQLM_IDENT_SZ];        /* Database name              */
  _SQLOLDCHAR    db_path[SQLM_DBPATH_SZ];       /* Database Path              */

  /****************************************************************************/
  /* Locking Information                                                      */
  /****************************************************************************/
  unsigned long  locks_held;             /* Locks currently held              */
  unsigned long  lock_waits;             /* Lock waits since 1st connect      */
  unsigned long  lock_wait_time;         /* Total time dbase waited on locks  */
  unsigned long  lock_list_in_use;       /* total lock list memory in use     */
  unsigned long  deadlocks;              /* Deadlocks since 1st db connect    */
  unsigned long  lock_escals;            /* lock escals since 1st db connect  */
  unsigned long  x_lock_escals;          /* X lock escals since 1st db connect*/
  unsigned long  locks_waiting;          /* Appls. currently waiting on locks */

  /****************************************************************************/
  /* Sorting Information                                                      */
  /****************************************************************************/
  unsigned long  sort_heap_allocated;    /* Total sort heap allocated         */
  unsigned long  total_sorts;            /* number of sorts since 1st connect */
  unsigned long  total_sort_time;        /* elapsed time spent in sorts       */
  unsigned long  sort_overflows;         /* number of sort overflows          */
  unsigned long  active_sorts;           /* sorts currently active            */

  /****************************************************************************/
  /* Buffer Pool Information                                                  */
  /****************************************************************************/
  unsigned long  pool_data_l_reads;      /* pool data logical reads since conn*/
  unsigned long  pool_data_p_reads;      /* pool data reads since 1st connect */
  unsigned long  pool_data_writes;       /* pool data writes since 1st connect*/
  unsigned long  pool_index_l_reads;     /* pool indx logical reads since conn*/
  unsigned long  pool_index_p_reads;     /* pool indx reads since 1st connect */
  unsigned long  pool_index_writes;      /* pool indx writes since 1st connect*/
  unsigned long  pool_read_time;         /* Buff pool read time since 1st conn*/
  unsigned long  pool_write_time;        /* Buff pool write time since 1st con*/

  unsigned long  files_closed;           /* files closed since first db conn  */

  /****************************************************************************/
  /* SQL statement counts                                                     */
  /****************************************************************************/
  unsigned long  commit_sql_stmts;       /* # of Commit SQL stmts since conn  */
  unsigned long  rollback_sql_stmts;     /* # of Rollback SQL stmts since conn*/
  unsigned long  dynamic_sql_stmts;      /* # of Dynamic SQL stmts since conn */
  unsigned long  static_sql_stmts;       /* # of Static SQL stmts since conn  */
  unsigned long  failed_sql_stmts;       /* # of Failed SQL stmts since conn  */
  unsigned long  select_sql_stmts;       /* # of SQL select stmts since conn  */
  unsigned long  ddl_sql_stmts;          /* # of data definition lang. stmts  */
  unsigned long  uid_sql_stmts;          /* # of update/insert/delete stmts   */

  /****************************************************************************/
  /* Internal counts                                                          */
  /****************************************************************************/
  unsigned long  int_auto_rebinds;       /* # of Auto Rebinds since 1st conn  */
  unsigned long  int_rows_deleted;       /* # of Casc. Deletes since 1st conn */
  unsigned long  int_rows_updated;       /* # of Set Null Deletes since conn  */
  unsigned long  int_commits;            /* # of int. Commits since 1st conn  */
  unsigned long  int_rollbacks;          /* # of int. Rollbacks since 1st conn*/
  unsigned long  int_deadlock_rollbacks; /* # of Rollbacks due to deadlock    */
                                         /*      since 1st connect            */

  /****************************************************************************/
  /* Row counts                                                               */
  /****************************************************************************/
  unsigned long  rows_deleted;           /* # of Rows Deleted since connect   */
  unsigned long  rows_inserted;          /* # of Rows Inserted since connect  */
  unsigned long  rows_updated;           /* # of Rows Updated since connect   */
  unsigned long  rows_selected;          /* # of Rows Selected since connect  */

  /****************************************************************************/
  /* Binds/Precompiles                                                        */
  /****************************************************************************/
  unsigned long  binds_precompiles;      /* # of Binds/Precomps since 1st conn*/

  /****************************************************************************/
  /* Timestamps                                                               */
  /****************************************************************************/
  sqlm_timestamp  db_conn_time;           /* Time of 1st database connection  */
  sqlm_timestamp  last_reset;             /* Date/Time of Last Reset          */
  sqlm_timestamp  last_backup;            /* Date/Time of Last Backup         */

  /****************************************************************************/
  /* Application connection counters                                          */
  /****************************************************************************/
  unsigned long  total_cons;             /* Connects since 1st db connect     */
  unsigned long  appls_cur_cons;         /* Appls currently connected         */
  unsigned long  appls_in_db2;           /* Appls executing in the DB2        */

  /****************************************************************************/
  /* Logging Information                                                      */
  /****************************************************************************/
  unsigned long  sec_log_used_top;       /* Maximum secondary log space used  */
  unsigned long  tot_log_used_top;       /* Maximum total log space used      */
  unsigned long  sec_logs_allocated;     /* Number of secondary logs allocated*/

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Database Status                                     */
  /****************************************************************************/
  unsigned long  db_status;             /* status of the Database             */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  lock information                                    */
  /****************************************************************************/
  unsigned long  lock_timeouts;        /* # of lock timeouts since 1st conn   */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  High Water Marks                                    */
  /****************************************************************************/
  unsigned long  connections_top;  /* high water mark for current connections */
  unsigned long  db_heap_top;      /* high water mark for database heap       */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Buffer Pool and I/O Information                     */
  /****************************************************************************/
  unsigned long  pool_async_data_reads;    /* asynchronous pool data reads    */
  unsigned long  pool_async_data_writes;   /* asynchronous pool data writes   */
  unsigned long  pool_async_index_writes;  /* asynchronous pool index writes  */
  unsigned long  pool_async_read_time;     /* total async read time           */
  unsigned long  pool_async_write_time;    /* total async write time          */
  unsigned long  pool_async_data_read_reqs; /* # async read requests          */
  unsigned long  pool_lsn_gap_clns;        /* LSN Gap cleaner triggers        */
  unsigned long  pool_drty_pg_steal_clns;  /* dirty page steal cleaner trig.  */
  unsigned long  pool_drty_pg_thrsh_clns;  /* dirty list threshold cln trig.  */
  unsigned long  direct_reads;             /* direct reads since 1st connect  */
  unsigned long  direct_writes;            /* direct writes since 1st conn    */
  unsigned long  direct_read_reqs;         /* direct read requests            */
  unsigned long  direct_write_reqs;        /* direct write requests           */
  unsigned long  direct_read_time;         /* direct read time since 1st conn */
  unsigned long  direct_write_time;        /* direct write time since 1st conn*/

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Internal counts                                      */
  /****************************************************************************/
  unsigned long  int_rows_inserted;      /* # rows insrted for Trigger        */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Logging Information                                  */
  /****************************************************************************/
  unsigned long  log_reads;             /* # of log pages read since 1st conn */
  unsigned long  log_writes;            /* # of log pages read since 1st conn */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Package Cache Information                            */
  /****************************************************************************/
  unsigned long  pkg_cache_lookups;     /* # of section lookups               */
  unsigned long  pkg_cache_inserts;     /* # of sections inserted into cache  */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Catalog Cache Information                            */
  /****************************************************************************/
  unsigned long  cat_cache_lookups;     /* # of table descriptor lookups      */
  unsigned long  cat_cache_inserts;     /* # of table descriptors inserted    */
  unsigned long  cat_cache_overflows;   /* # of catalog cache overflows       */
  unsigned long  cat_cache_heap_full;   /* # of overflows due to db heap full */
}sqlm_dbase;

/******************************************************************************/
/* Application Related Snapshot Information                                   */
/******************************************************************************/

typedef struct sqlm_appl
{
  unsigned long  size;                  /* size of sqlm_appl                  */
  _SQLOLDCHAR    info_type;             /* collected information type         */
  _SQLOLDCHAR    pad1[3];               /* padding for 4 byte alignment       */

  /****************************************************************************/
  /* Identification Information                                               */
  /****************************************************************************/
  sqlm_appl_id_info   id_info;               /* identification information    */

  /****************************************************************************/
  /* Lock Information                                                         */
  /****************************************************************************/
  unsigned long  locks_held;             /* locks currently held by appl.     */
  unsigned long  lock_waits;             /* Lock waits since appl. connect    */
  unsigned long  lock_wait_time;         /* total time appl waited on locks   */
  unsigned long  lock_escals;            /* Lock Escalations since appl conn. */
  unsigned long  x_lock_escals;          /* X lock escals since appl connect  */
  unsigned long  deadlocks;              /* Deadlocks since appl. connect     */
  unsigned long  uow_lock_wait_time;     /* time UOW waited on locks          */
  unsigned long  agent_id_holding_lk;    /* agent id Holding Lock             */
  unsigned long  table_file_id;          /* id of table of lock waited on     */
  unsigned long  lock_mode;              /* Mode of Lock waited on            */
  unsigned long  lock_object_type;       /* Lock Obj type for lock waited on  */
  unsigned long  lock_object_name;       /* Waited On lock obj name           */
  sqlm_timestamp lock_wait_start_time;   /* Time when lock wait entered       */
  _SQLOLDCHAR    appl_id_holding_lk[SQLM_APPLID_SZ]; /* id of appl holding lk */
  _SQLOLDCHAR    sequence_no_holding_lk[SQLM_SEQ_SZ]; /* seq no. holding lock */


  /****************************************************************************/
  /* Sorting Information                                                      */
  /****************************************************************************/
  unsigned long  total_sorts;            /* Total Sorts since connect         */
  unsigned long  total_sort_time;        /* elapsed time spent in sorts       */
  unsigned long  sort_overflows;         /* number of sort overflows          */

  /****************************************************************************/
  /* Buffer Pool Information                                                  */
  /****************************************************************************/
  unsigned long  pool_data_l_reads;      /* pool data logical reads since conn*/
  unsigned long  pool_data_p_reads;      /* pool data reads since 1st connect */
  unsigned long  pool_data_writes;       /* pool data writes since 1st connect*/
  unsigned long  pool_index_l_reads;     /* pool indx logical reads since conn*/
  unsigned long  pool_index_p_reads;     /* pool indx reads since 1st connect */
  unsigned long  pool_index_writes;      /* pool indx writes since 1st connect*/
  unsigned long  pool_read_time;         /* Buff pool read time since 1st conn*/
  unsigned long  pool_write_time;        /* Buff pool write time since 1st con*/

  /****************************************************************************/
  /* SQL statement counts                                                     */
  /****************************************************************************/
  unsigned long  commit_sql_stmts;       /* # of Commit SQL stmts since conn  */
  unsigned long  rollback_sql_stmts;     /* # of Rollback SQL stmts since conn*/
  unsigned long  dynamic_sql_stmts;      /* # of Dynamic SQL stmts since conn */
  unsigned long  static_sql_stmts;       /* # of Static SQL stmts since conn  */
  unsigned long  failed_sql_stmts;       /* # of Failed SQL stmts since conn  */
  unsigned long  select_sql_stmts;       /* # of SQL select stmts since conn  */
  unsigned long  ddl_sql_stmts;          /* # of data definition lang. stmts  */
  unsigned long  uid_sql_stmts;          /* # of update/insert/delete stmts   */

  /****************************************************************************/
  /* Internal counts                                                          */
  /****************************************************************************/
  unsigned long  int_auto_rebinds;       /* # of Auto Rebinds since 1st conn  */
  unsigned long  int_rows_deleted;       /* # of Casc. Deletes since 1st conn */
  unsigned long  int_rows_updated;       /* # of Set Null Deletes since conn  */
  unsigned long  int_commits;            /* # of int. Commits since 1st conn  */
  unsigned long  int_rollbacks;          /* # of int. Rollbacks since 1st conn*/
  unsigned long  int_deadlock_rollbacks; /* # of Rollbacks due to deadlock    */
                                         /*      since 1st connect            */

  /****************************************************************************/
  /* Row counts                                                               */
  /****************************************************************************/
  unsigned long  rows_deleted;           /* # of Rows Deleted since connect   */
  unsigned long  rows_inserted;          /* # of Rows Inserted since connect  */
  unsigned long  rows_updated;           /* # of Rows Updated since connect   */
  unsigned long  rows_selected;          /* # of Rows Selected since connect  */

  /****************************************************************************/
  /* Binds/Precompiles                                                        */
  /****************************************************************************/
  unsigned long  binds_precompiles;      /* # of Binds/Precomps since 1st conn*/

  /****************************************************************************/
  /* SQL Statement Information                                                */
  /****************************************************************************/
  unsigned long  stmt_type;              /* type of stmt: Dynamic or static   */
  unsigned long  stmt_operation;         /* Statement Operation               */
  unsigned long  section_number;         /* Section Number                    */
  unsigned long  stmt_length;            /* length of SQL statement following */
  unsigned long  stmt_sorts;             /* number of sorts for this statement*/
  sqlm_timestamp stmt_start;             /* SQL statement operation start time*/
  sqlm_timestamp stmt_stop;              /* SQL statement operation stop time */
  _SQLOLDCHAR    cursor_name[SQLM_IDENT_SZ];  /* sql stmt.cursor name         */
  _SQLOLDCHAR    creator[SQLM_IDENT_SZ];      /* auth id for precompile       */
  _SQLOLDCHAR    package_name[SQLM_IDENT_SZ]; /* Package Name                 */

  /****************************************************************************/
  /* Unit-Of-Work Information                                                 */
  /****************************************************************************/
  unsigned long   uow_log_space_used;   /* Log space used in most recent UOW  */
  unsigned long   uow_comp_status;      /* previous uow completion status     */
  sqlm_timestamp  prev_uow_stop_time;   /* prev commit or rollback time       */
  sqlm_timestamp  uow_start_time;       /* time trans exec started            */
  sqlm_timestamp  uow_stop_time;        /* unit-of-work stop time             */

  /****************************************************************************/
  /* Remote cursor Information                                                */
  /****************************************************************************/
  unsigned long  open_rem_curs;         /* Currently open remote cursors      */
  unsigned long  open_rem_curs_blk;     /* Currently open remote cursors w/blk*/
  unsigned long  rej_curs_blk;          /* Rej block remote cursor requests   */
  unsigned long  acc_curs_blk;          /* Acc block remote cursor requests   */

  /****************************************************************************/
  /* Timestamps                                                               */
  /****************************************************************************/
  sqlm_timestamp  appl_con_time;        /* Connect start date/time            */
  sqlm_timestamp  conn_complete_time;   /* Connect complete date/time         */
  sqlm_timestamp  last_reset;           /* Last reset date and time           */

  /****************************************************************************/
  /* Communication Information                                                */
  /****************************************************************************/
  unsigned long  curr_comm_heap_size;   /* Communication heap currently alloc */
  unsigned long  max_comm_heap_size;    /* client comheapsz config parameter  */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Lock Wait Information                               */
  /****************************************************************************/
  char           table_name[SQLM_IDENT_SZ];      /* table name                */
  char           table_schema[SQLM_IDENT_SZ];    /* table schema              */
  char           tablespace_name[SQLM_IDENT_SZ]; /* name of the tablespace    */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  lock information                                    */
  /****************************************************************************/
  unsigned long  lock_timeouts;        /* number of lock timeouts since conn  */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Agent CPU times                                     */
  /****************************************************************************/
  sqlm_time      agent_usr_cpu_time;   /* total user CPU time of agent        */
  sqlm_time      agent_sys_cpu_time;   /* total system CPU time for agent     */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  SQL Statement CPU times                             */
  /****************************************************************************/
  sqlm_time      stmt_usr_cpu_time;    /* total user CPU time of SQL stmt     */
  sqlm_time      stmt_sys_cpu_time;    /* total system CPU time for SQL stmt  */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Internal counts                                     */
  /****************************************************************************/
  unsigned long  int_rows_inserted;      /* # rows insrted for Trigger        */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Row Counts                                          */
  /****************************************************************************/
  unsigned long  rows_read;              /* # rows read since connection      */
  unsigned long  rows_written;           /* # rows written since connetion    */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  I/O Information                                     */
  /****************************************************************************/
  unsigned long  direct_reads;             /* direct reads since connect      */
  unsigned long  direct_writes;            /* direct writes since connect     */
  unsigned long  direct_read_reqs;         /* direct read requests since conn */
  unsigned long  direct_write_reqs;        /* direct write requests since conn*/
  unsigned long  direct_read_time;         /* direct read time since connect  */
  unsigned long  direct_write_time;        /* direct write time since connect */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Local Cursor Information                            */
  /****************************************************************************/
  unsigned long  open_loc_curs;         /* Currently open local cursors       */
  unsigned long  open_loc_curs_blk;     /* Currently open local cursors w/blk */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Client Identification Information                   */
  /****************************************************************************/
  char           execution_id[SQLM_IDENT_SZ]; /* login ID                     */
  char           corr_token[SQLM_APPLID_SZ];  /* DRDA AS Correlation Token    */
  unsigned long  client_pid;           /* Process ID of client application    */
  unsigned short client_platform;      /* Platform of client application      */
  unsigned short client_protocol;      /* Communications protocol of client   */
  unsigned short country_code;         /* Country code of client application  */
  char           pad2[2];              /* Padding for 4 byte alignment        */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Package Cache Information                            */
  /****************************************************************************/
  unsigned long  pkg_cache_lookups;     /* # of section lookups               */
  unsigned long  pkg_cache_inserts;     /* # of sections inserted into cache  */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2 Catalog Cache Information                            */
  /****************************************************************************/
  unsigned long  cat_cache_lookups;     /* # of table descriptor lookups      */
  unsigned long  cat_cache_inserts;     /* # of table descriptors inserted    */
  unsigned long  cat_cache_overflows;   /* # of catalog cache overflows       */
  unsigned long  cat_cache_heap_full;   /* # of overflows due to db heap full */
}sqlm_appl;

/******************************************************************************/
/* Table Related Snapshot Information                                         */
/******************************************************************************/

typedef struct sqlm_table_header
{
  unsigned long  size;                   /* size of sqlm_table_header         */
  _SQLOLDCHAR    info_type;              /* collected information type        */
  _SQLOLDCHAR    pad1[3];                /* padding for 4 byte alignment      */
  unsigned long  num_tables;             /* # of sqlm_table struct returned   */
  sqlm_timestamp db_conn_time;           /* Time of 1st database connection   */
  sqlm_timestamp last_reset;             /* last reset date and time          */
  _SQLOLDCHAR    input_db_alias[SQLM_IDENT_SZ]; /* Input Database Alias       */
  _SQLOLDCHAR    db_name[SQLM_IDENT_SZ];        /* Database name              */
  _SQLOLDCHAR    db_path[SQLM_DBPATH_SZ];       /* Database Path              */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */
}sqlm_table_header;

typedef struct sqlm_table
{
  unsigned long  size;                    /* size of sqlm_table               */
  _SQLOLDCHAR    info_type;               /* collected information type       */
  _SQLOLDCHAR    pad1[3];                 /* padding for 4 byte alignment     */
  unsigned long  table_file_id;           /* the file ID for the table        */
  unsigned long  table_type;              /* table type                       */
  unsigned long  rows_written;            /* number of changes to the table   */
  unsigned long  rows_read;               /* number of reads from the table   */
  unsigned long  overflow_accesses;       /* no. of accesses to overflow rec  */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Table Identification                                */
  /****************************************************************************/
  char           table_name[SQLM_IDENT_SZ];   /* table name                   */
  char           table_schema[SQLM_IDENT_SZ]; /* table schema                 */
}sqlm_table;

/******************************************************************************/
/* lock related information                                                   */
/******************************************************************************/

typedef struct sqlm_dbase_lock
{
  unsigned long  size;                   /* size of sqlm_dbase_lock           */
  _SQLOLDCHAR    info_type;              /* collected information type        */
  _SQLOLDCHAR    pad[3];                 /* padding for 4 byte alignment      */
  unsigned long  locks_held;             /* number of locks currently held    */
  unsigned long  appls_cur_cons;         /* Appls currently connected         */
  unsigned long  num_appls;              /* # sqlm_appl_lock structs returned */
  unsigned long  locks_waiting;          /* Appls. currently waiting on locks */
  _SQLOLDCHAR    input_db_alias[SQLM_IDENT_SZ]; /* Input Database Alias       */
  _SQLOLDCHAR    db_name[SQLM_IDENT_SZ];        /* Database name              */
  _SQLOLDCHAR    db_path[SQLM_DBPATH_SZ];       /* Database Path              */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */
}sqlm_dbase_lock;

typedef struct sqlm_appl_lock
{
  unsigned long  size;                   /* size of sqlm_appl_lock            */
  _SQLOLDCHAR    info_type;              /* collected information type        */
  _SQLOLDCHAR    pad[3];                 /* padding for 4 byte alignment      */

  /****************************************************************************/
  /* Application Identification Information                                   */
  /****************************************************************************/
  unsigned long  agent_id;                 /* Agent Id                        */
  unsigned long  appl_status;              /* Application Status              */
  unsigned long  codepage_id;              /* codepage/CCSID at node          */
                                           /* where app started               */
  unsigned long  locks_held;               /* locks currently held by appl.   */
  unsigned long  num_locks;                /* # sqlm_lock structures returned */
  sqlm_timestamp status_change_time;       /* last appl status change time    */
  _SQLOLDCHAR    appl_id[SQLM_APPLID_SZ];  /* Application Id                  */
  _SQLOLDCHAR    sequence_no[SQLM_SEQ_SZ]; /* appl id sequence number         */
  _SQLOLDCHAR    appl_name[SQLM_IDENT_SZ]; /* Application Name                */
  _SQLOLDCHAR    auth_id[SQLM_IDENT_SZ];   /* Authorization Id                */
  _SQLOLDCHAR    client_db_alias[SQLM_IDENT_SZ]; /* Client Database Alias     */

  /****************************************************************************/
  /* Lock Waited On Information                                               */
  /****************************************************************************/
  unsigned long  agent_id_holding_lk;    /* Agent Id Holding Lock             */
  unsigned long  lock_object_name;       /* Lock Object Name                  */
  unsigned long  lock_object_type;       /* Lock Object Type                  */
  unsigned long  table_file_id;           /* the file ID for the table        */
  _SQLOLDCHAR    appl_id_holding_lk[SQLM_APPLID_SZ]; /* id of appl holding lk */
  _SQLOLDCHAR    sequence_no_holding_lk[SQLM_SEQ_SZ]; /* seq. no holding lk   */

  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Lock Wait Information                               */
  /****************************************************************************/
  char           table_name[SQLM_IDENT_SZ];       /* table name               */
  char           table_schema[SQLM_IDENT_SZ];     /* table schema             */
  char           tablespace_name[SQLM_IDENT_SZ];  /* name of the tablespace   */
}sqlm_appl_lock;

typedef struct sqlm_lock
{
  unsigned long  size;                   /* size of sqlm_lock                 */
  _SQLOLDCHAR    info_type;              /* collected information type        */
  _SQLOLDCHAR    pad[3];                 /* padding for 4 byte alignment      */
  unsigned long  table_file_id;          /* FID of table involved in lock     */
  unsigned long  lock_object_type;       /* lock object type: row, table      */
  unsigned long  lock_mode;              /* Lock mode                         */
  unsigned long  lock_status;            /* Lock status                       */
  unsigned long  lock_object_name;       /* Lock Object Name -                */
                                         /* RID or FID of lock obj            */
  _SQLOLDCHAR    reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */

  /****************************************************************************/
  /* SQLM_DBMON_VERSION2  Lock Information                                    */
  /****************************************************************************/
  char           table_name[SQLM_IDENT_SZ];       /* table name               */
  char           table_schema[SQLM_IDENT_SZ];     /* table schema             */
  char           tablespace_name[SQLM_IDENT_SZ];  /* name of the tablespace   */
}sqlm_lock;


/******************************************************************************/
/* Tablespace Related Snapshot Information                                    */
/******************************************************************************/
typedef struct sqlm_tablespace_header
{
  unsigned long  size;                   /* size of sqlm_tablespace_header    */
  char           info_type;              /* collected information type        */
  char           pad[3];                 /* padding for 4 byte alignment      */
  unsigned long  num_tablespaces;        /* # sqlm_tablespace structs returned*/
  sqlm_timestamp db_conn_time;           /* Time of 1st database connection   */
  sqlm_timestamp last_reset;             /* last reset date and time          */
  char           input_db_alias[SQLM_IDENT_SZ]; /* Input Database Alias       */
  char           db_name[SQLM_IDENT_SZ];        /* Database name              */
  char           db_path[SQLM_DBPATH_SZ];       /* Database Path              */

  char           reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */
}sqlm_tablespace_header;


typedef struct sqlm_tablespace
{
  unsigned long  size;                   /* size of sqlm_table                */
  char           info_type;              /* collected information type        */
  char           pad[3];                 /* padding for 4 byte alignment      */

  char           tablespace_name[SQLM_IDENT_SZ];  /* name of the tablespace   */

  unsigned long  pool_data_l_reads;      /* pool data logical reads since conn*/
  unsigned long  pool_data_p_reads;      /* pool data physical reads since con*/
  unsigned long  pool_async_data_reads;  /* asynchronous pool data reads      */
  unsigned long  pool_data_writes;       /* pool data writes since connect    */
  unsigned long  pool_async_data_writes; /* asynchronous pool data writes     */
  unsigned long  pool_index_l_reads;     /* pool index logical reads since con*/
  unsigned long  pool_index_p_reads;     /* pool index physical reads since cn*/
  unsigned long  pool_index_writes;      /* pool index writes since connect   */
  unsigned long  pool_async_index_writes; /* asynchronous pool index writes   */
  unsigned long  pool_read_time;         /* Buff pool read time since 1st conn*/
  unsigned long  pool_write_time;        /* Buff pool write time since 1st con*/
  unsigned long  pool_async_read_time;   /* asynchronous read time            */
  unsigned long  pool_async_write_time;  /* asynchronous write time           */
  unsigned long  pool_async_data_read_reqs; /* # async read requests          */

  unsigned long  direct_reads;           /* direct reads since 1st connect    */
  unsigned long  direct_writes;          /* direct writes since 1st conn      */
  unsigned long  direct_read_reqs;       /* direct read requests              */
  unsigned long  direct_write_reqs;      /* direct write requests             */
  unsigned long  direct_read_time;       /* direct read time since 1st conn   */
  unsigned long  direct_write_time;      /* direct write time since 1st conn  */

  unsigned long  files_closed;           /* files closed for tablespace       */

  char           reserved[SQLM_RESERVED_SZ];  /* reserved for future use      */
}sqlm_tablespace;



/******************************************************************************/
/* Database Monitor Event Monitor Data Structures                             */
/******************************************************************************/

/******************************************************************************/
/*  Event Monitor Log Header Record                                           */
/******************************************************************************/
typedef struct sqlm_event_log_header
{
  int            byte_order;                   /* Big Endian or Little Endian */
  unsigned long  size;                         /* Size of this record         */
  unsigned long  version;                      /* Event Monitor Version       */
  char           event_monitor_name[SQLM_IDENT_SZ];  /* Name of the Event Mon */
  unsigned short codepage_id;                  /* Code page of Database       */
  unsigned short country_code;                 /* Country Code of Database    */
  char           server_prdid[SQLM_IDENT_SZ];  /* Server Product Id           */
  char           server_instance_name[SQLM_IDENT_SZ]; /*instance name of DB2  */

}sqlm_event_log_header;

/******************************************************************************/
/* Event Monitor Record Header                                                */
/******************************************************************************/
typedef struct sqlm_event_rec_header {
  /*
     All event monitor event records have size and type as their first data
     elements.  These fields can be viewed as a 'header' that has to be read
     first to determine how to read the rest of the data.
     The record size for a given event type may vary between releases of DB2.
   */
   unsigned long size;               /* size of Event (size of entire struct) */
   unsigned long type;               /* type of Event                         */
} sqlm_event_rec_header;

/******************************************************************************/
/*  Event Monitor Database Event Record                                       */
/******************************************************************************/
typedef struct sqlm_db_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */

  /****************************************************************************/
  /* Locking Information                                                      */
  /****************************************************************************/
  unsigned long  lock_waits;             /* Lock waits                        */
  unsigned long  lock_wait_time;         /* Total time dbase waited on locks  */
  unsigned long  deadlocks;              /* Deadlocks                         */
  unsigned long  lock_escals;            /* lock escalations                  */
  unsigned long  x_lock_escals;          /* X lock escalations                */
  unsigned long  lock_timeouts;          /* Lock timeouts                     */

  /****************************************************************************/
  /* Sorting Information                                                      */
  /****************************************************************************/
  unsigned long  total_sorts;            /* number of sorts                   */
  unsigned long  total_sort_time;        /* elapsed time spent in sorts       */
  unsigned long  sort_overflows;         /* number of sort overflows          */

  /****************************************************************************/
  /* Buffer Pool and I/O Information                                          */
  /****************************************************************************/
  unsigned long  pool_data_l_reads;      /* pool data logical reads           */
  unsigned long  pool_data_p_reads;      /* pool data physical reads          */
  unsigned long  pool_async_data_reads;  /* asynchronous pool data reads      */
  unsigned long  pool_data_writes;       /* pool data writes                  */
  unsigned long  pool_async_data_writes; /* asynchronous pool data writes     */
  unsigned long  pool_index_l_reads;     /* pool index logical reads          */
  unsigned long  pool_index_p_reads;     /* pool index physicl reads          */
  unsigned long  pool_index_writes;      /* pool index page writes            */
  unsigned long  pool_async_index_writes; /* asynchronous pool index writes   */
  unsigned long  pool_read_time;         /* Buff pool read time               */
  unsigned long  pool_write_time;        /* Buff pool write time              */
  unsigned long  pool_async_read_time;   /* asynchronous read time            */
  unsigned long  pool_async_write_time;  /* asynchronous write time           */
  unsigned long  pool_async_data_read_reqs; /* # async read requests          */
  unsigned long  pool_lsn_gap_clns;      /* LSN Gap cleaner triggers          */
  unsigned long  pool_drty_pg_steal_clns;    /* dirty page steal cleaner trig.*/
  unsigned long  pool_drty_pg_thrsh_clns;    /* dirty list threshold cln trig.*/
  unsigned long  direct_reads;           /* direct reads                      */
  unsigned long  direct_writes;          /* direct writes                     */
  unsigned long  direct_read_reqs;       /* direct read requests              */
  unsigned long  direct_write_reqs;      /* direct write requests             */
  unsigned long  direct_read_time;       /* direct read time                  */
  unsigned long  direct_write_time;      /* direct write time                 */

  unsigned long  files_closed;           /* files closed                      */

  /****************************************************************************/
  /* SQL statement counts                                                     */
  /****************************************************************************/
  unsigned long  commit_sql_stmts;       /* # of Commit SQL statements        */
  unsigned long  rollback_sql_stmts;     /* # of Rollback SQL statements      */
  unsigned long  dynamic_sql_stmts;      /* # of Dynamic SQL statements       */
  unsigned long  static_sql_stmts;       /* # of Static SQL statements        */
  unsigned long  failed_sql_stmts;       /* # of Failed SQL statements        */
  unsigned long  select_sql_stmts;       /* # of SQL select statements        */
  unsigned long  ddl_sql_stmts;          /* # of data definition lang. stmts  */
  unsigned long  uid_sql_stmts;          /* # of update/insert/delete stmts   */

  /****************************************************************************/
  /* Internal counts                                                          */
  /****************************************************************************/
  unsigned long  int_auto_rebinds;       /* # of interanl auto rebinds        */
  unsigned long  int_rows_deleted;       /* # of internal rows deleted        */
  unsigned long  int_rows_updated;       /* # of internal rows updated        */
  unsigned long  int_rows_inserted;      /* # of internal rows inserted       */
  unsigned long  int_commits;            /* # of internal commits             */
  unsigned long  int_rollbacks;          /* # of internal rollbacks           */

  /****************************************************************************/
  /* Row counts                                                               */
  /****************************************************************************/
  unsigned long  rows_deleted;           /* # of Rows Deleted                 */
  unsigned long  rows_inserted;          /* # of Rows Inserted                */
  unsigned long  rows_updated;           /* # of Rows Updated                 */
  unsigned long  rows_selected;          /* # of Rows Selected                */

  /****************************************************************************/
  /* Binds/Precompiles                                                        */
  /****************************************************************************/
  unsigned long  binds_precompiles;      /* # of Binds/Precomps/Rebinds       */

  /****************************************************************************/
  /* Timestamps                                                               */
  /****************************************************************************/
  sqlm_timestamp disconn_time;            /* Time of last database disconnect */

  /****************************************************************************/
  /* Application connection counters                                          */
  /****************************************************************************/
  unsigned long  total_cons;             /* Total Connects                    */
  unsigned long  connections_top;        /* High water mark for connections   */

  /****************************************************************************/
  /* Database memory pool high water marks                                    */
  /****************************************************************************/
  unsigned long  db_heap_top;            /* High water mark for dbheap        */


  /****************************************************************************/
  /* Logging Information                                                      */
  /****************************************************************************/
  unsigned long  sec_log_used_top;       /* Maximum secondary log space used  */
  unsigned long  tot_log_used_top;       /* Maximum total log space used      */
  unsigned long  log_reads;              /* # of log pages read               */
  unsigned long  log_writes;             /* # of log pages written            */

  /****************************************************************************/
  /* Package Cache Information                                                */
  /****************************************************************************/
  unsigned long  pkg_cache_lookups;     /* # of section lookups               */
  unsigned long  pkg_cache_inserts;     /* # of sections inserted into cache  */

  /****************************************************************************/
  /* Catalog Cache Information                                                */
  /****************************************************************************/
  unsigned long  cat_cache_lookups;     /* # of table descriptor lookups      */
  unsigned long  cat_cache_inserts;     /* # of table descriptors inserted    */
  unsigned long  cat_cache_overflows;   /* # of catalog cache overflows       */
  unsigned long  cat_cache_heap_full;   /* # of overflows due to db heap full */

}sqlm_db_event;


/******************************************************************************/
/*  Event Monitor Connection Event Record                                     */
/******************************************************************************/
typedef struct sqlm_conn_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/

  /****************************************************************************/
  /* Locking Information                                                      */
  /****************************************************************************/
  unsigned long  lock_waits;             /* Lock waits since appl. connect    */
  unsigned long  lock_wait_time;         /* total time appl waited on locks   */
  unsigned long  lock_escals;            /* Lock Escalations since appl conn. */
  unsigned long  x_lock_escals;          /* X lock escals since appl connect  */
  unsigned long  deadlocks;              /* Deadlocks since appl. connect     */
  unsigned long  lock_timeouts;          /* Lock timeouts since 1st db connect*/

  /****************************************************************************/
  /* Sorting Information                                                      */
  /****************************************************************************/
  unsigned long  total_sorts;            /* Total Sorts since connect         */
  unsigned long  total_sort_time;        /* elapsed time spent in sorts       */
  unsigned long  sort_overflows;         /* number of sort overflows          */

  /****************************************************************************/
  /* Buffer Pool and I/O Information                                          */
  /****************************************************************************/
  unsigned long  pool_data_l_reads;      /* pool data logical reads since conn*/
  unsigned long  pool_data_p_reads;      /* pool data physical reads since con*/
  unsigned long  pool_data_writes;       /* pool data writes since 1st connect*/
  unsigned long  pool_index_l_reads;     /* pool indx logical reads since conn*/
  unsigned long  pool_index_p_reads;     /* pool indx physical reads since con*/
  unsigned long  pool_index_writes;      /* pool indx writes since 1st connect*/
  unsigned long  pool_read_time;         /* Buff pool read time since 1st conn*/
  unsigned long  pool_write_time;        /* Buff pool write time since 1st con*/
  unsigned long  direct_reads;           /* direct reads since connect        */
  unsigned long  direct_writes;          /* direct writes since connect       */
  unsigned long  direct_read_reqs;       /* direct read requests since conn   */
  unsigned long  direct_write_reqs;      /* direct write requests since conn  */
  unsigned long  direct_read_time;       /* direct read time since connect    */
  unsigned long  direct_write_time;      /* direct write time since connect   */

  /****************************************************************************/
  /* SQL statement counts                                                     */
  /****************************************************************************/
  unsigned long  commit_sql_stmts;       /* # of Commit SQL stmts since conn  */
  unsigned long  rollback_sql_stmts;     /* # of Rollback SQL stmts since conn*/
  unsigned long  dynamic_sql_stmts;      /* # of Dynamic SQL stmts since conn */
  unsigned long  static_sql_stmts;       /* # of Static SQL stmts since conn  */
  unsigned long  failed_sql_stmts;       /* # of Failed SQL stmts since conn  */
  unsigned long  select_sql_stmts;       /* # of SQL select stmts since conn  */
  unsigned long  ddl_sql_stmts;          /* # of data definition lang. stmts  */
  unsigned long  uid_sql_stmts;          /* # of update/insert/delete stmts   */

  /****************************************************************************/
  /* Internal counts                                                          */
  /****************************************************************************/
  unsigned long  int_auto_rebinds;       /* # of Auto Rebinds since connect   */
  unsigned long  int_rows_deleted;       /* # of internal deletes since conn  */
  unsigned long  int_rows_updated;       /* # of internal updates since conn  */
  unsigned long  int_rows_inserted;      /* # of internal inserts since conn  */
  unsigned long  int_commits;            /* # of int. Commits since 1st conn  */
  unsigned long  int_rollbacks;          /* # of int. Rollbacks since 1st conn*/
  unsigned long  int_deadlock_rollbacks; /* # of Rollbacks due to deadlock    */
                                         /*      since 1st connect            */

  /****************************************************************************/
  /* Row counts                                                               */
  /****************************************************************************/
  unsigned long  rows_deleted;           /* # of Rows Deleted since connect   */
  unsigned long  rows_inserted;          /* # of Rows Inserted since connect  */
  unsigned long  rows_updated;           /* # of Rows Updated since connect   */
  unsigned long  rows_selected;          /* # of Rows Selected since connect  */
  unsigned long  rows_read;              /* # of Rows read since connect      */
  unsigned long  rows_written;           /* # of Rows written since connect   */

  /****************************************************************************/
  /* Binds/Precompiles                                                        */
  /****************************************************************************/
  unsigned long  binds_precompiles;      /* # of Binds/Precomps/Rebinds       */

  /****************************************************************************/
  /* Blocking Cursor Information                                              */
  /****************************************************************************/
  unsigned long  rej_curs_blk;          /* Rejected block cursor requests     */
  unsigned long  acc_curs_blk;          /* Accepted block cursor requests     */

  /****************************************************************************/
  /* Timestamps                                                               */
  /****************************************************************************/
  sqlm_timestamp  disconn_time;         /* Disconnection  date/time           */

  /****************************************************************************/
  /* Agent activity                                                           */
  /****************************************************************************/
  sqlm_time       user_cpu_time;        /* Total user CPU time of agent       */
  sqlm_time       system_cpu_time;      /* Total system CPU time of agent     */

  /****************************************************************************/
  /* Package Cache Information                                                */
  /****************************************************************************/
  unsigned long  pkg_cache_lookups;     /* # of section lookups               */
  unsigned long  pkg_cache_inserts;     /* # of sections inserted into cache  */

  /****************************************************************************/
  /* Catalog Cache Information                                                */
  /****************************************************************************/
  unsigned long  cat_cache_overflows;   /* # of catalog cache overflows       */
  unsigned long  cat_cache_heap_full;   /* # of overflows due to db heap full */

}sqlm_conn_event;


/******************************************************************************/
/*  Event Monitor Table Event Record                                          */
/******************************************************************************/
typedef struct sqlm_table_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */
  char           table_name[SQLM_IDENT_SZ];     /* the name of the table      */
  char           table_schema[SQLM_IDENT_SZ];   /* the name of the table      */
  unsigned long  table_type;             /* table type                        */
  unsigned long  rows_written;           /* number of changes to the table    */
  unsigned long  rows_read;              /* number of reads from the table    */
  unsigned long  overflow_accesses;      /* no. of accesses to overflow rec   */
  sqlm_timestamp table_event_time;       /* Table Event Date and Time         */

}sqlm_table_event;


/******************************************************************************/
/*  Event Monitor Statment and Statment Text Event Records                    */
/******************************************************************************/
typedef struct sqlm_stmt_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  unsigned long  stmt_type;              /* type of stmt: Dynamic or static   */
  unsigned long  operation;              /* Statement Operation               */
  unsigned long  fetch_count;            /* Count of fetches                  */
  unsigned long  section_number;         /* Section Number                    */
  sqlm_timestamp start_time;             /* SQL statement operation start time*/
  sqlm_timestamp stop_time;              /* SQL statement operation stop time */
  char           cursor_name[SQLM_IDENT_SZ];  /* sql stmt.cursor name         */
  char           creator[SQLM_IDENT_SZ];      /* auth id for precompile       */
  char           package_name[SQLM_IDENT_SZ]; /* Package Name                 */
  sqlm_time      user_cpu_time;         /* Total user CPU time of statement   */
  sqlm_time      system_cpu_time;       /* Total system CPU time of statement */
  unsigned long  total_sorts;           /* Total number of sorts for this stmt*/
  unsigned long  total_sort_time;       /* Total sort time for this statement */
  unsigned long  sort_overflows;        /* # of sort overflows for this stmt  */
  unsigned long  rows_read;             /* # of rows read by this statement   */
  unsigned long  rows_written;          /* # of rows upd/ins/del for this stmt*/
  unsigned long  int_rows_deleted;      /* # of internal deletes by the stmt  */
  unsigned long  int_rows_updated;      /* # of internal updates by the stmt  */
  unsigned long  int_rows_inserted;     /* # of internal inserts by the stmt  */
  struct sqlca   sqlca;                 /* sqlca from statement               */

}sqlm_stmt_event;

typedef struct sqlm_stmttext_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  char           creator[SQLM_IDENT_SZ];      /* auth id for precompile       */
  char           package_name[SQLM_IDENT_SZ]; /* Package Name                 */
  unsigned long  section_number;         /* Section Number                    */
  unsigned long  stmt_length;           /* length of SQL statement following  */
  char           stmt_text[1];          /* dynamic sql statement text         */


}sqlm_stmttext_event;


/******************************************************************************/
/*  Event Monitor Transaction Event Record                                    */
/******************************************************************************/
typedef struct sqlm_xaction_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;                 /* event type identifier         */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  unsigned long  log_space_used;        /* Log space used in transaction      */
  unsigned long  status;                /* transaction completion status      */
  unsigned long  lock_wait_time;        /* transaction lock wait time         */
  unsigned long  locks_held_top;        /* max locks held in transaction      */
  unsigned long  lock_escals;           /* # of lock escalation in transaction*/
  unsigned long  x_lock_escals;         /* # of x lock escals in transaction  */
  unsigned long  rows_read;             /* # of rows read by this transaction */
  unsigned long  rows_written;          /* # of rows upd/ins/del for this xact*/
  sqlm_time      user_cpu_time;         /* Total user CPU time of transaction */
  sqlm_time      system_cpu_time;       /* Total system CPU time of xaction   */
  sqlm_timestamp prev_stop_time;        /* prev commit or rollback time       */
  sqlm_timestamp start_time;            /* time trans exec started            */
  sqlm_timestamp stop_time;             /* trans stop time                    */

}sqlm_xaction_event;


/******************************************************************************/
/*  Event Monitor Deadlock and Deadlocked Connection Event Records            */
/******************************************************************************/
typedef struct sqlm_deadlock_event
{
  unsigned long  size;                       /* event record size             */
  unsigned long  event_type;                 /* event type identifier         */
  unsigned long  dl_conns;                   /* number of conns deadlocked    */
  sqlm_timestamp start_time;                 /* Time when deadlock detected   */

}sqlm_deadlock_event;


typedef struct sqlm_dlconn_event
{
  unsigned long  size;                       /* event record size             */
  unsigned long  event_type;                 /* event type identifier         */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  char           appl_id_holding_lk[SQLM_APPLID_SZ];  /* id of appl holding lk */
  char           sequence_no_holding_lk[SQLM_SEQ_SZ]; /* seq no. holding lock */
  char           table_name[SQLM_IDENT_SZ];   /* name of tb of lock waited on */
  char           table_schema[SQLM_IDENT_SZ]; /* table schema of lk waited on */
  char           tablespace_name[SQLM_IDENT_SZ];  /* name of the tablespace   */
  unsigned long  lock_mode;              /* Mode of Lock waited on            */
  unsigned long  lock_object_type;       /* Lock Obj type for lock waited on  */
  unsigned long  lock_object_name;       /* Waited On lock obj name           */
  sqlm_timestamp lock_wait_start_time;   /* Time when lock wait started       */
  sqlm_timestamp start_time;             /* Time when deadlock detected       */

}sqlm_dlconn_event;


/******************************************************************************/
/*  Event Monitor Tablespace Event Record                                     */
/******************************************************************************/
typedef struct sqlm_tablespace_event
{
  unsigned long  size;                   /* event record size                 */
  unsigned long  event_type;             /* event type identifier             */

  char           tablespace_name[SQLM_IDENT_SZ];  /* name of tablespace       */
  unsigned long  pool_data_l_reads;      /* pool data logical reads since conn*/
  unsigned long  pool_data_p_reads;      /* pool data physical reads since con*/
  unsigned long  pool_async_data_reads;  /* asynchronous pool data reads      */
  unsigned long  pool_data_writes;       /* pool data writes since connect    */
  unsigned long  pool_async_data_writes; /* asynchronous pool data writes     */
  unsigned long  pool_index_l_reads;     /* pool index logical reads since con*/
  unsigned long  pool_index_p_reads;     /* pool index physical reads since cn*/
  unsigned long  pool_index_writes;      /* pool index writes since connect   */
  unsigned long  pool_async_index_writes; /* asynchronous pool index writes   */
  unsigned long  pool_read_time;         /* Buff pool read time since 1st conn*/
  unsigned long  pool_write_time;        /* Buff pool write time since 1st con*/
  unsigned long  pool_async_read_time;   /* asynchronous read time            */
  unsigned long  pool_async_write_time;  /* asynchronous write time           */
  unsigned long  pool_async_data_read_reqs; /* # async read requests          */

  unsigned long  direct_reads;           /* direct reads since 1st connect    */
  unsigned long  direct_writes;          /* direct writes since 1st conn      */
  unsigned long  direct_read_reqs;       /* direct read requests              */
  unsigned long  direct_write_reqs;      /* direct write requests             */
  unsigned long  direct_read_time;       /* direct read time since 1st conn   */
  unsigned long  direct_write_time;      /* direct write time since 1st conn  */

  unsigned long  files_closed;           /* files closed since first db conn  */
  sqlm_timestamp ts_event_time;          /* Tablespace event date and time    */

}sqlm_tablespace_event;


/******************************************************************************/
/*  Event Monitor Database Header Event Record                                */
/******************************************************************************/
typedef struct sqlm_dbheader_event
{
  unsigned long  size;                    /* event record size                */
  unsigned long  event_type;              /* event type identifier            */
  char           db_name[SQLM_IDENT_SZ];  /* Database name                    */
  char           db_path[SQLM_DBPATH_SZ]; /* Database Path                    */
  sqlm_timestamp conn_time;               /* Time of 1st database connection  */

}sqlm_dbheader_event;



/******************************************************************************/
/*  Event Monitor Start Event Record                                          */
/******************************************************************************/
typedef struct sqlm_evmon_start_event
{
  unsigned long  size;                    /* event record size                */
  unsigned long  event_type;              /* event type identifier            */
  sqlm_timestamp start_time;              /* Time event monitor started       */

} sqlm_evmon_start_event;


/******************************************************************************/
/*  Event Monitor Connection Header Event Record                              */
/******************************************************************************/
typedef struct sqlm_connheader_event
{
  unsigned long  size;                       /* event record size             */
  unsigned long  event_type;                 /* event type identifier         */
  char           appl_id[SQLM_APPLID_SZ];    /* Application Id                */
  char           sequence_no[SQLM_SEQ_SZ];   /* application id sequence number*/
  char           corr_token[SQLM_APPLID_SZ]; /* DRDA AS Correlation Token     */
  char           appl_name[SQLM_IDENT_SZ];   /* Application Program Name      */
  char           auth_id[SQLM_IDENT_SZ];     /* Authorization Id              */
  char           execution_id[SQLM_IDENT_SZ]; /* Login ID                     */
  char           client_nname[SQLM_IDENT_SZ]; /* Config NNAME of client       */
  char           client_prdid[SQLM_IDENT_SZ]; /* product/version on client    */
  char           client_db_alias[SQLM_IDENT_SZ]; /* Client Database Alias     */
  long           client_pid;                 /* PID of client                 */
  long           agent_id;                   /* agent id                      */
  unsigned short codepage_id;                /* codepage at client node       */
  unsigned short country_code;               /* country code of client app    */
  unsigned short client_platform;            /* platform of client app        */
  unsigned short client_protocol;            /* Comms protocol of client      */
  sqlm_timestamp conn_time;                  /* Connect start date/time       */

} sqlm_connheader_event;


/******************************************************************************/
/*  Event Monitor Overflow Event Record                                       */
/******************************************************************************/
typedef struct sqlm_overflow_event
{
  unsigned long  size;                       /* event record size             */
  unsigned long  event_type;                 /* event type identifier         */
  unsigned long  count;                      /* The number of overflows       */
  sqlm_timestamp first_overflow_time;        /* The time of the first overflow*/
  sqlm_timestamp last_overflow_time;         /* The time of the last overflow */

} sqlm_overflow_event;


/******************************************************************************/
/* data structure sizes                                                       */
/* DON'T USE THESE CONSTANTS. THEY ARE PROVIDED FOR COMPATIBILITY ONLY        */
/******************************************************************************/

#define SQLM_APPLINFO_SZ        492    /* size of old sqlm_applinfo struct    */
#define SQLM_DB2_SZ             100    /* size of old sqlm_db2 structure      */
#define SQLM_DBASE_SZ           548    /* size of old sqlm_dbase structure    */
#define SQLM_TABLE_HEADER_SZ    356    /* size of old sqlm_table_header struct*/
#define SQLM_TABLE_SZ           60     /* size of old sqlm_table structure    */
#define SQLM_APPL_SZ            880    /* size of old sqlm_appl structure     */
#define SQLM_DBASE_LOCK_SZ      352    /* size of old sqlm_dbase_lock struct  */
#define SQLM_APPL_LOCK_SZ       216    /* size of old sqlm_appl_lock struct   */
#define SQLM_LOCK_SZ            60     /* size of old sqlm_lock structure     */
#define SQLM_COLLECTED_SZ       232    /* size of old sqlm_collected structure*/
#define SQLM_DCS_APPLINFO_SZ    260    /* size of old sqlm_dcs_applinfo struct*/

#define SQLM_TIMESTAMP_SZ       sizeof(sqlm_timestamp)


/******************************************************************************/
/* Database Monitor APIs                                                      */
/******************************************************************************/

/* Database Monitor Switch API */
int SQL_API_FN sqlmon(unsigned long        version,       /* Version Id       */
                      _SQLOLDCHAR          *reserved,     /* reserved         */
                      sqlm_recording_group group_states[],
                                      /* monitor switches and current states  */
                      struct sqlca         *sqlca         /* sqlca            */
                     );

/* Database Monitor Snapshot API */
int SQL_API_FN sqlmonss(unsigned long     version,        /* Version id       */
                        _SQLOLDCHAR       *reserved,      /* reserved         */
                        sqlma             *sqlma_ptr,     /* monitoring area  */
                        unsigned long     buffer_length,  /* buffer length    */
                        void              *buffer_area,   /* buffer area      */
                        sqlm_collected    *collected,     /* num collected    */
                        struct sqlca      *sqlca          /* sqlca            */
                       );

/* Estimate the buffer size that user need to allocate */
int SQL_API_FN sqlmonsz(unsigned long         version,    /* Version id       */
                        _SQLOLDCHAR           *reserved,  /* reserved         */
                        sqlma                 *sqlma_ptr, /* sqlma pointer    */
                        unsigned long         *buff_size, /* est. buffer sz   */
                        struct sqlca          *sqlca      /* sqlca structure  */
                       );

/* Reset Database Monitor */
int SQL_API_FN sqlmrset(unsigned long          version,   /* Version Id       */
                        _SQLOLDCHAR            *reserved, /* reserved         */
                        unsigned long          reset_all, /* reset db or all  */
                        _SQLOLDCHAR            *db_alias, /* ptr to db_alias  */
                        struct sqlca           *sqlca     /* sqlca            */
                       );


/******************************************************************************/
/* Database Monitor Generic APIs                                              */
/******************************************************************************/

/* Generic Database Monitor Switch API  */
int SQL_API_FN sqlgmon
   (
     unsigned long          reserved_lgth,   /* length of reserved field      */
     struct   sqlca         *sqlca,          /* pointer to sqlca              */
     sqlm_recording_group   group_states[],  /* ptr to returned states        */

     _SQLOLDCHAR            *reserved,       /* reserved for future use       */
     unsigned long          version          /* Version id                    */
   );


/* Generic Database Monitor Snapshot API */
int SQL_API_FN sqlgmnss
   (
     unsigned long           reserved_lgth,  /* length of reserved field      */
     struct   sqlca          *sqlca,         /* pointer to sqlca              */
     sqlm_collected          *collected,     /* pointer to # collected        */
     void                    *buffer_area,   /* pointer to buffer area        */
     unsigned long           buffer_length,  /* length of buffer              */
     sqlma                   *sqlma_ptr,     /* pointer to monitor area       */
     _SQLOLDCHAR             *reserved,      /* reserved for future use       */
     unsigned long           version         /* Version id                    */
   );


/* Generic Database Monitor Estimate Buffer Size API */
int SQL_API_FN sqlgmnsz
   (
     unsigned long           reserved_lgth,  /* length of reserved field      */
     struct   sqlca          *sqlca,         /* pointer to sqlca              */
     unsigned long           *buff_size,     /* length of buffer              */
     sqlma                   *sqlma_ptr,     /* pointer to sqlma              */
     _SQLOLDCHAR             *reserved,      /* reserved for future use       */
     unsigned long           version         /* Version id                    */
   );



/* Generic Database Monitor Reset API */
int SQL_API_FN sqlgmrst
   (
     unsigned short           dbnamel,       /* length of database            */
     unsigned long            reserved_lgth, /* length of reserved field      */
     struct   sqlca           *sqlca,        /* pointer to sqlca              */
     _SQLOLDCHAR              *db_alias,     /* database alias                */
     unsigned long            reset_all,     /* reset db or all info          */
     _SQLOLDCHAR              *reserved,     /* reserved for future use       */
     unsigned long            version        /* Version id                    */
   );

#if (defined(DB2OS2) || defined(DB2NT) || defined(DB2WIN))
#pragma pack()
#elif (defined(DB2MAC))
#pragma align
#elif (defined(DB2HP) || defined(DB2SNI))

#elif (defined(DB2AIX) || defined(DB2SUN))
#pragma options align=reset
#endif

#ifdef __cplusplus
}
#endif

#endif  /* SQL_H_SQLMON */
