/*******************************************************************************
**
** Source File Name = dbconf.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**       This program is an example of how APIs are implemented in order to
**       CREATE a DATABASE and then GET the CONFIGURATION information from
**       it, then UPDATE the CONFIGURATION, RESET the CONFIGURATION, then
**       DROP the DATABASE.
**       This program only can only be run locally.
**       It can not be run on a remote node.
**
**    APIs USED :
**       CREATE DATABASE                  sqledbcr()
**       DROP DATABASE                    sqledrpd()
**       GET DATABASE CONFIGURATION       sqlfxdb()
**       UPDATE DATABASE CONFIGURATION    sqlfudb()
**       RESET DATABASE CONFIGURATION     sqlfrdb()
**
**
**    STRUCTURES USED :
**       sqledbcinfo
**       sqlfupd
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       'C' COMPILER LIBRARY :
**          stdio.h  -  printf
**
**       internal :
**          print_info :      Displays a directory of databases
**          alloc_mem :       Allocates the proper amount of memory for the
**                            GET DATABASE CONFIGURATION API to fill with
**                            data.
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.C]          related information available.
**                               This procedure is located in the UTIL.C file.
**
**
**    EXTERNAL DEPENDENCIES :
**       - Existing database for precompile purposes.
**       - Precompile with the SQL precompiler (PREP in DB2)
**       - Binding to a database (BIND in DB2)
**       - Compiling and linking with the IBM Cset++ compiler (AIX and OS/2)
**         or the Microsoft Visual C++ compiler (Windows) 
**         or the compiler supported on your platform.
**       - a database by the name of "DBCONF" does not exist.
**
*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sqlutil.h>
#include <sqlenv.h>
#include "util.h"

#define  CHECKERR(CE_STR)   if (check_error (CE_STR, &sqlca) != 0) return 1;
#define  LISTNUMBER 4
#define  MAXLENGTH 242

int alloc_mem (struct sqlfupd *);
int print_info (struct sqlfupd *);

int main (void) {
   struct sqlfupd itemList[LISTNUMBER];
   struct sqlca sqlca;
   struct sqledbdesc db_desc;
   struct sqledbcountryinfo dbCountry;


   strcpy(db_desc.sqldbdid, SQLE_DBDESC_2);
   db_desc.sqldbccp = 0;
   db_desc.sqldbcss = 0;
   db_desc.sqldbsgp = 0;
   db_desc.sqldbnsg = 10;
   db_desc.sqltsext = -1;
   db_desc.sqlcatts = NULL;
   db_desc.sqlusrts = NULL;
   db_desc.sqltmpts = NULL;


   strncpy(dbCountry.sqldbcodeset, "IBM-850",9);
   strncpy(dbCountry.sqldblocale, "En_US",6);

   printf ("CREATing the temporary database DBCONF...\n");
   printf ("please wait... this will take a while...\n");
   /****************************\
   * CREATE DATABASE API called *
   \****************************/
   sqlecrea ("DBCONF", "DBCONF", "", &db_desc, &dbCountry, '\0', NULL, &sqlca);
   CHECKERR("creating the database");
   printf ("database DBCONF created\n");

   alloc_mem (itemList);

   printf ("getting the database configuration for DBCONF\n");
   /***************************************\
   * GET DATABASE CONFIGURATION API called *
   \***************************************/
   sqlfxdb ("DBCONF", LISTNUMBER, itemList, &sqlca);
   CHECKERR("get database config");

   printf ("listing the database configuration\n");
   print_info (itemList);

   /* Altering the default Database Configuration */
   *(short *)itemList[0].ptrvalue = 4;
   *(int *)itemList[1].ptrvalue = 2000;
   *(short *)itemList[2].ptrvalue = 3;
   *(short *)itemList[3].ptrvalue = 1;

   printf ("UPDATing the database configuration\n");
   /******************************************\
   * UPDATE DATABASE CONFIGURATION API called *
   \******************************************/
   sqlfudb("DBCONF", LISTNUMBER, itemList, &sqlca);
   CHECKERR("updating the database configuration");

   /***************************************\
   * GET DATABASE CONFIGURATION API called *
   \***************************************/
   sqlfxdb ("DBCONF", LISTNUMBER, itemList, &sqlca);
   CHECKERR("get database config");

   printf ("listing the UPDATEd database configuration\n");
   print_info (itemList);

   printf ("RESETting the database configuration\n");
   /*****************************************\
   * RESET DATABASE CONFIGURATION API called *
   \*****************************************/
   sqlfrdb("DBCONF", &sqlca);

   /***************************************\
   * GET DATABASE CONFIGURATION API called *
   \***************************************/
   sqlfxdb ("DBCONF", LISTNUMBER, itemList, &sqlca);
   CHECKERR("get database config");

   printf ("printing the database configuration after the RESET\n");
   print_info (itemList);

   printf ("DROPping the database DBCONF\n");
   /**************************\
   * DROP DATABASE API called *
   \**************************/
   sqledrpd ("DBCONF", &sqlca);
   CHECKERR("dropping the database");

   return 0;
}

/*******************************************************************************
* this procedure allocates the required memory to each section of the array.
* Each member of the array must be appointed to a specific field in regards
* to the output of the GET DATABASE CONFIGURATION API call
*******************************************************************************/
int alloc_mem (struct sqlfupd *itemList) {
   itemList[0].token = SQLF_DBTN_LOCKLIST;
   itemList[0].ptrvalue = (char *)malloc(sizeof(short));

   itemList[1].token = SQLF_DBTN_BUFF_PAGE;
   itemList[1].ptrvalue = (char *)malloc(sizeof(int));

   itemList[2].token = SQLF_DBTN_MAXFILOP;
   itemList[2].ptrvalue = (char *)malloc(sizeof(short));

   itemList[3].token = SQLF_DBTN_SOFTMAX;
   itemList[3].ptrvalue = (char *)malloc(sizeof(short));

   return 0;
}

int print_info (struct sqlfupd *itemList) {
   printf ("Max. storage for lost lists (4kb)             : %d\n",
      *(short *)itemList[0].ptrvalue);
   printf ("Buffer pool size (4kb)                        : %d\n",
      *(int *)itemList[1].ptrvalue);
   printf ("Max. DB files open per appl.                  : %d\n",
      *(short *)itemList[2].ptrvalue);
   printf ("percent log reclaimed before soft checkpoint  : %d\n",
      *(short *)itemList[3].ptrvalue);
   printf ("\n");

   return 0;
}
