/*******************************************************************************
**
** Source File Name = dbinst.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**       an example showing how to use DATABASE INSTANCE APIs in order to:
**          - Attach to an instance
**          - Retrieve the instance
**          - Detach from the instance.
**
**    APIs USED :
**       ATTACH TO INSTANCE               sqleatin
**       GET INSTANCE                     sqlegins
**       DETACH FROM INSTANCE             sqledtin
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS DECLARED :
**       'C' COMPILER LIBRARY :
**          stdio.h  -  printf
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.C]          related information available.
**                               This procedure is located in the UTIL.C file.
**
**    EXTERNAL DEPENDENCIES :
**       - Existing database for precompile purposes.
**       - Precompile with the SQL precompiler (PREP in DB2)
**       - Binding to a database (BIND in DB2)
**       - Compiling and linking with the IBM Cset++ compiler (AIX and OS/2)
**         or the Microsoft Visual C++ compiler (Windows) 
**         or the compiler supported on your platform.
**
*******************************************************************************/

/*--> SQLB0X08.C */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sqlenv.h>
#include "util.h"

#ifdef DB268K
/* Need to include ASLM for 68K applications */
#include <LibraryManager.h>
#endif

/*<-- */

#define  CHECKERR(CE_STR)   if (check_error (CE_STR, &sqlca) != 0) return 1;
/*--> */
int main (int argc, char *argv[]) {
   struct sqlca sqlca;
   char instName[SQL_INSTNAME_SZ + 1];
/*<-- */

#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initial the Library Manager */
	InitLibraryManager(0,kCurrentZone,kNormalMemory);
	atexit(CleanupLibraryManager);
#endif

   /*********************************************
      the first argument is the instance name
      the second argument is the user name
      the thirs argument is the password
   *********************************************/
   if (argc != 4) {
      printf ("\nUSAGE: dbinst instance_name user_name password\n\n");
      return 1;
   }

   printf ("sample program : dbinst.c\n");

   printf ("ATTACHed TO INSTANCE API called for instance :%s:\n", argv[1]);
/*--> */
   /*******************************\
   * ATTACH TO INSTANCE API called *
   \*******************************/
   sqleatin (argv[1], argv[2], argv[3], &sqlca);
/*<-- */
   CHECKERR ("attach to instance");

   printf ("GET INSTANCE API called\n");
/*--> */
   /*************************\
   * GET INSTANCE API called *
   \*************************/
   sqlegins (instName, &sqlca);
/*<-- */
   CHECKERR ("get instance name");
   printf ("current instance = :%.*s:\n", SQL_INSTNAME_SZ, instName);

   printf ("DETACHed FROM INSTANCE API called\n", instName);
/*--> */
   /*********************************\
   * DETACH FROM INSTANCE API called *
   \*********************************/
   sqledtin (&sqlca);
/*<-- */
   CHECKERR ("detach from instance");

   return 0;
}
/* end of program : dbinst.c */
