/*******************************************************************************
**
** Source File Name = dbstart.c  %I% 
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**  PURPOSE : to start a database manager
**
**    APIs USED :
**       START DATABASE MANAGER             sqlestar
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.C]          related information available.
**                               This procedure is located in the UTIL.C file.
**
**    EXTERNAL DEPENDENCIES :
**       - Existing database for precompile purposes.
**       - Precompile with the SQL precompiler (PREP in DB2)
**       - Binding to a database (BIND in DB2)
**       - Compiling and linking with the IBM Cset++ compiler (AIX and OS/2)
**         or the Microsoft Visual C++ compiler (Windows) 
**         or the compiler supported on your platform.
**
*******************************************************************************/
/*--> SQLB0X32.C */
#include <sqlenv.h>
#include <sqlca.h>
#include "util.h"
/*<-- */

#define  CHECKERR(CE_STR)   if (check_error (CE_STR, &sqlca) != 0);

int main (int argc, char *argv[]) {
   struct sqlca sqlca;
/*--> */
   int rc;
   /***********************************\
   * START DATABASE MANAGER API called *
   \***********************************/
   rc = sqlestar ();
/*<-- */
   if (rc != SQL_RC_OK)  { 
      if (rc == SQLE_RC_INVSTRT) 
         printf ("The database manager is already active.\n");
      return 0;
#ifdef DB2AIX
   } else {
      CHECKERR ("START DATABASE MANAGER");
      if (sqlca.sqlcode > 0) {
         printf ("Warning ONLY.  DATABASE has been STARTED\n");
         return 1;
      } else if (sqlca.sqlcode < 0) {
         printf ("ERROR.  DATABASE has NOT been STARTED\n");
         return 1;
      } /* endif */
#endif
   } /* endif */

   printf ("The database has been successfully STARTED\n");
   return 0;
}
