/*******************************************************************************
**
** Source File Name = monreset.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE : to demonstrate the use the RESET DATABASE SYSTEM MONITOR DATA
**           AREAS.
** The following illustrates how to issue a snapshot and process the output.
** It prints database lock snapshots. Printing routines for other
** request types are left to the reader to complete as an exercise...
**
** EXTERNAL FUNCTIONS USED IN CODE SAMPLE:
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.C]          related information available.
**
**    EXTERNAL DEPENDENCIES :
**       - Existing database for precompile purposes.
**       - Precompile with the SQL precompiler (PREP in DB2)
**       - Binding to a database (BIND in DB2)
**       - Compiling and linking with the IBM Cset++ compiler (AIX and OS/2)
**         or the Microsoft Visual C++ compiler (Windows) 
**         or the compiler supported on your platform.
**
*******************************************************************************/
/*******************************************************************************
    Database Monitor Reset API

#include "sqlmon.h"
#include "sqlca.h"
#include "util.h"
int SQL_API_FN sqlmrset(unsigned long          version,
                        char                   *reserved,
                        unsigned long          reset_all,
                        char                   *db_alias,
                        struct sqlca           *sqlca
                       );

This function calls resets to 0, all *resettable* data items *for the
aplication performing the call*. (Note: In Version 1, Reset would affect
the data for all monitoring applications, this is no longer the case.)

INPUT:

    reset_all:    1   -     Reset monitor data for all databases,
                            and also the database manager level data.
                  0   -     Only reset data for the database 'db_alias'.

    db_alias:     NULL terminated string, the alias of the database to
                  reset.  Ignored if reset_all = 1.

OUTPUT:
    sqlca:        Indicates whether or not the call was successful.

*******************************************************************************/
/*--> SQLB0X19.C */
#include <stdio.h>
#include "sqlca.h"
#include "sqlutil.h"
#include "sqlmon.h"
/*<-- */

#define CHECKERR(CE_STR)    if (check_error (CE_STR, &sqlca) !=0) return 1;

/* Reset monitored data for a single database */
int main(int argc, char* argv[]) {

    if (argc!=2) printf("\nreset: Reset Database Monitor Data for a "
        "database.\n\tusage: monreset dbname\n");
    else {
        struct sqlca sqlca;
/*--> */
        /*****************************************************\
        * RESET DATABASE SYSTEM MONITOR DATA AREAS API called *
        \*****************************************************/
        sqlmrset(SQLM_DBMON_VERSION2, NULL, SQLM_OFF, argv[1], &sqlca);
/*<-- */
        CHECKERR ("RESET DB MONITOR");

        printf("Database Monitor Reset for '%s' was successful!\n",
            argv[1]);
    }
    return 0;
}
