/*******************************************************************************
**                                                                        
** Source File Name = basiccon.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - demonstrate basic connection to two datasources.
**    - error handling mostly ignored for simplicity
**
**  Local Functions:
**    DBconnect
**
**  Refer to mutlicon.c for an expanded version.
**
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocConnect
**        SQLAllocEnv
**        SQLConnect
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**                                                                        
**                                                                        
*******************************************************************************/

/*--> SQLL1X11.SCRIPT */
#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif


int
DBconnect(SQLHENV henv,
          SQLHDBC * hdbc);

#define MAX_UID_LENGTH    18
#define MAX_PWD_LENGTH    30
#define MAX_CONNECTIONS   2

int
main( )
{
    SQLHENV         henv;
    SQLHDBC         hdbc[MAX_CONNECTIONS];

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif


    /* allocate an environment handle   */
    SQLAllocEnv(&henv);

    /* Connect to first data source */
    DBconnect(henv, &hdbc[0]);

    /* Connect to second data source */
    DBconnect(henv, &hdbc[1]);

    /*********   Start Processing Step  *************************/
    /* allocate statement handle, execute statement, etc.       */
    /*********   End Processing Step  ***************************/

    printf("\nDisconnecting .....\n");
    SQLDisconnect(hdbc[0]);     /* disconnect first connection */
    SQLDisconnect(hdbc[1]);     /* disconnect second connection */
    SQLFreeConnect(hdbc[0]);    /* free first connection handle  */
    SQLFreeConnect(hdbc[1]);    /* free second connection handle */
    SQLFreeEnv(henv);           /* free environment handle       */

    return (SQL_SUCCESS);
}

/********************************************************************
**   connect - Prompt for connect options and connect              **
********************************************************************/

int
DBconnect(SQLHENV henv,
          SQLHDBC * hdbc)
{
    SQLRETURN       rc;
    SQLCHAR         server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR         uid[MAX_UID_LENGTH + 1];
    SQLCHAR         pwd[MAX_PWD_LENGTH + 1];
    SQLCHAR         buffer[255];
    SQLSMALLINT     outlen;

    printf(">Enter Server Name:\n");
    gets((char *) server);
    printf(">Enter User Name:\n");
    gets((char *) uid);
    printf(">Enter Password:\n");
    gets((char *) pwd);

    SQLAllocConnect(henv, hdbc);/* allocate a connection handle     */

    rc = SQLConnect(*hdbc, server, SQL_NTS, uid, SQL_NTS, pwd, SQL_NTS);
    if (rc != SQL_SUCCESS) {
        printf(">--- Error while connecting to database: %s -------\n", server);
        return (SQL_ERROR);
    } else {
        printf(">Connected to %s\n", server);
        return (SQL_SUCCESS);
    }
}
/*<-- */
