/*******************************************************************************
**
** Source File Name = columns.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
** Example using SQLColumns
** - prompts for pattern search values for schema name, table name
** - list all columns for the indicated tables
**
**    FUNCTIONS USED :
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindCol
**        SQLColumns
**        SQLDisconnect
**        SQLFetch
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**
**
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for common CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif


#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;
    struct {  SQLINTEGER   ind;
              SQLCHAR      s[129];
           } table_schem, table_name, column_name, type_name;

    struct {  SQLINTEGER   ind;
              SQLCHAR      s[255];
           } remarks;

    SQLINTEGER      length_ind;
    SQLINTEGER      length;
    SQLINTEGER      scale_ind;
    SQLSMALLINT     scale;
    SQLINTEGER      nullable_ind;
    SQLSMALLINT     nullable;

    SQLCHAR         cur_name[512] = "", pre_name[512] = "";

    SQLINTEGER      scale_l;

#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif


 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    printf("Enter Table Schema Name Search Pattern:\n");
    gets((char *)table_schem.s);
    printf("Enter Table Name Search Pattern:\n");
    gets((char *)table_name.s);

    rc = SQLColumns(hstmt, NULL, 0, table_schem.s, SQL_NTS,
                    table_name.s, SQL_NTS, (SQLCHAR *)"%", SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 2, SQL_C_CHAR, (SQLPOINTER) table_schem.s, 129,
                    &table_schem.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 3, SQL_C_CHAR, (SQLPOINTER) table_name.s, 129,
                    &table_name.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 4, SQL_C_CHAR, (SQLPOINTER) column_name.s, 129,
                    &column_name.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 6, SQL_C_CHAR, (SQLPOINTER) type_name.s, 129,
                    &type_name.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 7, SQL_C_LONG, (SQLPOINTER) & length,
                    sizeof(length), &length_ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 9, SQL_C_SHORT, (SQLPOINTER) & scale,
                    sizeof(scale), &scale_ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 12, SQL_C_CHAR, (SQLPOINTER) remarks.s, 129,
                    &remarks.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 11, SQL_C_SHORT, (SQLPOINTER) & nullable,
                    sizeof(nullable), &nullable_ind);
    CHECK_STMT(hstmt, rc);


    /* Fetch each row, and display */
    while ((rc = SQLFetch(hstmt)) == SQL_SUCCESS) {
        sprintf((char *)cur_name, "%s.%s", table_schem.s, table_name.s);
        if (strcmp((const char *)cur_name, (const char *)pre_name) != 0) {
            printf("\n%s\n", cur_name);
        }
        strcpy((char *)pre_name, (char *)cur_name);
        printf("   %s", column_name.s);
        if (nullable == SQL_NULLABLE) {
            printf(", NULLABLE");
        } else {
            printf(", NOT NULLABLE");
        }
        printf(", %s", type_name.s);
        printf(" (%ld", length);
        if (scale_ind != SQL_NULL_DATA) {
            printf(", %d)\n", scale);
        } else {
            printf(")\n");
        }
        if (remarks.ind > 0 ) {
            printf("(remarks), %s)\n", remarks.s);
        }
    }                           /* endwhile */

    if (rc != SQL_NO_DATA_FOUND)
        check_error(henv, hdbc, hstmt, rc, __LINE__, __FILE__);

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
