/*******************************************************************************
**                                                                        
** Source File Name = datasour.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - demonstrate SQLDataSource function
**    - list available servers
**      (error checking has been ignored for simplicity)
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLDataSources
**        SQLFreeEnv
**                                                                        
**                                                                        
*******************************************************************************/
/*--> SQLL1X01.SCRIPT */

#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/

    SQLCHAR server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR uid[MAX_UID_LENGTH + 1];
    SQLCHAR pwd[MAX_PWD_LENGTH + 1]; 


int 
main()
{
    SQLRETURN       rc;
    SQLHENV         henv;
    SQLCHAR         source[SQL_MAX_DSN_LENGTH + 1], description[255];
    SQLSMALLINT     buffl, desl;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif


    SQLAllocEnv(&henv);         /* allocate an environment handle   */

    /* list the available data sources (servers)         */
    printf("The following data sources are available:\n");
    printf("ALIAS NAME                      Comment(Description)\n");
    printf("----------------------------------------------------\n");

    while ((rc = SQLDataSources(henv, SQL_FETCH_NEXT, source,
                   SQL_MAX_DSN_LENGTH + 1, &buffl, description, 255, &desl))
           != SQL_NO_DATA_FOUND) {
        printf("%-30s  %s\n", source, description);
    }

    SQLFreeEnv(henv);

    return (SQL_SUCCESS);
}
/*<-- */
