/*******************************************************************************
**                                                                        
** Source File Name = duowcon.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - demonstrate basic DUOW connection to two datasources.
**    - error handling  ignored for simplicity
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocConnect
**        SQLAllocEnv
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

#define MAX_CONNECTIONS  2 

/*--> SQLL1X13.SCRIPT */
int
main()
{
    SQLHENV         henv;
    SQLHDBC         hdbc[MAX_CONNECTIONS];
    SQLRETURN       rc;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

    /* allocate an environment handle   */
    SQLAllocEnv(&henv);
    
    /* Before allocating any connection handles, set Environment wide
       Connect Options  */
    /* Set to Connect Type 2, Syncpoint 1 */
    rc = SQLSetEnvAttr(henv, SQL_CONNECTTYPE, 
                       (SQLPOINTER) SQL_COORDINATED_TRANS, 0);
/*<-- */
    if (rc != SQL_SUCCESS) {
        printf(">---ERROR while setting Connect Type 2 -------------\n");
        return (SQL_ERROR);
    }
/*--> */
    rc = SQLSetEnvAttr(henv, SQL_SYNC_POINT, 
                       (SQLPOINTER) SQL_ONEPHASE, 0);
/*<-- */
    if (rc != SQL_SUCCESS) {
        printf(">---ERROR while setting Syncpoint One Phase --------\n");
        return (SQL_ERROR);
    }

/*--> */
    /* Connect to first data source */
    /* allocate a connection handle     */
    if (SQLAllocConnect(henv, &hdbc[0]) != SQL_SUCCESS) {
        printf(">---ERROR while allocating a connection handle-----\n");
        return (SQL_ERROR);
    }
    /* Call local connect function */
    Prompted_Connect(henv, &hdbc[0]);

    /* allocate a second connection handle     */
    if (SQLAllocConnect(henv, &hdbc[1]) != SQL_SUCCESS) {
        printf(">---ERROR while allocating a connection handle-----\n");
        return (SQL_ERROR);
    }
    /* Connect to second data source */
    Prompted_Connect(henv, &hdbc[1]);

    /*********   Start Processing Step  *************************/
    /* allocate statement handle, execute statement, etc.       */
    /*********   End Processing Step  ***************************/
   
    /* Disconnect, free handles and exit */
/*<--
*/
    printf("\nHit Enter to disconnect\n");
    getchar();
    printf("Disconnecting .....\n");
    SQLDisconnect(hdbc[0]);     /* disconnect first connection */
    SQLDisconnect(hdbc[1]);     /* disconnect second connection */
    SQLFreeConnect(hdbc[0]);    /* free first connection handle  */
    SQLFreeConnect(hdbc[1]);    /* free second connection handle */
    SQLFreeEnv(henv);           /* free environment handle       */

    return (SQL_SUCCESS);
}
