/*******************************************************************************
**                                                                        
** Source File Name = getattrs.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - Retrieves and displays environment, connection and statement 	
**      attributes (options).
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLGetConnectOption
**        SQLGetEnvAttr
**        SQLGetStmtOption
**                                                                        
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"  /* header file for common macros and functions */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;
    SQLINTEGER      output_nts;
    SQLINTEGER      cursor_hold;
    SQLINTEGER      autocommit;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    print_connect_info(hdbc);  /* Print connection information */

/*--> SQLL1X37.SCRIPT */
    rc = SQLGetEnvAttr(henv, SQL_ATTR_OUTPUT_NTS, &output_nts, 0, 0); 
    CHECK_ENV(henv, rc);
    printf("Null Termination of Output strings is: ");
    if (output_nts == SQL_TRUE) 
       printf("True\n");
    else
       printf("False\n");
/*<-- */

/*--> SQLL1X38.SCRIPT */
    rc = SQLGetConnectOption(hdbc, SQL_AUTOCOMMIT, &autocommit); 
    CHECK_DBC(hdbc, rc);
    printf("Autocommit is: ");
    if (autocommit == SQL_AUTOCOMMIT_ON) 
       printf("ON\n");
    else
       printf("OFF\n");
/*<-- */

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_STMT(hstmt, rc);

/*--> SQLL1X39.SCRIPT */
    rc = SQLGetStmtOption(hstmt, SQL_CURSOR_HOLD, &cursor_hold); 
    CHECK_STMT(hstmt, rc);
    printf("Cursor With Hold is: ");
    if (cursor_hold == SQL_CURSOR_HOLD_ON ) 
       printf("ON\n");
    else
       printf("OFF\n");
/*<-- */

    printf("\nDisconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}
