/*******************************************************************************
**                                                                        
** Source File Name = getfuncs.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - Connect to a database
**    - Display connect information
**    - List all functions, and if they are supported
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLGetFunctions
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"  /* header file for common macros and functions */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

/*--> SQLL1X06.SCRIPT */
/* header file that defines func_list[], func_names[][28] */
#include "getfuncs.h"  

extern  SQLSMALLINT  func_list[];
extern  SQLCHAR      func_names[][28];

/*<-- */

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;
    SQLCHAR         buffer[255];
    SQLSMALLINT     output;
    SQLUSMALLINT     outlen, supported;
    int             i;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = print_connect_info(hdbc);  /* Print connection information */

/*--> */
    for (i = 0; i < NUM_FUNCTIONS; i = i + 2) {
        rc = SQLGetFunctions(hdbc, func_list[i], &supported);
        printf("%-28s = %-5s", func_names[i], truefalse[supported]);
        if ( i+1 < NUM_FUNCTIONS) {
            rc = SQLGetFunctions(hdbc, func_list[i + 1], &supported);
            printf("  %-28s = %-5s\n", func_names[i + 1], truefalse[supported]);
        }
    }

/*<-- */
    printf("\nDisconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}
