/*******************************************************************************
**                                                                        
** Source File Name = lookres.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    Search a resume CLOB using a CLOB Locator, print employees interests.
**    Only the result is sent from the server to the application.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindCol
**        SQLDisconnect
**        SQLExecDirect
**        SQLFetch
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLGetLength
**        SQLGetPosition
**        SQLGetSubString
**        SQLSetParam
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define ROWSET_SIZE  10

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt, lhstmt;
    SQLRETURN       rc;
    SQLCHAR         stmt1[] =
                    "SELECT employee.empno, firstnme || lastname as name "
                      "FROM employee, emp_resume "
                      "WHERE employee.empno = emp_resume.empno "
                        "AND resume_format = 'ascii'";
/*--> SQLL1X22.SCRIPT */
    SQLCHAR         stmt2[] =
                    "SELECT resume FROM emp_resume "
                      "WHERE empno = ?  AND resume_format = 'ascii'";
/*<-- */

    SQLCHAR         stmt3[] = "FREE LOCATOR ?";

    struct {
              SQLINTEGER      ind;
              SQLCHAR         s[30];
           } Name;

    struct { 
              SQLINTEGER      ind;
              SQLCHAR         s[7];
           } Empno;

    SQLINTEGER      ClobLoc1;  /* A LOB locator used for resume */
    SQLINTEGER      pcbValue;
    SQLINTEGER      SLength;
    SQLUINTEGER     Pos1;
    SQLINTEGER      OutLength, Ind;
    SQLCHAR       * buffer;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

     /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

/******************************************************************
**  Display list of employee's with resumes on file **
*******************************************************************/
    rc = SQLExecDirect(hstmt, stmt1, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 1, SQL_C_CHAR, Empno.s, 7, &Empno.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 2, SQL_C_CHAR, Name.s, 30, &Name.ind);
    CHECK_STMT(hstmt, rc);

    printf("\nEmpno   Name \n");
    printf("------- ---------------------\n");
    while ((rc = SQLFetch(hstmt)) == SQL_SUCCESS) {
        printf("%-6s %-30s \n", Empno.s, Name.s);
    }
    if (rc != SQL_NO_DATA_FOUND)
        check_error(henv, hdbc, hstmt, rc, __LINE__, __FILE__);

    rc = SQLFreeStmt(hstmt, SQL_CLOSE); CHECK_STMT(hstmt, rc);
    rc = SQLFreeStmt(hstmt, SQL_UNBIND); CHECK_STMT(hstmt, rc);
    rc = SQLFreeStmt(hstmt, SQL_RESET_PARAMS); CHECK_STMT(hstmt, rc);

/*--> */
/******************************************************************
**  Get CLOB locator to selected Resume  **
*******************************************************************/

    rc = SQLSetParam(hstmt, 1, SQL_C_CHAR, SQL_CHAR, 7,
                     0, Empno.s, &Empno.ind);
    CHECK_STMT(hstmt, rc);

    printf("\n>Enter an employee number:\n");
    gets((char *)Empno.s);

    rc = SQLExecDirect(hstmt, stmt2, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 1, SQL_C_CLOB_LOCATOR, &ClobLoc1, 0,
                     &pcbValue);
    CHECK_STMT(hstmt, rc);

    rc = SQLFetch(hstmt);
    CHECK_STMT(hstmt, rc);

/******************************************************************
    Search CLOB locator to find "Interests" 
    Get substring of resume (from position of interests to end)
*******************************************************************/

    rc = SQLAllocStmt(hdbc, &lhstmt);
    CHECK_DBC(hdbc, rc);

    /* Get total length */
    rc = SQLGetLength(lhstmt, SQL_C_CLOB_LOCATOR, ClobLoc1, &SLength, &Ind);
    CHECK_STMT(lhstmt, rc);

    /* Get Starting postion */
    rc = SQLGetPosition(lhstmt, SQL_C_CLOB_LOCATOR, ClobLoc1, 0, 
                    (SQLCHAR *)"Interests", 9, 1, &Pos1, &Ind);
    CHECK_STMT(lhstmt, rc);

    rc = SQLFreeStmt(lhstmt, SQL_CLOSE); CHECK_STMT(lhstmt, rc);

    buffer = (SQLCHAR *)malloc(SLength - Pos1 + 1);

    /* Get just the "Interests" section of the Resume CLOB */
    /* (From Pos1 to end of CLOB) */
    rc = SQLGetSubString(lhstmt, SQL_C_CLOB_LOCATOR, ClobLoc1, Pos1, 
         SLength - Pos1, SQL_C_CHAR, buffer, SLength - Pos1 +1, 
         &OutLength, &Ind);
    CHECK_STMT(lhstmt, rc);

    /* Print Interest section of Employee's resume */
    printf("\nEmployee #: %s\n %s\n", Empno.s, buffer);
/*<-- */

    rc = SQLFreeStmt(hstmt, SQL_UNBIND);       CHECK_STMT(hstmt, rc);
    rc = SQLFreeStmt(hstmt, SQL_RESET_PARAMS); CHECK_STMT(hstmt, rc);
    rc = SQLFreeStmt(hstmt, SQL_CLOSE);        CHECK_STMT(hstmt, rc);

/******************************************************************
    FREE LOCATOR 
*******************************************************************/
    rc = SQLSetParam(hstmt, 1, SQL_C_CLOB_LOCATOR, SQL_CLOB_LOCATOR, 0,
                     0, &ClobLoc1, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecDirect(hstmt, stmt3, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLFreeStmt(hstmt, SQL_DROP);  CHECK_STMT(hstmt, rc);
    rc = SQLFreeStmt(lhstmt, SQL_DROP); CHECK_STMT(lhstmt, rc);

/******************************************************************
   COMMIT, free resources and exit
*******************************************************************/

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf(">Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
