/*******************************************************************************
**
** Source File Name = mrspcli2.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**  Client sample for the mrspsrv2 'output' stored procedure sample
**  that demonstrates returning a result set from a stored procedure
**  using embedded SQL.
**  Only the line:
**          SQLCHAR stmt[] = "CALL mrspsrv2( ? )";
**  is different between this program and mrspcli.c.
**  See mrspsrv2.c for details on what happens on the server side.
**
**
**    FUNCTIONS USED :
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLPrepare
**
**
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for common CLI sample code */

#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;
/*--> SQLL1X45.SCRIPT */
    SQLCHAR         stmt[] = "CALL mrspsrv2( ? )";

/* Declare Local Variables for Holding Returned Data */
     SQLDOUBLE   sal     = 0.0;  /* Bound to parameter marker in stmt */
     SQLINTEGER  salind  = 0;    /* Indicator variable for sal */
/*<-- */

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
      return (terminate(henv, rc));

   /* Connect to Remote Database */
    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
       return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);
/*--> */
   /**********************************************************\
   * Call the Remote Procedure via CALL with bound parameters *
   \**********************************************************/
   printf("Use CALL with Host Variable to invoke the Server Procedure "
      "named mrspsrv2\n");
   salind = SQL_NULL_DATA;                  /* Sal has no input, so set to null */

   /* Prepare the call statement */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    /* Bind the parameter to application variables (sal and salind) */
    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_OUTPUT, SQL_C_DOUBLE, SQL_DOUBLE,
                      4, 0, &sal, 0, &salind);
    CHECK_STMT(hstmt, rc);

    SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);

   printf("Server Procedure Complete.\n");

   /* Print Salary Returned in the bound application variables */
   if (salind == SQL_NULL_DATA) /* Check for null value */
      printf("Median Salary = NULL\n");
   else
      printf("Median Salary = %.2f\n\n", sal );
/*<-- */

    /* Assume only 1 result set */
    rc = print_results(hstmt);
    CHECK_STMT(hstmt, rc);

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
