/*******************************************************************************
**                                                                        
** Source File Name = multicon.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**    - Demonstrate connecting to multiple data sources.
**    - Print Connection information
**    - Disconnect from each data source
**    - Basic error handling only
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocConnect
**        SQLAllocEnv
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_CONNECTIONS   5

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

int
main( )
{
    SQLHENV         henv;
    SQLHDBC         hdbc[MAX_CONNECTIONS];
    SQLINTEGER      con = 0;
    SQLRETURN       rc;
    char            prompt[256];

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

    /* allocate an environment handle   */
    rc = SQLAllocEnv(&henv);
    if (rc != SQL_SUCCESS) {
        return (terminate(henv, rc));
    }
    /* Connect to one or more data sources  */
    do {
        rc = SQLAllocConnect(henv, &hdbc[con]);
        CHECK_DBC(hdbc[con], rc);
        if (Prompted_Connect(henv, &hdbc[con]) == SQL_SUCCESS) {
            print_connect_info(hdbc[con]);
            con++;
        }
        if (con < MAX_CONNECTIONS) {
            printf("Connect to another Data Source?(Y or N)\n");
            gets(prompt);
        }
    }
    while ((prompt[0] == 'Y' || prompt[0] == 'y') &&
           (con < MAX_CONNECTIONS));

    /*********   Start Processing Step  *************************/
    /* allocate statement handle, execute statement, etc.       */
    /*********   End Processing Step  ***************************/

    /* Disconnect and Free each Connection       */
    printf("Disconnecting ...\n");
    while (con > 0) {
        con--;
        rc = SQLDisconnect(hdbc[con]);
        CHECK_DBC(hdbc[con], rc);

        rc = SQLFreeConnect(hdbc[con]);
        CHECK_DBC(hdbc[con], rc);
    }

    /* free environment handle       */
    printf("Free environment handle ...\n");
    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}
