/*******************************************************************************
**                                                                        
** Source File Name = ordin.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
** Use array input, adds order to the ord_line & ord_cust tables.
** This example uses the tables created by create.c, see the README file
** for more information.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLParamOptions
**        SQLPrepare
**                                                                        
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define NUM_ORDS 16
#define NUM_ORD_LINES 25

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;
    SQLCHAR         stmt1[] =
    "INSERT INTO ORD_CUST VALUES (?, ?, CURRENT DATE)";
    SQLCHAR         stmt2[] =
    "INSERT INTO ORD_LINE VALUES (?, ?, ?)";

    SQLINTEGER      Ord_Num[NUM_ORDS] = {
        100101, 100102, 100103, 100104, 100105, 100106,
        100107, 100108, 100109, 100110, 100111, 100112,
        100113, 100114, 100115, 100116
    };
    SQLINTEGER      Cust_Num[NUM_ORDS] = {
        10, 10, 30, 40, 50, 60, 60, 60, 90, 100,
        110, 110, 130, 160, 160, 160
    };
    SQLINTEGER      Prod_Num_Lines[NUM_ORD_LINES] = {
        100110, 100510, 200510, 200610, 100220, 200120,
        200510, 500210, 200510, 990110, 990110, 500210,
        200220, 200610, 500210, 990120, 990110, 200510,
        200610, 100110, 100210, 990120, 500110, 500210,
        200510
    };
    SQLINTEGER      Ord_Num_Lines[NUM_ORD_LINES] = {
        100101, 100101, 100102, 100103, 100104, 100104,
        100104, 100105, 100105, 100106, 100107, 100107,
        100108, 100108, 100109, 100110, 100111, 100112,
        100113, 100114, 100115, 100116, 100116, 100116,
        100116
    };

    SQLDOUBLE       Quant[NUM_ORD_LINES] = {
        1, 1, 1, 1, 1, 1,
        1, 0.250, 1, 1, 1, 0.5,
        1, 1, 1.5, 1, 1, 1,
        1, 1, 1, 1, 0.250, 1.0,
        1
    };
    SQLUINTEGER      pirow = 0;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif


 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    /* Prepare the first statement */
    rc = SQLPrepare(hstmt, stmt1, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Ord_Num, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Cust_Num, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLParamOptions(hstmt, NUM_ORDS, &pirow);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);
    printf("Inserted %ld Rows\n", pirow);

    /* Reset the statement handle for use with second statement */
    rc = SQLFreeStmt(hstmt, SQL_RESET_PARAMS);
    CHECK_STMT(hstmt, rc);

    /* Prepare the second statement */
    rc = SQLPrepare(hstmt, stmt2, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Ord_Num_Lines, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT, SQL_C_SLONG, SQL_INTEGER,
                          0, 0, Prod_Num_Lines, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 3, SQL_PARAM_INPUT, SQL_C_DOUBLE, SQL_DECIMAL,
                          14, 7, Quant, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLParamOptions(hstmt, NUM_ORD_LINES, &pirow);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);
    printf("Inserted %ld Rows\n", pirow);

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_STMT(hstmt, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
