/*******************************************************************************
**                                                                        
** Source File Name = outcli.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**         This sample program demonstrates an 'output' stored procedures.
**
**         There are two parts to this program:
**            1. the outcli executable (placed on the client)
**            2. the outsrv library (placed on the server)
**
**         The outsrv2 routine will obtain the median salary of
**         employees in the "staff" table of the "sample" database.
**         This value will be placed in the output SQLDA and
**         returned to the outcli routine.  The outcli routine will
**         then print out the median salary.
**
** NOTE:   All variables on the SQL CALL statements are assummed to
**         be used for both input and output.  One technique to minimize
**         network flow is for the client program to provide indicator
**         variables with all its host variables.
**           -  The client program should set the "output-only" variable's
**              indicator value to -1 before issuing the CALL.
**           -  The server program should set the "input-only" variable's
**              indicator value to -128 before returning.
**
**         This will cause the transmission of just the indicator value
**         instead of the host variable itself.  This will be worthwhile
**         when dealing with fairly long character data.
**
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLPrepare
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for common CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;

    SQLCHAR         stmt[] = "CALL outsrv( ? )";

/* Declare Local Variables for Holding Returned Data */
    SQLDOUBLE       sal     = 0.0;  /* :rk.2:erk. */
    SQLINTEGER      salind  = 0;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

   /* Connect to Remote Database */
   rc = SQLAllocEnv(&henv);
   if (rc == SQL_ERROR)
      return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
       return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

   /********************************************************\
   * Call the Remote Procedure via CALL with Host Variables *
   \********************************************************/
   printf("Use CALL with Host Variable to invoke the Server Procedure "
      "named outsrv\n");
   salind = -1;                  /* Sal has no input, so set to null */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_OUTPUT, SQL_C_DOUBLE, SQL_DOUBLE,
                      0, 0, &sal, 0, NULL);
    CHECK_STMT(hstmt, rc);

    SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);

   printf("Server Procedure Complete.\n");

   /* Print Salary Returned in The Host Variables */
   printf("Median Salary = %.2f\n\n", sal ); /* :rk.6:erk. */


    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
