/*******************************************************************************
**                                                                        
** Source File Name = outcli2.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**  Client sample for the outsrv2 'output' stored procedure sample,
**  a cli version of the embedded sample outsrv2 in sqllib/samples/c.
**  See outsrv2.c for more details.                                       
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLPrepare
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for common CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;
/*--> SQLL1X45.SCRIPT */
    SQLCHAR         stmt[] = "CALL outsrv2( ? )";

/* Declare Local Variables for Holding Returned Data */
     SQLDOUBLE   sal     = 0.0;  /* Bound to parameter marker in stmt */
     SQLINTEGER  salind  = 0;    /* Indicator variable for sal */
/*<-- */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
      return (terminate(henv, rc));

   /* Connect to Remote Database */
    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
       return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);
/*--> */
   /**********************************************************\
   * Call the Remote Procedure via CALL with bound parameters *
   \**********************************************************/
   printf("Use CALL with Host Variable to invoke the Server Procedure "
      "named outsrv\n");
   salind = SQL_NULL_DATA;                  /* Sal has no input, so set to null */

   /* Prepare the call statement */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    /* Bind the parameter to application variables (sal and salind) */
    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_OUTPUT, SQL_C_DOUBLE, SQL_DOUBLE,
                      0, 0, &sal, 0, &salind);
    CHECK_STMT(hstmt, rc);

    SQLExecute(hstmt);
    /* Ignore Warnings */
    if (rc != SQL_SUCCESS & rc != SQL_SUCCESS_WITH_INFO)
       CHECK_STMT(hstmt, rc);

   printf("Server Procedure Complete.\n");

   /* Print Salary Returned in the bound application variables */
   if (salind == SQL_NULL_DATA) /* Check for null value */
      printf("Median Salary = NULL\n");
   else
      printf("Median Salary = %.2f\n\n", sal );
/*<-- */

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
