/*******************************************************************************
**                                                                        
** Source File Name = partrep.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**        Use recursive SQL to generate an exploding parts list.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecDirect
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLParamOptions
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 1024
#define NUM_PRODS 2

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;
    SQLCHAR         stmt[] =

    "WITH mainp (level, prod_num, part_num) AS "
      "( SELECT 1, root.prod_num, root.part_num "
         "FROM prod_parts root "
         "WHERE root.prod_num = pnum(cast(? as integer)) "
        "UNION ALL "
        "SELECT parent.level + 1, sub.prod_num, sub.part_num "
         "FROM mainp parent, prod_parts sub "
         "WHERE parent.part_num = sub.prod_num "
         "AND parent.level < 2 "
       ") "
    "SELECT distinct "
      "m.level, m.prod_num, m.part_num "
      "FROM mainp m ";


    SQLINTEGER      Prod_Num[NUM_PRODS] = {990110, 990120};
    SQLUINTEGER     pirow = 0;
    int             i, j;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    rc = SQLParamOptions(hstmt, NUM_PRODS, &pirow);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Prod_Num, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecDirect(hstmt, stmt, SQL_NTS);
    if (rc != SQL_SUCCESS_WITH_INFO)  /* Ignore Warnings */
       CHECK_STMT(hstmt, rc);

    if (print_results(hstmt) != SQL_SUCCESS)
        printf("> Error processing Statement\n");

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
