/*******************************************************************************
**
** Source File Name = picin2.c  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**      Duplicate of picin.c, but reads the file itself, and inserts
**      the blob in pieces.
**
**    FUNCTIONS USED :
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLCancel
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLParamData
**        SQLPrepare
**        SQLPutData
**
**
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define NUM_PICS 4

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;
/*--> SQLL1X31.SCRIPT */
    SQLCHAR         stmt[] =
    "INSERT INTO emp_photo (empno, photo_format, picture) VALUES (?, ?, ?)";
/*<-- */

    SQLCHAR         Photo_Format[11] = {""};
    SQLCHAR         Empno[7];
    SQLCHAR         FName[256] = "";
    SQLCHAR         fbuffer[BUFSIZ];  /* Use BUFSIZ from stdio.h */
    SQLCHAR         input_param[] = "Photo Data";

    SQLINTEGER      PicLength=0;
    SQLINTEGER      FInd = 0;
    SQLSMALLINT     FLength = 13;
    SQLINTEGER      prgbValue=0;
    SQLINTEGER      i = 0;
    FILE           *PicFile;
    size_t          n = 0;
    size_t          FileSize = 0;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);
/*--> */
    /* Prepare the statement */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR,
                          6, 0, Empno, 7, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR,
                          10, 0,  Photo_Format, 11, NULL);
    CHECK_STMT(hstmt, rc);

    /*
     * This paramter will use SQLPutData, rgbValue is set to Param Number,
     * pcbValue is set to SQL_DATA_AT_EXEC
     */
    PicLength = SQL_DATA_AT_EXEC;
    rc = SQLBindParameter(hstmt, 3, SQL_PARAM_INPUT, SQL_C_BINARY, SQL_BLOB,
                          BUFSIZ, 0, (SQLPOINTER)input_param, BUFSIZ, &PicLength);
    CHECK_STMT(hstmt, rc);
/*<-- */

    while (1) {
        printf("Which Picture Format [xwd (XWindows), bitmap]?\n");
        gets((char *)Photo_Format);
        if (strcmp((char *)Photo_Format, "xwd") == 0 ||
            strcmp((char *)Photo_Format, "bitmap") == 0) break;
        printf("Invalid Format!\n");
    }


    printf("Enter the Employee Number:\n");
    gets((char *)Empno);
    printf("Enter the filename of the Photo of type %s\n", Photo_Format);
    gets((char *)FName);

/*--> */
    rc = SQLExecute(hstmt);
    if (rc == SQL_NEED_DATA)
    {
        PicFile = fopen((char *)FName, "rb");
        if (PicFile == NULL)
        {   printf(">---- ERROR Opening File -------");
            /* Cancel the DATA AT EXEC state for hstmt */
            rc = SQLCancel(hstmt);
            CHECK_STMT(hstmt, rc);
            /* Commit, free resources, disconnect and exit */
            goto CLEANUP;
        }
        while ((rc = SQLParamData(hstmt, (SQLPOINTER) & prgbValue)) ==
                     SQL_NEED_DATA)
        {   printf("Getting data for %s\n", prgbValue);
          /* if more than 1 parms used DATA_AT_EXEC then prgbValue would
             have to be checked to determine which param needed data    */
            do
            {   n = fread(fbuffer, sizeof(char), BUFSIZ, PicFile);
                rc = SQLPutData(hstmt, fbuffer, n);
                CHECK_STMT(hstmt, rc);
                FileSize = FileSize + n;
                if (FileSize > 102400u) /* BLOB column defined as 100K MAX */
                {
                    printf(">---- ERROR: File > 100K  -------");
                    exit(terminate(hdbc, SQL_ERROR));
                }
            }
            while (feof(PicFile) == 0);
            printf("Read a total of %u bytes from %s\n", FileSize, FName);
        }
        CHECK_STMT(hstmt, rc);
    } else
    CHECK_STMT(hstmt, rc);

CLEANUP:

/*<-- */
    rc = SQLFreeStmt(hstmt, SQL_DROP);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    rc = SQLFreeConnect(hdbc);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
