/*******************************************************************************
**                                                                        
** Source File Name = prodpart.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**      Uses array input to populate the prod_part table,
**      (list products that are made up of other products).
**      Execute the create and then the prodin example before 
**      executing prodpart.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLParamOptions
**        SQLPrepare
**                                                                        
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define NUM_INSERT_ITEMS 10

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;

    SQLHSTMT        hstmt;

    SQLCHAR         stmt[] =
    "INSERT INTO Prod_Parts VALUES(cast(? as integer), cast(? as integer), ?)";

    SQLINTEGER      Prod_Num[NUM_INSERT_ITEMS] =
    {200110, 200120, 200210, 200220,
        990110, 990110, 990120, 990120,
    200210, 200220};
    SQLINTEGER      Part_Num[NUM_INSERT_ITEMS] =
    {200510, 200510, 200610, 200610,
        100510, 200110, 100520, 200120,
    300100, 300100};
    SQLDOUBLE       Quant[NUM_INSERT_ITEMS] =
    {1, 1, 1, 1,
        1, 1, 1, 1,
    1.5, 1.5};

    SQLUINTEGER     pirow;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    /* Prepare the statement */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Prod_Num, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT, SQL_C_LONG, SQL_INTEGER,
                          0, 0, Part_Num, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindParameter(hstmt, 3, SQL_PARAM_INPUT, SQL_C_DOUBLE, SQL_DECIMAL,
                          10, 2, Quant, 0, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLParamOptions(hstmt, NUM_INSERT_ITEMS, &pirow);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_STMT(hstmt, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_STMT(hstmt, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (SQL_SUCCESS);
};                              /* end main */
