/*******************************************************************************
**                                                                        
** Source File Name = sendda.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**      An input/output stored procedure sample.  This is the calling
**      application.  The showda procedure is called, which accepts any
**      number of arguments, displays sqlda information, and modifies the
**      argument values.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindParameter
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLPrepare
**                                                                        
**                                                                        
*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sql.h"
#include "sqlcli.h"
#include "sqlcli1.h"
#include "sqlca.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define NUM_SP_PARAMS 9

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main(  int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc;
    SQLHSTMT        hstmt;

/*--> SQLL1X42.SCRIPT */
    SQLCHAR         stmt[] = "CALL showda(?, ?, ?, ?, ?, ?, ?, ?, ?)";
/*
    SQLCHAR         stmt[] = "CALL showda(?, ?, ?, ?, ?, ?, ?, ?)";
*/

/*<-- */

    SQLINTEGER      ind[NUM_SP_PARAMS];
    SQLCHAR         returnbuf[10240] = "Empty";
   
    SQLCHAR         blob[11] = {'\xff','\x01','\xff','\x02','\xff','\x03',
                           '\xff','\x04','\xff','\x05'};
    SQLCHAR         clob[15] =      "I am a CLOB";
    SQLCHAR         character[15] = "I am a CHAR   ";
    SQLCHAR         varchar[15] =   "I am a VARCHAR";
    SQLINTEGER      integer = 12345678;
    SQLCHAR         decimal[18] = "-00001234.56780000";
    double          double_var = (1234.5678);
    struct sqlca    sqlca;
    int             i;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc == SQL_ERROR)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

/*--> */
    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);


    ind[0] = 10;
    rc = SQLBindParameter(hstmt, 1, SQL_PARAM_INPUT_OUTPUT, SQL_C_BINARY, 
                          SQL_BLOB, 10, 0, blob, 10, &ind[0]);
    CHECK_STMT(hstmt, rc);

    ind[1] = SQL_NTS;
    rc = SQLBindParameter(hstmt, 2, SQL_PARAM_INPUT_OUTPUT, SQL_C_CHAR, 
                          SQL_CLOB, 14, 0, clob, 15, &ind[1]);
    CHECK_STMT(hstmt, rc);

    ind[2] = SQL_NTS;
    rc = SQLBindParameter(hstmt, 3, SQL_PARAM_INPUT_OUTPUT, SQL_C_CHAR, 
           SQL_CHAR, 14, 0, character, 15, &ind[2]);
    CHECK_STMT(hstmt, rc);

    ind[3] = SQL_NTS;
    rc = SQLBindParameter(hstmt, 4, SQL_PARAM_INPUT_OUTPUT, SQL_C_CHAR, 
             SQL_VARCHAR, 14, 0, varchar, 15, &ind[3]);
    CHECK_STMT(hstmt, rc);

    ind[4] = 0;
    rc = SQLBindParameter(hstmt, 5, SQL_PARAM_INPUT_OUTPUT, SQL_C_LONG, 
                          SQL_INTEGER, 0, 0, &integer, 4, &ind[4]);
    CHECK_STMT(hstmt, rc);

    ind[5] = SQL_NTS;
    rc = SQLBindParameter(hstmt, 6, SQL_PARAM_INPUT_OUTPUT, SQL_C_CHAR, 
                          SQL_DECIMAL, 16, 8, &decimal, sizeof(decimal), &ind[5]);
    CHECK_STMT(hstmt, rc);

    ind[6] = 0;
    rc = SQLBindParameter(hstmt, 7, SQL_PARAM_INPUT_OUTPUT, SQL_C_DOUBLE, 
                          SQL_DOUBLE, 0, 0, &double_var, 4, &ind[6]);
    CHECK_STMT(hstmt, rc);

    ind[7] = 0;
    rc = SQLBindParameter(hstmt, 8, SQL_PARAM_INPUT, SQL_C_DOUBLE, SQL_DECIMAL, 
	              16, 11, &double_var, 4, &ind[7]);
    CHECK_STMT(hstmt, rc);

/*  The last parameter is an output CLOB, used by showda to send back the
    SQLDA information that the stored procedure received
*/
    ind[NUM_SP_PARAMS -1] = 0;   
    rc = SQLBindParameter(hstmt, 9, SQL_PARAM_INPUT_OUTPUT, SQL_C_CHAR, 
                          SQL_CLOB, 10239, 0, returnbuf, 10240, 
                          &ind[NUM_SP_PARAMS-1]);
    CHECK_STMT(hstmt, rc);

    printf("Calling Stored Procedure with valid arguments\n");
    rc = SQLExecute(hstmt);
    /* Ignore Warnings */
    if (rc != SQL_SUCCESS_WITH_INFO)
       CHECK_STMT(hstmt, rc);

    printf("\nValues after being reset by the stored procedure\n");
    printf("\nReturn Buffer:\n %s \n", returnbuf);
    printf("  Blob =", clob);
        for (i = 0; i<sizeof(blob); i++)
            printf("%02X", (int)blob[i]);
    printf("\n");
    printf("  Clob = %s\n", clob);
    printf("  Char = %s\n", character);
    printf("  Varchar = %s\n", varchar);
    printf("  Integer = %ld\n", integer );
    printf("  Decimal = %s\n", decimal);
    printf("  Double  = %lf\n", double_var );

    for (i=0; i<NUM_SP_PARAMS; i++)
       ind[i]=SQL_NULL_DATA;

    printf("Calling Stored Procedure with NULL arguments\n");

    rc = SQLExecute(hstmt);
    /* Ignore Warnings */
    if (rc != SQL_SUCCESS & rc != SQL_SUCCESS_WITH_INFO)
       CHECK_STMT(hstmt, rc);
/*<-- */

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        terminate(henv, rc);

    return (0);
};                              /* end main */

