/*******************************************************************************
**                                                                        
** Source File Name = setcolat.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
** Example using SQLSetColAttributes
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLDisconnect
**        SQLExecute
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLPrepare
**        SQLSetColAttributes
**        SQLSetStmtOption
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for common CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;
/*--> SQLL1X40.SCRIPT */
    SQLCHAR         stmt[] = 
    { "Select id, name from staff" };
/*<-- */

    SQLINTEGER      length_ind;
    SQLINTEGER      length;
    SQLINTEGER      scale_ind;
    SQLSMALLINT     scale;
    SQLINTEGER      nullable_ind;
    SQLSMALLINT     nullable;

    SQLCHAR         cur_name[512] = "", pre_name[512] = "";

    SQLINTEGER      scale_l;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);
/*--> */

  /* Tell DB2 CLI not to get Column Attribute from the server for this hstmt */
    rc = SQLSetStmtOption(hstmt, SQL_NODESCRIBE, SQL_NODESCRIBE_ON);
    CHECK_STMT(hstmt, rc);

    rc = SQLPrepare(hstmt, stmt, SQL_NTS);
    CHECK_STMT(hstmt, rc);
    
/* Provide the columns attributes to DB2 CLI for this hstmt */
    rc = SQLSetColAttributes(hstmt, 1, (SQLCHAR *)"-ID-", SQL_NTS, SQL_SMALLINT, 
                             5, 0, SQL_NO_NULLS);
    rc = SQLSetColAttributes(hstmt, 2, (SQLCHAR *)"-NAME-", SQL_NTS, SQL_CHAR, 
                             9, 0, SQL_NULLABLE);
    rc = SQLExecute(hstmt);
    CHECK_STMT(hstmt, rc);

    print_results(hstmt); /* Call sample function to print column attributes
                             and fetch and print rows.  */
/*--> */

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
