/*******************************************************************************
**                                                                        
** Source File Name = setcurs.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
** Example of directly executing a SELECT and positioned UPDATE SQL statement.
** Two statment handles are used, and SQLSetCursor is used to create
** an application defined cursor name to be used in the SQL statement.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindCol
**        SQLDisconnect
**        SQLExecDirect
**        SQLFetch
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLSetCursorName
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli1.h"
#include "samputil.h"

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLRETURN       rc, rc2;
    SQLHSTMT        hstmt1, hstmt2;
/*--> SQLL1X09.SCRIPT */
    SQLCHAR         sqlstmt[] = 
                    "SELECT name, job FROM staff "
                    "WHERE job='Clerk'  FOR UPDATE OF job";
/*<-- */
    SQLCHAR         updstmt[MAX_STMT_LEN + 1];
    struct { SQLINTEGER ind;
             SQLCHAR  s[10];
           } name;
    struct { SQLINTEGER ind;
             SQLCHAR  s[6];
           } job;

    SQLCHAR         newjob[6];

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt1);
    CHECK_DBC(hdbc, rc);
/*--> */
    /* allocate second statement handle for update statement */
    rc2 = SQLAllocStmt(hdbc, &hstmt2);
    CHECK_DBC(hdbc, rc);

    /* Set Cursor for the SELECT statement's handle */
    rc = SQLSetCursorName(hstmt1, (SQLCHAR *)"JOBCURS", SQL_NTS);
    CHECK_STMT(hstmt1, rc);

    rc = SQLExecDirect(hstmt1, sqlstmt, SQL_NTS);
    CHECK_STMT(hstmt1, rc);

    /* bind name to first column in the result set */
    rc = SQLBindCol(hstmt1, 1, SQL_C_CHAR, (SQLPOINTER) name.s, 10,
                    &name.ind);
    CHECK_STMT(hstmt1, rc);

    /* bind job to second column in the result set */
    rc = SQLBindCol(hstmt1, 2, SQL_C_CHAR, (SQLPOINTER) job.s, 6,
                    &job.ind);
    CHECK_STMT(hstmt1, rc);

    printf("Job Change for all clerks\n");

    while ((rc = SQLFetch(hstmt1)) == SQL_SUCCESS) {
        printf("Name: %-9.9s Job: %-5.5s \n", name.s, job.s);
        printf("Enter new job or return to continue\n");
        gets((char *)newjob);
        if (newjob[0] != '\0') {
            sprintf((char *)updstmt,
                    "UPDATE staff set job = '%s' where current of JOBCURS",
                    newjob);
            rc2 = SQLExecDirect(hstmt2, updstmt, SQL_NTS);
            CHECK_STMT(hstmt2, rc2);
        }
    }
    if (rc != SQL_NO_DATA_FOUND)
        check_error(henv, hdbc, hstmt1, rc, __LINE__, __FILE__);
/*<-- */
    rc = SQLFreeStmt(hstmt1, SQL_DROP);
    CHECK_STMT(hstmt1, rc);

    rc = SQLFreeStmt(hstmt2, SQL_DROP);
    CHECK_STMT(hstmt2, rc2);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
