/*******************************************************************************
**                                                                        
** Source File Name = showda.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**      An input/output stored procedure sample.  
**      Showda accepts any number of arguments, 
**      displays sqlda information, and modifies the argument values.
**                                                                        
**      If this sample is run locally, the stored procedure is actually   
**      in the same process as the client, and the standard output is     
**      displayed in the screen that the calling application is executed.
**                                                                        
**      If this sample is run remotely, pass a CLOB OUTPUT buffer as the
**      LAST parameter, and the same information will be written to this  
**      buffer and can then be displayed by the client.  
**      See the sendda.c sample.
**                                                                        
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocConnect
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLConnect
**        SQLDisconnect
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLGetSQLCA
**                                                                        
**                                                                        
*******************************************************************************/

#include <memory.h>
#include <string.h>
#include <sqlca.h>
#include <sqlda.h>
#include <sql.h>
#include <sqlcli.h>
#include <sqlcli1.h>

#ifndef max
   #define  max(A, B) ((A) > (B) ? (A) : (B))
#endif
#ifndef min
   #define  min(A, B) ((A) < (B) ? (A) : (B))
#endif
#define  LOBLENGTH  23

struct lob_file {
   unsigned long name_length;
   unsigned long data_length;
   unsigned long file_option;
   char          name[255];
};

/*  Global buufer to send display info back to clients as an output CLOB */
void display_update_da (struct sqlda *sqldaPointer);

SQLCHAR         returnbuf[10240] = "No Info found!\n";
SQLCHAR         *prbuf = &returnbuf[0];

int SQL_API_FN 
   showda (void           *reserved1,
           void           *reserved2, 
           struct sqlda   *inout_sqlda,
           struct sqlca   *ca)
{
   /* Declare a local SQLCA */
   struct sqlca  sqlca;

   /* Delare CLI Variables */
   SQLHENV      henv;
   SQLHDBC      hdbc;
   SQLHSTMT     hstmt;
   SQLRETURN    rc;

   SQLINTEGER   sqlvarIndex;
   SQLINTEGER   i;
   SQL_STRUCTURE  sqlvar2 *sqlvar2;
   long         *len_ptr;

   /*-----------------------------------------------------------------*/
   /* Setup CLI required environment                                  */
   /*-----------------------------------------------------------------*/
/* Skip the CLI setup since this exaample only inpsects and modifes the 
   SQLDA, and does not execute any SQL statements
 

    SQLAllocEnv(&henv);
    SQLAllocConnect(henv, &hdbc);

    SQLConnect(hdbc, NULL, SQL_NTS, NULL, SQL_NTS, NULL, SQL_NTS);
    rc = SQLAllocStmt(hdbc, &hstmt);
*/

    printf("\nDumping SQLDA\n");
    prbuf += sprintf(prbuf, "\nDumping SQLDA\n");
    printf("SQLN = %d SQLD = %d \n", inout_sqlda->sqln, inout_sqlda->sqld);
    prbuf += sprintf(prbuf, "SQLN = %d SQLD = %d \n", inout_sqlda->sqln, 
                     inout_sqlda->sqld);

    /* Displaye the SQLDA information, and update the values */ 
    display_update_da(inout_sqlda);
 
    sqlvarIndex = inout_sqlda->sqld-1;  /* Last SQLVAR */    

    /* If the last parameter is a CLOB, use it to return SQLDA info */
    /* since a remote client won't see the printf's to stdout       */
    if (inout_sqlda->sqlvar[sqlvarIndex].sqltype == SQL_TYP_CLOB
        || inout_sqlda->sqlvar[sqlvarIndex].sqltype ==  SQL_TYP_NCLOB 
       )
    {  /* copy global returnbuf to the last sqlvar entry */ 
       strncpy( (char *) inout_sqlda->sqlvar[sqlvarIndex].sqldata ,
               (char *) returnbuf,
               GETSQLDALONGLEN(inout_sqlda, sqlvarIndex) );
       /* Get pointer to length */
       len_ptr = GETSQLDALENPTR(inout_sqlda, inout_sqlda->sqld-1);
       if (len_ptr != NULL )
          *len_ptr = prbuf - returnbuf;  /* Set length of OUTOUT CLOB */
       else  /* len_ptr should never be NULL */
          printf("Error trying to set length of output CLOB\n");
    }


   /*-----------------------------------------------------------------*/
   /* Return to caller                                                */
   /*   -  Copy the SQLCA                                             */
   /*   -  Commit or Rollback the inserts.                            */
   /*-----------------------------------------------------------------*/

ext:
/* Skip the usual exit steps, since this sample just inspects and modifies
   the SQLDA.

   rc = SQLGetSQLCA(henv, hdbc, hstmt, &sqlca);
   if ( rc != SQL_SUCCESS) printf("RC = %ld\n", rc);
   memcpy(ca, &sqlca, sizeof(struct sqlca));

   SQLFreeStmt(hstmt, SQL_DROP);

   SQLDisconnect(hdbc);
   SQLFreeConnect(hdbc);
   SQLFreeEnv(henv);
*/

   return(SQLZ_DISCONNECT_PROC);
}
/*<-- */

int
dumpSQLCA (struct sqlca sqlca)
{
int  i = 0;
char state[6];

   printf("Dumping SQLCA\n");
   printf("SQLCODE = %ld\n", sqlca.sqlcode);
   strncpy(state, sqlca.sqlstate, 5);
   state[5] = '\0';
   printf("SQLSTATE = %s\n", state);

   for (i = 0; i < 6; i++)
   {   printf("  SQLERRD[%ld] = %ld\n", i, sqlca.sqlerrd[i]);
   }
   for (i = 0; i < 11; i++)
   {   printf("  SQLWARN[%ld] = %c\n", i, sqlca.sqlwarn[i]);
   }
}


/*******************************************************************************
* PROCEDURE : print_var
* The following procedure prints out a SQLDA SQLVAR variable.
*
*******************************************************************************/
void print_var (char *ptr, int type, long length)
{
   short idx, ind ;            /* Array idx variables */
   /* Variables for decoding packed decimal data */
   short bottom, point ;
   unsigned short top, precision, scale;

   int i;


   /*
   ** Determine the type of data, coerce or decode the data for output
   ** if necessary, then output the data (or first 20 characters).
   */

   switch ( type ) {
      case SQL_TYP_INTEGER:   /* long */
      case SQL_TYP_NINTEGER:  /* long with null indicator */
         printf("%ld", *(long *) ptr) ;
         prbuf += sprintf(prbuf, "%ld", *(long *) ptr) ;
         break ;
      case SQL_TYP_SMALL:     /* short */
      case SQL_TYP_NSMALL:    /* short with null indicator */
         printf("%d",  *(short *) ptr ) ;
         prbuf += sprintf(prbuf, "%d",  *(short *) ptr ) ;
         break ;
      case SQL_TYP_DECIMAL:   /* decimal */
      case SQL_TYP_NDECIMAL:  /* decimal with null indicator */
      /* Determine the scale and precision */
         /* Precsion is 1 byte of short, 3 byte of long length */
         /* Scale is 2 byte of short, 4 byte of long length */
         precision = ((char *)&(length))[2];
         scale = ((char *)&(length))[3];

/*****************************************************************************/
/* Note:  Precision can only be odd because internally only odd are stored.  */
/*        When and if it happens that an even precision can occur, the       */
/*        precision must be incremented by 1 in order for the proper         */
/*        calculation of "idx" and "point" to occur, and the correct value */
/*        outputted.                                                         */
/*****************************************************************************/
         if ((precision %2) == 0) precision += 1;

         /* Calculate the total number of bytes */
         idx = ( precision + 2 ) / 2 ;
         point = precision - scale ;

         /* Determine the sign */
         bottom = *(ptr + idx -1) & 0x000F ;   /* sign */
         if ( (bottom == 0x000D) || (bottom == 0x000B) ) {
            printf("-") ;
            prbuf += sprintf(prbuf, "-") ;
         } else {
            printf(" ") ;
            prbuf += sprintf(prbuf, " ") ;
         }


         /* Decode and print the decimal number */
         for (ind=0; ind < idx; ind++) {
            top = *(ptr + ind) & 0x00F0 ;
            top = (top >> 4 ) ;
            bottom = *(ptr + ind) & 0x000F ;
               if ( point-- == 0 ) 
               {   printf(".") ;
                   prbuf += sprintf(prbuf, ".");
               }
               printf("%d", top ) ;
               prbuf += sprintf(prbuf, "%d", top ) ;
/*****************************************************************************/
/* Ignore bottom of last half byte because its the sign.                     */
/*****************************************************************************/
            if ( ind < idx - 1 ) { /* sign half byte ? */
               if ( point-- == 0 )
               {   printf(".") ;
                   prbuf += sprintf(prbuf, ".");
               }
               printf("%d", bottom ) ;
               prbuf += sprintf(prbuf, "%d", bottom ) ;
            }
         }
         if ( scale == 0 ) 
         {  printf(".") ;
            prbuf += sprintf(prbuf, ".") ;
         }
         break ;

      case SQL_TYP_FLOAT:  /* double */
      case SQL_TYP_NFLOAT: /* double with null indicator */
         printf("%e", *(double *) ptr) ;
         prbuf += sprintf(prbuf, "%e", *(double *) ptr) ;
         break ;
      case SQL_TYP_CLOB:  /* Character LOB */
      case SQL_TYP_NCLOB:
      case SQL_TYP_CHAR:  /* fixed length character string */
      case SQL_TYP_NCHAR: /* fixed length character string with null
                             indicator */
         printf ("%-20.20s", ptr);
         prbuf += sprintf (prbuf, "%-20.20s", ptr);
         break;
      case SQL_TYP_DBCLOB:  /* Double-Byte Character LOB */
      case SQL_TYP_NDBCLOB:
      case SQL_TYP_BLOB:  /* Binary LOB */
      case SQL_TYP_NBLOB:
         for (i = 0; i<20 && i<length; i++)
         {  printf("%02X", (int)ptr[i]);
            prbuf += sprintf(prbuf, "%02X", (int)ptr[i]);
         }
         printf (" ");
         prbuf += sprintf (prbuf, " ");
         break;
      case SQL_TYP_VARCHAR:
      case SQL_TYP_NVARCHAR:
         /* Print a maximum of the first 20 characters */
         printf ("%-20.*s", min( ((struct sqlchar *)ptr)->length, 20 ),
                ((struct sqlchar *)ptr)->data);
         prbuf += sprintf (prbuf, "%-20.*s", 
                           min( ((struct sqlchar *)ptr)->length, 20 ),
                           ((struct sqlchar *)ptr)->data);
         break;

      case SQL_TYP_CSTR:  /* null terminated varying length character string */
      case SQL_TYP_NCSTR: /* null terminate varying length character
                              string with null indicator */
         break ;
         printf ("%-20.20s", ptr);
         prbuf += sprintf (prbuf, "%-20.20s", ptr);
      default:
         /* Unknown data type */
         printf("%-20.20s", "UNKNOWN");
         prbuf += sprintf(prbuf, "%-20.20s", "UNKNOWN");
         break ;
   }
}

/*******************************************************************************
* PROCEDURE : update_var
*   Updates the SQLDA SQLVAR variables.
*
*******************************************************************************/
void update_var (char *ptr, int type, long length)
{
   short idx, ind ;            /* Array idx variables */
   /* Variables for decoding packed decimal data */
   short bottom, point ;
   unsigned short top, precision, scale;

   int i;
   char tc;

   /*
   ** Determine the type of data, then update
   */

   switch ( type ) {
      case SQL_TYP_INTEGER:   /* long */
      case SQL_TYP_NINTEGER:  /* long with null indicator */
         *(long *) ptr = 99999;
         break ;
      case SQL_TYP_SMALL:     /* short */
      case SQL_TYP_NSMALL:    /* short with null indicator */
         *(short *) ptr = 999;
         break ;
      case SQL_TYP_DECIMAL:   /* decimal */
      case SQL_TYP_NDECIMAL:  /* decimal with null indicator */
      /* Determine the scale and precision */
         /* Precsion is 1 byte of short, 3 byte of long length */
         /* Scale is 2 byte of short, 4 byte of long length */
         precision = ((char *)&(length))[2];
         scale = ((char *)&(length))[3];

         if ((precision %2) == 0) precision += 1;
         /* Calculate the total number of bytes */
         idx = ( precision + 2 ) / 2 ;

         /* Reverse the sign */
         bottom = (*(ptr + idx -1) & 0x000F);   /* sign */
         if ( (bottom == 0x000C) ) /* Positive, set negative */
         {  *(ptr + idx -1) = (*(ptr + idx -1) & 0xFFF0) | 0x000D;
         } else  
         {  *(ptr + idx -1) = (*(ptr + idx -1) & 0xFFF0) | 0x000C;
         }
         break ;

      case SQL_TYP_FLOAT:  /* double */
      case SQL_TYP_NFLOAT: /* double with null indicator */
         *(double *) ptr = 99.99;
         break ;
      case SQL_TYP_CLOB:  /* Character LOB */
      case SQL_TYP_NCLOB:
      case SQL_TYP_CHAR:  /* fixed length character string */
      case SQL_TYP_NCHAR: /* fixed length character string with null
                             indicator */
         /* Reverse String */
         for (i=0;i<length/2;i++ ) {
           tc = ptr[i];
           ptr[i] = ptr[length-i-1];
           ptr[length-i-1] = tc;
         } /* endfor */

         break;
      case SQL_TYP_DBCLOB:  /* Double-Byte Character LOB */
      case SQL_TYP_NDBCLOB:
      case SQL_TYP_BLOB:  /* Binary LOB */
      case SQL_TYP_NBLOB:
         /* Reverse String */
         for (i=0;i<length/2;i++ ) {
           tc = ptr[i];
           ptr[i] = ptr[length-i-1];
           ptr[length-i] = tc;
         } /* endfor */
         break;
      case SQL_TYP_VARCHAR:
      case SQL_TYP_NVARCHAR:
         /* Reverse String */
         for (i=0;i<length/2;i++ ) {
           tc = ((struct sqlchar *)ptr)->data[i];
           ((struct sqlchar *)ptr)->data[i] =
               ((struct sqlchar *)ptr)->data[length-i-1];
           ((struct sqlchar *)ptr)->data[length-i-1] = tc;
         } /* endfor */
         break;

      case SQL_TYP_CSTR:  /* null terminated varying length character string */
      case SQL_TYP_NCSTR: /* null terminate varying length character
                              string with null indicator */
         break ;
         sprintf (ptr,"%-*.*s", length, length, "!");
      default:
         /* Unknown data type */
         break ;
   }
}

/*******************************************************************************
* PROCEDURE : display_update_da
*             Displays SQLDA information, calls display_var to display the 
*             value of each SQLVAR entry, calls update_var to update the
*             value of each SQLVAR entry.
*******************************************************************************/
void display_update_da (struct sqlda *sqldaPointer) {
   short variableIndex, numBytes, sqlvarIndex, nullIndicator;
   short sqltype;
   short isnull;
   short *indptr;
   long  *lenptr;
   long  length;
   long  width;
   char  value[20];

   struct lob {
      long length;
      char *data;
   } *lobPointer;

   /* Output the contents for all host variables */
   for(sqlvarIndex=0;sqlvarIndex < sqldaPointer->sqld; sqlvarIndex++) {

      sqltype = sqldaPointer->sqlvar[sqlvarIndex].sqltype;
      indptr = sqldaPointer->sqlvar[sqlvarIndex].sqlind;

      printf("SQLVAR[%d] : Type = %ld ", sqlvarIndex, sqltype);
      prbuf += sprintf(prbuf, "SQLVAR[%d] : Type = %ld ", sqlvarIndex, sqltype);

      /* If sqltype is odd, then type is nullable */
      if (sqltype & 1)
         printf(" Nullable     ");
      else
         printf(" Not Nullable ");

      if ( (indptr != NULL ) && (*(indptr) < 0) )
          isnull = 1;
      else
          isnull = 0;

       switch (sqltype) {
         case SQL_TYP_CLOB:
         case SQL_TYP_NCLOB:
         case SQL_TYP_BLOB:
         case SQL_TYP_NBLOB:
         case SQL_TYP_DBCLOB:
         case SQL_TYP_NDBCLOB:
         /* LOB type, get lob length */
            lenptr = (long *)GETSQLDALENPTR(sqldaPointer, sqlvarIndex);
            if (lenptr == NULL)
                length = ((struct lob *)
                         (sqldaPointer->sqlvar[sqlvarIndex].sqldata))->length;
            else
                length = *lenptr;
            width = GETSQLDALONGLEN(sqldaPointer, sqlvarIndex);

            if (isnull == 0) 
            {  printf("Length = %ld Width=%ld\n", length, width);
               prbuf += sprintf(prbuf, "Length = %ld Width=%ld\n", length, width);
            }
            break;
         case SQL_TYP_VARCHAR:
         case SQL_TYP_NVARCHAR:
            length = ((struct sqlchar *) 
                     (sqldaPointer->sqlvar[sqlvarIndex].sqldata))->length;
            width = sqldaPointer->sqlvar[sqlvarIndex].sqllen;
            if (isnull == 0) 
            {  printf("Length = %ld Width=%ld\n", length, width);
               prbuf += sprintf(prbuf, "Length = %ld Width=%ld\n", length, width);
            }
           
           break;
         case SQL_TYP_DECIMAL:   /* decimal */
         case SQL_TYP_NDECIMAL:  /* decimal with null indicator */
            /* Precision is 1 byte of sqllen */
            /* Scale is 2 byte of sqllen     */
            if (isnull == 1) break; /* Null, no info */
            printf("Precision= %d Scale = %d\n",
                   ((char *)&(sqldaPointer->sqlvar[sqlvarIndex].sqllen))[0],
                   ((char *)&(sqldaPointer->sqlvar[sqlvarIndex].sqllen))[1]);
            prbuf += sprintf(prbuf, "Precision= %d Scale = %d\n",
                   ((char *)&(sqldaPointer->sqlvar[sqlvarIndex].sqllen))[0],
                   ((char *)&(sqldaPointer->sqlvar[sqlvarIndex].sqllen))[1]);
            length = sqldaPointer->sqlvar[sqlvarIndex].sqllen;
            break;

         default:
            length = (sqldaPointer->sqlvar[sqlvarIndex].sqllen);
            if (isnull == 0) 
            {  printf("Length = %ld\n", length);
               prbuf += sprintf(prbuf, "Length = %ld\n", length);
            }
            break;
         } /* endswitch */
      /* If indptr is not NULL, and the indicator is < 0, the value is null */
      if (isnull == 1)
      {   printf("\n            Value = NULL");
          prbuf += sprintf(prbuf, "\n            Value = NULL");
      }
      else
      {   printf("            Value = ");
          prbuf += sprintf(prbuf, "            Value = ");
          print_var(sqldaPointer->sqlvar[sqlvarIndex].sqldata,
                    sqltype, length);
          update_var(sqldaPointer->sqlvar[sqlvarIndex].sqldata,
                    sqltype, length);
      }
      printf("\n") ;
      prbuf += sprintf(prbuf, "\n") ;
   } /* endfor */
}

