/*******************************************************************************
**                                                                        
** Source File Name = showpic.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
**        - Displays all employees with pictures, and prompts the user to
**          select a picture (BLOB) from the emp_photo table
**        - Writes a file to the current directory of the indicated type
**        - xwud is used to display the xwd format  (unix)
**        - iconedit is used to display the bitmap format (OS/2)
**          (edit this file to use a different viewer).
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindCol
**        SQLBindFileToCol
**        SQLDisconnect
**        SQLExecDirect
**        SQLFetch
**        SQLFreeConnect
**        SQLFreeEnv
**        SQLFreeStmt
**        SQLSetParam
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255
#define ROWSET_SIZE  10

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;
/*--> SQLL1X33.SCRIPT */
    SQLCHAR         stmt1[] =
"select employee.empno, firstnme || lastname as name from employee, emp_photo "
" where employee.empno = emp_photo.empno and photo_format = ?";

    SQLCHAR         stmt2[] =
    "SELECT picture FROM emp_photo WHERE empno  = ? AND photo_format = ?";
/*<-- */

    SQLCHAR         Photo_Format[11] = {""};
    SQLCHAR         Desc[61];
    struct {
              SQLINTEGER      ind;
              SQLCHAR         s[30];
           } Name;
    struct {
              SQLINTEGER      ind;
              SQLCHAR         s[7];
           } Empno;

    SQLUINTEGER     FOption = SQL_FILE_OVERWRITE;
    SQLINTEGER      FNInd = 0;
    SQLINTEGER      Pic_Length = 0;
    SQLSMALLINT     FNLength = 13;
    SQLCHAR         FName[13];
    char            buffer[256] = "";

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    /* Get picture */
    while (1) {
        printf("Which Picture Format [xwd (XWindows), bitmap, gif ]?\n");
        gets((char *)Photo_Format);
        if (strcmp((char *)Photo_Format, "xwd") == 0 ||
            strcmp((char *)Photo_Format, "bitmap") == 0 ||
            strcmp((char *)Photo_Format, "gif") == 0) break;
        printf("Invalid Format!\n");
    }

    rc = SQLSetParam(hstmt, 1, SQL_C_CHAR, SQL_CHAR, 11, 0, Photo_Format, NULL);
    CHECK_STMT(hstmt, rc);

    rc = SQLExecDirect(hstmt, stmt1, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 1, SQL_C_CHAR, Empno.s, 7, &Empno.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 2, SQL_C_CHAR, Name.s, 30, &Name.ind);
    CHECK_STMT(hstmt, rc);

    printf("Empno   Name \n");
    printf("------- ---------------------\n");
    while ((rc = SQLFetch(hstmt)) == SQL_SUCCESS) {
        printf("%-6s %-30s \n", Empno.s, Name.s);
    }
    if (rc != SQL_NO_DATA_FOUND)
        check_error(henv, hdbc, hstmt, rc, __LINE__, __FILE__);

    rc = SQLFreeStmt(hstmt, SQL_DROP);
    CHECK_STMT(hstmt, rc);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_STMT(hstmt, rc);

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_STMT(hstmt, rc);

    rc = SQLSetParam(hstmt, 1, SQL_C_CHAR, SQL_CHAR, 7, 0,
                     Empno.s, &Empno.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLSetParam(hstmt, 2, SQL_C_CHAR, SQL_CHAR, 11, 0, Photo_Format,
                     NULL);
    CHECK_STMT(hstmt, rc);

/*--> */
    /* Get Employee Number */
    printf("Select a Employee Number from the list above\n");
    gets((char *)Empno.s);

    /* Execute statement 2 which selects the picturee blob */
    rc = SQLExecDirect(hstmt, stmt2, SQL_NTS);
    CHECK_STMT(hstmt, rc);

    /* Bind blob column to a file */
    rc = SQLBindFileToCol(hstmt, 1, FName, &FNLength, &FOption,
                          13, NULL, &FNInd);
    CHECK_STMT(hstmt, rc);

    /* Set deferred FName argument to putput file name.  */
    switch (Photo_Format[0]) {
    case 'x':
        sprintf((char *)FName, "P%s.xwd", Empno.s, Photo_Format);
        sprintf(buffer, "xwud -in %s &", FName);
        printf("xwud will be used to display image\n");
        break;
    case 'b':
        sprintf((char *)FName, "P%s.bmp", Empno.s, Photo_Format);
        sprintf(buffer, "iconedit %s", FName);
#if !defined(DB2WIN)
        printf("iconedit will be used to display image\n");
#endif
        break;
    case 'g':
        sprintf((char *)FName, "P%s.gif", Empno.s, Photo_Format);
        printf("Will create file: %s\n", FName);
        break;
    default :
        sprintf((char *)FName, "P%s.pic", Empno.s, Photo_Format);
        printf("Unknown Format, will attempt to create file: %s \n", FName);
    }

    /* Fetch the blob column into the bound file */
    rc = SQLFetch(hstmt);
    CHECK_STMT(hstmt, rc);

    printf("%s has been sucessfully Created\n", FName);

#if !defined(DB2WIN)
    /*If supported, execute local display tool with the file just created */
    if (buffer[0] != '\0' ) system(buffer);
#endif
/*<-- */
    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    printf(">Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    rc = SQLFreeConnect(hdbc);
    if (rc != SQL_SUCCESS)
        check_error(henv, hdbc, SQL_NULL_HSTMT, rc, __LINE__, __FILE__);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
