/*******************************************************************************
**                                                                        
** Source File Name = tables.c  %I%                                      
**                                                                        
** Licensed Materials - Property of IBM                                   
**                                                                        
** (C) COPYRIGHT International Business Machines Corp. 1995               
** All Rights Reserved.                                                   
**                                                                        
** US Government Users Restricted Rights - Use, duplication or            
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      
**                                                                        
**                                                                        
**    PURPOSE :                                                           
** Example using SQLColumns
** - prompts for pattern search values for schema name, table name
** - list all columns for the indicated tables
**
** SQLBindCol & SQLFetch is used to retrive data from the result set
** directly into application storage.
**                                                                        
**    FUNCTIONS USED :                                                    
**        SQLAllocEnv
**        SQLAllocStmt
**        SQLBindCol
**        SQLDisconnect
**        SQLFetch
**        SQLFreeConnect
**        SQLFreeEnv
**                                                                        
**                                                                        
*******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "sqlcli.h"
#include "sqlcli1.h"
#include "samputil.h"           /* Header file for CLI sample code */

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Need to include ASLM for 68K applications */
   #include <LibraryManager.h>
#endif

#define MAX_STMT_LEN 255

/* Global Variables for user id and password.
   To keep samples simple, not a recommended practice.
*/
    SQLCHAR   server[SQL_MAX_DSN_LENGTH + 1];
    SQLCHAR   uid[MAX_UID_LENGTH + 1];
    SQLCHAR   pwd[MAX_PWD_LENGTH + 1];

/*******************************************************************
** main
*******************************************************************/
int
main( int argc, char * argv[] )
{
    SQLHENV         henv;
    SQLHDBC         hdbc;
    SQLHSTMT        hstmt;
    SQLRETURN       rc;

    struct {   SQLINTEGER   ind;
               SQLCHAR      s[129];
           } table_qual, table_schem, table_name, table_type; 

    struct {   SQLINTEGER  ind;
               SQLCHAR     s[255];
           } remarks;

/* For the Macintosh environment when generating 68K applications */
#ifdef DB268K
   /* Before making any API calls for 68K environment, need to initialize the
      Library Manager */
   InitLibraryManager(0,kCurrentZone,kNormalMemory);
   atexit(CleanupLibraryManager);
#endif

 /* macro to initalize server, uid and pwd */
    INIT_UID_PWD;

    rc = SQLAllocEnv(&henv);    /* allocate an environment handle    */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = DBconnect(henv, &hdbc);/* allocate a connect handle, and connect */
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    rc = SQLAllocStmt(hdbc, &hstmt);
    CHECK_DBC(hdbc, rc);

    printf("Enter Table Schema Name Search Pattern:\n");
    gets((char *)table_schem.s);
    printf("Enter Table Name Search Pattern:\n");
    gets((char *)table_name.s);

    rc = SQLTables(hstmt, NULL, 0, table_schem.s, SQL_NTS,
                   table_name.s, SQL_NTS, NULL, 0);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 1, SQL_C_CHAR, (SQLPOINTER) table_qual.s, 129,
                    &table_qual.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 2, SQL_C_CHAR, (SQLPOINTER) table_schem.s, 129,
                    &table_schem.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 3, SQL_C_CHAR, (SQLPOINTER) table_name.s, 129,
                    &table_name.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 4, SQL_C_CHAR, (SQLPOINTER) table_type.s, 129,
                    &table_type.ind);
    CHECK_STMT(hstmt, rc);

    rc = SQLBindCol(hstmt, 5, SQL_C_CHAR, (SQLPOINTER) remarks.s, 255,
                    &remarks.ind);
    CHECK_STMT(hstmt, rc);

    printf("TABLE SCHEMA              TABLE_NAME                TABLE_TYPE\n");
    printf("------------------------- ------------------------- ----------\n");
    /* Fetch each row, and display */
    while ((rc = SQLFetch(hstmt)) == SQL_SUCCESS) {
        printf("%-25s %-25s %-11s\n", table_schem.s, table_name.s, table_type.s);
        if (remarks.ind > 0) {
            printf("  (Remarks ) %s\n", remarks.s);
        }
    }                           /* endwhile */

    if (rc != SQL_NO_DATA_FOUND)
        check_error(henv, hdbc, hstmt, rc, __LINE__, __FILE__);

    rc = SQLTransact(henv, hdbc, SQL_COMMIT);
    CHECK_DBC(hdbc, rc);

    printf("Disconnecting .....\n");
    rc = SQLDisconnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeConnect(hdbc);
    CHECK_DBC(hdbc, rc);

    rc = SQLFreeEnv(henv);
    if (rc != SQL_SUCCESS)
        return (terminate(henv, rc));

    return (SQL_SUCCESS);
}                               /* end main */
