*******************************************************************************
**
** Source File Name = client.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use CLIENT APIs in order to:
**          - set a client
**          - and query a client
**
**    APIs USED :
**       SET CLIENT                     sqlgsetc
**       QUERY CLIENT                   sqlgqryc
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**          printquery :      Displays the data in each of the connection
**                            settings returned from the QUERY CLIENT API
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program client
      implicit none

*--> sqlb0x02.fortran
      include 'sql.f'
      include 'sqlenv.f'
      include 'sqlca_cn.f'

      integer*4         rc
      integer*2         numsettings      /5/
*<--
      character*80      errloc

*-->
* Connection Setting Array declaration.
      character         conn_setting (5 * sqle_conn_setting_struct_sz)

      integer*2         conset_item1
      integer*2         conset_item2
      integer*2         conset_item3
      integer*2         conset_item4
      integer*2         conset_item5
      parameter         (conset_item1 = 0*sqle_conn_setting_struct_sz)
      parameter         (conset_item2 = 1*sqle_conn_setting_struct_sz)
      parameter         (conset_item3 = 2*sqle_conn_setting_struct_sz)
      parameter         (conset_item4 = 3*sqle_conn_setting_struct_sz)
      parameter         (conset_item5 = 4*sqle_conn_setting_struct_sz)

      integer*2         conset_type1    ! First conn_setting item
      integer*2         conset_val1

      integer*2         conset_type2    ! Second conn_setting item
      integer*2         conset_val2

      integer*2         conset_type3    ! Third conn_setting item
      integer*2         conset_val3

      integer*2         conset_type4    ! Fourth conn_setting item
      integer*2         conset_val4

      integer*2         conset_type5    ! Fifth conn_setting item
      integer*2         conset_val5

      equivalence (conn_setting(conset_item1 +
     +             sqle_conn_setting_type_ofs), conset_type1)
      equivalence (conn_setting(conset_item2 +
     +             sqle_conn_setting_type_ofs), conset_type2)
      equivalence (conn_setting(conset_item3 +
     +             sqle_conn_setting_type_ofs), conset_type3)
      equivalence (conn_setting(conset_item4 +
     +             sqle_conn_setting_type_ofs), conset_type4)
      equivalence (conn_setting(conset_item5 +
     +             sqle_conn_setting_type_ofs), conset_type5)

      equivalence (conn_setting(conset_item1 +
     +             sqle_conn_setting_value_ofs), conset_val1)
      equivalence (conn_setting(conset_item2 +
     +             sqle_conn_setting_value_ofs), conset_val2)
      equivalence (conn_setting(conset_item3 +
     +             sqle_conn_setting_value_ofs), conset_val3)
      equivalence (conn_setting(conset_item4 +
     +             sqle_conn_setting_value_ofs), conset_val4)
      equivalence (conn_setting(conset_item5 +
     +             sqle_conn_setting_value_ofs), conset_val5)
*<--

      integer*2         temp_val1
      integer*2         temp_val2
      integer*2         temp_val3
      integer*2         temp_val4
      integer*2         temp_val5


* Main Program Body.
      print *, 'Sample Fortran program : CLIENT.F'
      print *, ' '

      conset_type1 = sql_connect_type
      conset_type2 = sql_rules
      conset_type3 = sql_disconnect
      conset_type4 = sql_syncpoint
      conset_type5 = sql_max_netbios_connections

      print *, 'QUERY CLIENT*******************************************'
*-->
********************
*     QUERY CLIENT *
********************
      rc = sqlgqryc (%ref(conn_setting),
     +               %val(numsettings),
     +               %ref(sqlca))
*<--
      errloc = 'QUERY CLIENT'
      call checkerr (sqlca, errloc, *999)

      call printquery (conset_val1, conset_val2, conset_val3,
     +                 conset_val4, conset_val5)

      temp_val1 = conset_val1
      temp_val2 = conset_val2
      temp_val3 = conset_val3
      temp_val4 = conset_val4
      temp_val5 = conset_val5

      conset_val1 = sql_connect_2
      conset_val2 = sql_rules_std
      conset_val3 = sql_disconnect_cond
      conset_val4 = sql_sync_twophase
      conset_val5 = 254

      print *, 'SET CLIENT*********************************************'
      print *, 'connect type            = SQL_CONNECT_2'
      print *, 'rules                   = SQL_RULES_STD'
      print *, 'disconnect              = SQL_DISCONNECT_COND'
      print *, 'syncpoint               = SQL_SYNC_TWOPHASE'
      print *, 'max netbios conn.       = 254'

*-->
******************
*     SET CLIENT *
******************
      rc = sqlgsetc (%ref(conn_setting),
     +               %val(numsettings),
     +               %ref(sqlca))
*<--
      errloc = 'SET CLIENT'
      call checkerr (sqlca, errloc, *999)

      print *, 'QUERY CLIENT*******************************************'
********************
*     QUERY CLIENT *
********************
      rc = sqlgqryc (%ref(conn_setting),
     +               %val(numsettings),
     +               %ref(sqlca))
      errloc = 'QUERY CLIENT'
      call checkerr (sqlca, errloc, *999)

      call printquery (conset_val1, conset_val2, conset_val3,
     +                 conset_val4, conset_val5)

      conset_val1 = temp_val1
      conset_val2 = temp_val2
      conset_val3 = temp_val3
      conset_val4 = temp_val4
      conset_val5 = temp_val5

      print *, 'SET CLIENT back to original settings ******************'
******************
*     SET CLIENT *
******************
      rc = sqlgsetc (%ref(conn_setting),
     +               %val(numsettings),
     +               %ref(sqlca))
      errloc = 'SET CLIENT to original settings'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end



*******************************************************************************
* SUBROUTINE : printquery
*
* PURPOSE : This subroutine displays the data contained in each of the
*           connection settings returned from the Query Client API
*
*******************************************************************************
      subroutine printquery (conset_val1, conset_val2, conset_val3,
     +                       conset_val4, conset_val5)
      integer*2 conset_val1
      integer*2 conset_val2
      integer*2 conset_val3
      integer*2 conset_val4
      integer*2 conset_val5

      include 'sql.f'


      print *, ' '
      print *, ' '

* SQL CONNECTION TYPES
      print *, ' '
      print *, 'SQL CONNECTION TYPE'
      print *, '==================='
      if (conset_val1 .eq. sql_connect_1) then
         print *, 'Type 1 CONNECTs enforce the single database per'
         print *, 'unit of work semantics of older releases, also known'
         print *, 'as the rules for remote unit of work (RUOW)'
         print *, '  TYPE = SQL_1'
      endif

      if (conset_val1 .eq. sql_connect_2) then
        print *, 'Type 2 CONNECTs support the multiple databases per'
        print *, 'unit of work semantics of DUOW'
        print *, '  TYPE = SQL_2'
      endif

* SQL RULES
      print *, ' '
      print *, 'SQL RULES'
      print *, '========='
      if (conset_val2 .eq. sql_rules_db2) then
        print *, 'Enable the SQL CONNECT statement to switch the '
        print *, 'current connection to anextablished (dorman)'
        print *, 'connection.'
        print *, '  TYPE = SQL_DB2'
      endif

      if (conset_val2 .eq. sql_rules_std) then
        print *, 'Permit only the establishment of a new connection'
        print *, 'through the SQL CONNECT statement.  The SQL SET'
        print *, 'CONNECTION statement must be used to switch the '
        print *, 'current connection to a dormant connection.'
        print *, '  TYPE = SQL_STD'
      endif

* SQL DISCONNECT
      print *, ' '
      print *, 'SQL DISCONNECT'
      print *, '=============='
      if (conset_val3 .eq. sql_disconnect_expl) then
        print *, 'Breaks those connections that have been explicitly'
        print *, 'marked for release by the SQL RELEASE statement at'
        print *, 'commit.'
        print *, '  TYPE = SQL_EXPLICIT'
      endif

      if (conset_val3 .eq. sql_disconnect_cond) then
        print *, 'Breaks those connections that have no open WITH'
        print *, 'HOLD cursors at commit, and those that have been'
        print *, 'marked for release by the SQL RELEASE statement.'
        print *, '  TYPE = SQL_CONDITIONAL'
      endif

      if (conset_val3 .eq. sql_disconnect_auto) then
        print *, 'Breaks all connections to commit.'
        print *, '  TYPE = SQL_AUTO'
      endif

* SQL SYNC POINT
      print *, ' '
      print *, 'SQL SYNCPOINT'
      print *, '============='
      if (conset_val4 .eq. sql_sync_twophase) then
        print *, 'Requires a Transaction Manager (TM) to coordinate'
        print *, 'two-phase commits among databases that support this'
        print *, 'protocol.'
        print *, '  TYPE = SQL_ONEPHASE'
      endif

      if (conset_val4 .eq. sql_sync_onephase) then
        print *, 'Uses one-phase commits to commit thw workd done by'
        print *, 'each database in multiple  database transactions.'
        print *, 'Enforces single updater, multiple read behaviour.'
        print *, '  TYPE = SQL_ONEPHASE'
      endif

      if (conset_val4 .eq. sql_sync_none) then
        print *, 'Does not enforce two-phase commits, or single'
        print *, 'updater, multiple read behaviour.'
        print *, '  TYPE = SQL_NONE'
      endif

* SQL MAX NETBIOS CONNECTIONS
      print *, ' '
      print *, 'SQL MAX NETBIOS CONNECTIONS'
      print *, '==========================='
      print *, 'This specifies the maximum number of concurrent'
      print *, 'connections that can be made using a NETBIOS'
      print *, 'adapter in an application.'
      print *, ' CONNECTIONS = ', conset_val5

      print *, ' '
      print *, ' '
      return
      end
