*******************************************************************************
**
** Source File Name = dbauth.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**       This program is an example of how APIs are implemented in order to
**          obtain and print out authorization information of the current user
**          to the currenlty attached database.
**       This program needs the embedded SQL calls in order to connect to
**          an existing database, then to create a temporary table to work with.
**
**    STRUCTURES USED :
**       sql_authorizations
**       sqlca
**
**    APIs USED :
**       GET AUTHORIZATION     sqlgadau
**
**    FUNCTIONS DECLARED :
**       'C' COMPILER LIBRARY :
**          stdio.h  -  printf
**
**       DBMS LIBRARY :
**          sqlenv.h -  see "APIs USED" above
**
**    OTHER FUNCTIONS USED :
**       internal :
**          list_auth :       Displays the authorization rights of the
**                               current user
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbauth
      implicit none

*--> sqlb0x05.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      EXEC SQL INCLUDE SQLCA
*<--

      EXEC SQL BEGIN DECLARE SECTION
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

*-->
      integer*4         rc
*<--
      character*80      errloc
      character*3       authority


*-->
* Authorization Structure to be used with GET AUTHORIZATIONS API
      character         auths(sql_authorizations_struct_sz)
      integer*2         auth_len

      integer*2         sysadm_auth
      integer*2         sysctrl_auth
      integer*2         sysmaint_auth
      integer*2         dbadm_auth
      integer*2         createtab_auth
      integer*2         bindadd_auth
      integer*2         connect_auth
      integer*2         create_not_fenc_auth

      integer*2         sysadm_grp_auth
      integer*2         sysctrl_grp_auth
      integer*2         sysmaint_grp_auth
      integer*2         dbadm_grp_auth
      integer*2         createtab_grp_auth
      integer*2         bindadd_grp_auth
      integer*2         connect_grp_auth
      integer*2         create_not_fenc_grp_auth


      equivalence (auth_len,     auths(sql_auth_authorizations_len_ofs))

      equivalence (sysadm_auth,         auths(sql_auth_sysadm_auth_ofs))
      equivalence (sysctrl_auth,       auths(sql_auth_sysctrl_auth_ofs))
      equivalence (sysmaint_auth,     auths(sql_auth_sysmaint_auth_ofs))
      equivalence (dbadm_auth,           auths(sql_auth_dbadm_auth_ofs))
      equivalence (createtab_auth,   auths(sql_auth_createtab_auth_ofs))
      equivalence (bindadd_auth,       auths(sql_auth_bindadd_auth_ofs))
      equivalence (connect_auth,       auths(sql_auth_connect_auth_ofs))
      equivalence (create_not_fenc_auth,
     +                         auths(sql_auth_crtnfenc_auth_ofs))

      equivalence (sysadm_grp_auth, auths(sql_auth_sysadm_grp_auth_ofs))
      equivalence (sysctrl_grp_auth,
     +                             auths(sql_auth_sysctrl_grp_auth_ofs))
      equivalence (sysmaint_grp_auth,
     +                            auths(sql_auth_sysmaint_grp_auth_ofs))
      equivalence (dbadm_grp_auth,   auths(sql_auth_dbadm_grp_auth_ofs))
      equivalence (createtab_grp_auth,
     +                           auths(sql_auth_createtab_grp_auth_ofs))
      equivalence (bindadd_grp_auth,
     +                             auths(sql_auth_bindadd_grp_auth_ofs))
      equivalence (connect_grp_auth,
     +                             auths(sql_auth_connect_grp_auth_ofs))
      equivalence (create_not_fenc_grp_auth,
     +                     auths(sql_auth_crtnfenc_grp_auth_ofs))

      auth_len = sql_authorizations_struct_sz
*<--


* Main Program body.
      print *, 'Sample Fortran Program: DBAUTH.F'

      print *, 'Enter in your user id :'
      read 100, userid
100   format (a8)      

      print *, 'Enter in your password :'
      read 100, passwd

      EXEC SQL CONNECT TO sample USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

      print *, 'Administrative Authorizations for Current User'
      print *, ' '
*-->
**************************
*     GET AUTHORIZATIONS *
**************************
      rc = sqlgadau (%ref(auths),
     +               %ref(sqlca))
*<--
      errloc = 'GET AUTHORIZATION'
      call checkerr (sqlca, errloc, *999)

* listing the contents of the Authorization Structure
      authority = 'NO '
      if (sysadm_auth .eq. 1) authority = 'YES'
      print *, 'Direct SYSADM authority            = ', authority

      authority = 'NO '
      if (sysctrl_auth .eq. 1) authority = 'YES'
      print *, 'Direct SYSCTRL authority           = ', authority

      authority = 'NO '
      if (sysmaint_auth .eq. 1) authority = 'YES'
      print *, 'Direct SYSMAINT authority          = ', authority

      authority = 'NO '
      if (dbadm_auth .eq. 1) authority = 'YES'
      print *, 'Direct DBADM authority             = ', authority

      authority = 'NO '
      if (createtab_auth .eq. 1) authority = 'YES'
      print *, 'Direct CREATETAB authority         = ', authority

      authority = 'NO '
      if (bindadd_auth .eq. 1) authority = 'YES'
      print *, 'Direct BINDADD authority           = ', authority

      authority = 'NO '
      if (connect_auth .eq. 1) authority = 'YES'
      print *, 'Direct CONNECT authority           = ', authority

      authority = 'NO '
      if (create_not_fenc_auth .eq. 1) authority = 'YES'
      print *, 'Direct CREATE_NOT_FENC authority   = ', authority
      print *, ' '


      authority = 'NO '
      if (sysadm_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect SYSADM authority          = ', authority

      authority = 'NO '
      if (sysctrl_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect SYSCTRL authority         = ', authority

      authority = 'NO '
      if (sysmaint_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect SYSMAINT authority        = ', authority

      authority = 'NO '
      if (dbadm_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect DBADM authority           = ', authority

      authority = 'NO '
      if (createtab_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect CREATETAB authority       = ', authority

      authority = 'NO '
      if (bindadd_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect BINDADD authority         = ', authority

      authority = 'NO '
      if (connect_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect CONNECT authority         = ', authority

      authority = 'NO '
      if (create_not_fenc_grp_auth .eq. 1) authority = 'YES'
      print *, 'Indirect CREATE_NOT_FENC authority = ', authority


      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
