*******************************************************************************
**
** Source File Name = dbcat.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use DATABASE CATALOG APIs in order to:
**          - catalog a database
**          - list a directory of databases (showing what was created)
**          - uncatalog the database
**
**    APIs USED :
**       CATALOG DATABASE                       sqlgctdd()
**       OPEN DATABASE DIRECTORY SCAN           sqlgdosd()
**       GET NEXT DATABASE DIRECTORY ENTRY      sqlgdgne()
**       CLOSE DATABASE DIRECTORY SCAN          sqlgdcls()
**       UNCATALOG DATABASE                     sqlguncd()
**
**    STRUCTURES USED :
**       sqldinfo
**       sqlca
**    OTHER FUNCTIONS USED :
**       internal :
**          list_db :         Displays a directory of databases
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************
      program dbcat
      implicit none

*--> sqlb0x06.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqlca_cn.f'

      integer*4         rc
*<--
      character*80      errloc

* Variables for the CATALOG/UNCATALOG DATABASE APIs
*-->
      integer*2         authentication
      integer*2         comment_len
      integer*2         nname_len
      integer*2         alias_len
      integer*2         db_len
      integer*2         path_len
      integer*2         loc_type_int
      character         loc_type_char2(2)
      character         loc_type
      equivalence       ( loc_type_int, loc_type_char2(1) )
      equivalence       ( loc_type,     loc_type_char2(2) )
      character*(sql_cmt_sz+1)          comment
      character*(sql_nname_sz+1)        nname
      character*(sql_alias_sz+1)        alias
      character*(sql_dbname_sz+1)       dbname
      character         path(sql_path_sz+1)
*<--

* Initialize the DATABASE variables
      authentication = sql_authentication_client
      path_len       = 0
      nname_len      = 0
      loc_type       = sql_indirect
      alias          = 'newalias'
      alias_len      = 8
      dbname         = 'newdata'
      db_len         = 7
      comment        = 'This is a test database'
      comment_len    = 23

* Main program body.
      print *, 'Sample Fortran Program: DBCAT.F'

      print *, 'cataloging the new database...'
*-->
************************
*     CATALOG DATABASE *
************************
      rc = sqlgctdd (%val(comment_len),
     +               %val(path_len),
     +               %val(nname_len),
     +               %val(alias_len),
     +               %val(db_len),
     +               %ref(sqlca),
     +               %val(authentication),
     +               %ref(comment),
     +               %ref(path),
     +               %ref(nname),
     +               %val(loc_type_int),
     +               %ref(alias),
     +               %ref(dbname))
*<--
      errloc = 'CATALOG DATABASE'
      call checkerr (sqlca, errloc, *999)

      print *, 'Listing all databases...'
      print *, '========================'
      call list_db (*999)

      print *, 'UNCATALOGing the database that was created'
*-->
**************************
*     UNCATALOG DATABASE *
**************************
      rc = sqlguncd (%val(alias_len),
     +               %ref(sqlca),
     +               %ref(alias))
*<--
      errloc = 'UNCATALOG DATABASE'
      call checkerr (sqlca, errloc, *999)

      print *, 'Listing all databases [after uncatalogued database]'
      print *, '==================================================='
      call list_db (*999)

  999 stop
      end


*******************************************************************************
* SUBROUTINE : list_db
*
* PURPOSE : This subroutine displays the data contained in each database
*           directory entry, by retrieving the "sqldinfo" structure.
*
*******************************************************************************
      subroutine list_db (*)

*--> sqlb0x33.fortran
      include 'sqlca_cn.f'
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sql.f'

      integer*4 rc
*<--
      character*80 errloc

*     variables declared for the OPEN/CLOSE database directory scan APIs
*-->
      integer*2         idx
      integer*2         path_length
      integer*2         dbHandle
      integer*2         dbCount
      character         path(sql_path_sz+1)

*     variables declared for the GET DATABASE DIRECTORY ENTRY API.
      integer*4 buffer

*     DATABASE DIRECTORY ENTRY structure (SQLEDINFO)
      character         dbdir_info(sqledinfo_struct_sz)
      character*(sql_alias_sz)        alias
      character*(sql_dbname_sz)       dbname
* The "drive" field of the SQLEDINFO is truncated to 50 characters for
* display purposes in this program.  The actual length of this field is 215.
* or "sql_drive_sz" + 1
      character*50                      drive
      character*(sql_iname_sz)          iname
      character*(sql_nname_sz)          nname
      character*(sql_dbtyp_sz)          dbtype
      character*(sql_cmt_sz)            comment
      integer*2         com_codepage
      character         loc_type
      integer*2         authentication

      equivalence (alias, dbdir_info(sqledinfo_alias_ofs))
      equivalence (dbname, dbdir_info(sqledinfo_dbname_ofs))
      equivalence (drive, dbdir_info(sqledinfo_drive_ofs))
      equivalence (iname, dbdir_info(sqledinfo_intname_ofs))
      equivalence (nname, dbdir_info(sqledinfo_nodename_ofs))
      equivalence (dbtype, dbdir_info(sqledinfo_dbtype_ofs))
      equivalence (comment, dbdir_info(sqledinfo_comment_ofs))
      equivalence (com_codepage,
     +             dbdir_info(sqledinfo_com_codepage_ofs))
      equivalence (loc_type, dbdir_info(sqledinfo_type_ofs))
      equivalence (authentication,
     +             dbdir_info(sqledinfo_authentication_ofs))
*<--

* Initialize the database directory scan variables
      path(1) = ' '
      path_length = 0

* Subroutine body.

*-->
************************************
*     OPEN DATABASE DIRECTORY SCAN *
************************************
      rc = sqlgdosd (%val(path_length),
     +               %ref(sqlca),
     +               %ref(dbCount),
     +               %ref(dbHandle),
     +               %ref(path))
*<--
      if (sqlcode .eq. sqle_rc_nodbdir) then
         print *, '--- Database directory is empty ---'
         return
      endif
      errloc = 'OPEN DATABASE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *9999)

      idx = 0
      do 1500 while (idx .lt. dbCount)
         idx = idx + 1
*-->
*****************************************
*     GET NEXT DATABASE DIRECTORY ENTRY *
*****************************************
      rc = sqlgdgne (%val(dbHandle),
     +               %ref(buffer),
     +               %ref(sqlca))
*<--
      errloc = 'GET NEXT DATABASE DIRECTORY ENTRY'
      call checkerr (sqlca, errloc, *9999)

*-->
***************************
*     DEREFERENCE ADDRESS *
***************************
      rc = sqlgdref (%val(sqledinfo_struct_sz),
     +               %ref(dbdir_info),
     +               %ref(buffer))
*<--
      errloc = 'DEREFERENCE ADDRESS API'
      call checkerr (sqlca, errloc, *9999)

      print *, 'alias name :            ', alias
      print *, 'database name :         ', dbname
      print *, 'database drive        = ', drive
      print *, 'database directory    = ', iname
      print *, 'node name             = ', nname
      print *, 'database release type = ', dbtype
      print *, 'database comment      = ', comment
      print *, 'database entry type   = ', loc_type

      print *, 'authentication value :  ', authentication
      if (authentication .eq. sql_authentication_server)
     +print *, 'authentication        = SERVER'
      if (authentication .eq. sql_authentication_client)
     +print *, 'authentication        = CLIENT'
      if (authentication .eq. sql_authentication_dcs)
     +print *, 'authentication        = DCS'

      print *, ' '
1500  end do

*-->
*************************************
*     CLOSE DATABASE DIRECTORY SCAN *
*************************************
      rc = sqlgdcls (%val(dbHandle),
     +               %ref(sqlca))
*<--
      errloc = 'CLOSE DATABASE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *9999)

      return
 9999 return 1
      end
