*******************************************************************************
**
** Source File Name = dbcmt.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**       change the comment for a database.
**
**    STRUCTURES USED :
**       sqledinfo
**       sqlca
**
**    APIs USED :
**            CHANGE DATABASE COMMENT        sqledcgd
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbcmt
      implicit none

*--> sqlb0x25.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqlca_cn.f'
      include 'sql.f'

      integer*4         rc
*<--
      character*80      errloc

*-->
* Variables declared for the OPEN/CLOSE database directory scan APIs
      integer*2         idx
      integer*2         path_length
      integer*2         dbHandle
      integer*2         dbCount
      character         path(sql_path_sz+1)

* Variables declared for the GET DATABASE DIRECTORY ENTRY API.
      integer*4 buffer

*     DATABASE DIRECTORY ENTRY structure (SQLEDINFO)
      character         dbdir_info(sqledinfo_struct_sz)
      character*(sql_alias_sz)        alias
      character*(sql_dbname_sz)       dbname
* The "drive" field of the SQLEDINFO is truncated to 50 characters for
* display purposes in this program.  The actual length of this field is 215.
* or "sql_drive_sz" + 1
      character*50                      drive
      character*(sql_iname_sz)          iname
      character*(sql_nname_sz)          nname
      character*(sql_dbtyp_sz)          dbtype
      character*(sql_cmt_sz)            comment
      integer*2         com_codepage
      character         loc_type
      integer*2         authentication

      equivalence (alias, dbdir_info(sqledinfo_alias_ofs))
      equivalence (dbname, dbdir_info(sqledinfo_dbname_ofs))
      equivalence (drive, dbdir_info(sqledinfo_drive_ofs))
      equivalence (iname, dbdir_info(sqledinfo_intname_ofs))
      equivalence (nname, dbdir_info(sqledinfo_nodename_ofs))
      equivalence (dbtype, dbdir_info(sqledinfo_dbtype_ofs))
      equivalence (comment, dbdir_info(sqledinfo_comment_ofs))
      equivalence (com_codepage,
     +             dbdir_info(sqledinfo_com_codepage_ofs))
      equivalence (loc_type, dbdir_info(sqledinfo_type_ofs))
      equivalence (authentication,
     +             dbdir_info(sqledinfo_authentication_ofs))
*<--

* Variables declared for CHANGE DATABASE COMMENT API
      integer*2         new_comment_len
      integer*2         dbname_len
      character*(sql_cmt_sz+1)  new_comment



* Initialize the database directory scan variables
      path(1) = ' '
      path_length = 0

* Initialize the database comment variables
      new_comment = 'the new comment for sample'
      new_comment_len = 26

* Main Program Body.

      print *, 'Sample Fortran program : DBCMT.F'
      print *, 'opening directory scan'

*-->
******************************
*     INSTALL SIGNAL HANDLER *
******************************
      rc = sqlgisig (%ref(sqlca))
*<--
      errloc = 'INSTALL SIGNAL HANDLER'
      call checkerr (sqlca, errloc, *999)

*-->
************************************
*     OPEN DATABASE DIRECTORY SCAN *
************************************
      rc = sqlgdosd (%val(path_length),
     +               %ref(sqlca),
     +               %ref(dbCount),
     +               %ref(dbHandle),
     +               %ref(path))
*<--
      if (sqlcode .eq. sqle_rc_nodbdir) then
         print *, '--- Database directory is empty ---'
         goto 999
      endif
      errloc = 'OPEN DATABASE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *999)

      idx = 0
      do 150 while (idx .lt. dbCount)
         idx = idx + 1
*-->
*****************************************
*     GET NEXT DATABASE DIRECTORY ENTRY *
*****************************************
      rc = sqlgdgne (%val(dbHandle),
     +               %ref(buffer),
     +               %ref(sqlca))
*<--
      errloc = 'GET NEXT DATABASE DIRECTORY ENTRY'
      call checkerr (sqlca, errloc, *999)

*-->
***************************
*     DEREFERENCE ADDRESS *
***************************
      rc = sqlgdref (%val(sqledinfo_struct_sz),
     +               %ref(dbdir_info),
     +               %ref(buffer))
*<--
      errloc = 'DEREFERENCE ADDRESS API'
      call checkerr (sqlca, errloc, *999)

      if (alias .eq. 'SAMPLE  ') then
         print *, 'alias found'
         dbname_len = index (alias, ' ') -1
         if (dbname_len .lt. 0) dbname_len = sql_dbname_sz

**********************************
*        CHANGE DATABASE COMMENT *
**********************************
         rc = sqlgdcgd (%val(new_comment_len),
     +                  %val(path_length),
     +                  %val(dbname_len),
     +                  %ref(sqlca),
     +                  %ref(new_comment),
     +                  %ref(path),
     +                  %ref(alias))
         errloc = 'CHANGE DATABASE COMMENT'
         call checkerr (sqlca, errloc, *999)
         print *, 'CHANGE DATABASE COMMENT successful'

         goto 150
      endif


      print *, ' '
  150 end do

*-->
*************************************
*     CLOSE DATABASE DIRECTORY SCAN *
*************************************
      rc = sqlgdcls (%val(dbHandle),
     +               %ref(sqlca))
*<--
      errloc = 'CLOSE DATABASE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end

