*******************************************************************************
**
** Source File Name = dbconf.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**       CREATE a DATABASE and then GET the CONFIGURATION information from
**       it, then UPDATE the CONFIGURATION, RESET the CONFIGURATION, then
**       DROP the DATABASE.
**
**    APIs USED :
**       CREATE DATABASE                  sqledbcr()
**       DROP DATABASE                    sqledrpd()
**       GET DATABASE CONFIGURATION       sqlfxdb()
**       UPDATE DATABASE CONFIGURATION    sqlfudb()
**       RESET DATABASE CONFIGURATION     sqlfrdb()
**
**
**    STRUCTURES USED :
**       sqledbcinfo
**       sqlfupd
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**          printinfo :       Displays the database configuration
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbconf
      implicit none

*--> sqlb0x07.fortran
      include 'sqlutil.f'
      include 'sqlenv.f'
      include 'sqlca_cn.f'
      include 'sql.f'
      include 'sqle850b.f'

      integer*4         rc
      integer*2         listnumber      /4/

      integer*2         dbname_len      /6/
      integer*2         dbalias_len     /6/
      integer*2         path_len        /0/

      character*(sql_dbname_sz+1)       dbname          /'dbconf'/
      character*(sql_alias_sz+1)        dbalias         /'dbconf'/
      character         path            /' '/
*<--
      character*80      errloc

*-->
* Variables for DATABASE CONFIGURATION API
*     The number "4" is used to declare the number of items "listnumber" in the
*     "token_list".  This is hardcoded for FORTRAN on AIX inorder to compile
*     properly.
      integer*2         item_lengths (4)
      character         token_list   (4 * sqlfupd_struct_sz)

      integer*2         token1
      integer*2         token2
*<--
      integer*2         token3
      integer*2         token4

*-->
      integer*4         token1ptr
      integer*4         token2ptr
*<--
      integer*4         token3ptr
      integer*4         token4ptr

*-->
      equivalence (token_list(0*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token1)
      equivalence (token_list(1*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token2)
*<--
      equivalence (token_list(2*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token3)
      equivalence (token_list(3*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token4)

*-->
      equivalence (token_list(0*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token1ptr)
      equivalence (token_list(1*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token2ptr)
*<--
      equivalence (token_list(2*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token3ptr)
      equivalence (token_list(3*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token4ptr)

*-->
      integer*2         locklist
      integer*4         buff_page
*<--
      integer*2         maxfilop
      integer*2         softmax

*-->
* Variables for CREATE DATABASE APIs
*     The DATABASE DESCRIPTION BLOCK structure
      character         db_desc(sqledbdesc_struct_sz)
      character*(sqledbdesc_sqldbdid_sz) sqldbdid       /sqle_dbdesc_2/
      integer*4         sqldbccp        /0/
      integer*4         sqldbcss        /0/
      character*(sql_cs_sz)     sqldbudc
      character*(sql_cmt_sz+1)  sqldbcmt
      integer*4         sqldbsgp        /0/
      integer*2         sqldbnsg        /10/
      integer*4         sqltsext        /10/
      integer*4         sqlcatts
      integer*4         sqlusrts
      integer*4         sqltmpts

      equivalence (db_desc(sqledbdesc_sqldbdid_ofs), sqldbdid)
      equivalence (db_desc(sqledbdesc_sqldbccp_ofs), sqldbccp)
      equivalence (db_desc(sqledbdesc_sqldbcss_ofs), sqldbcss)
      equivalence (db_desc(sqledbdesc_sqldbudc_ofs), sqldbudc)
      equivalence (db_desc(sqledbdesc_sqldbcmt_ofs), sqldbcmt)
      equivalence (db_desc(sqledbdesc_sqldbsgp_ofs), sqldbsgp)
      equivalence (db_desc(sqledbdesc_sqldbnsg_ofs), sqldbnsg)
      equivalence (db_desc(sqledbdesc_sqltsext_ofs), sqltsext)
      equivalence (db_desc(sqledbdesc_sqlcatts_ofs), sqlcatts)
      equivalence (db_desc(sqledbdesc_sqlusrts_ofs), sqlusrts)
      equivalence (db_desc(sqledbdesc_sqltmpts_ofs), sqltmpts)

*     the DATABASE COUNTRY INFORMATION structure
      character         db_country(sqledbcountryinfo_struct_sz)
      character*(sqledbcountryinfo_codeset_sz)  sqlcty_codeset
      character*(sqledbcountryinfo_locale_sz)   sqlcty_locale

      equivalence (db_country(sqledbcinfo_sqldbcp_ofs), sqlcty_codeset)
      equivalence (db_country(sqledbcinfo_sqldbcc_ofs), sqlcty_locale)
*<--


* Main Program Body.
      print *, 'Sample Fortran program : DBCONF.F'

*-->
*     Initializing the SQLFUPD structure for the DATABASE CONFIGURATION APIs
      token1 = sqlf_dbtn_locklist
      token2 = sqlf_dbtn_buff_page
*<--
      token3 = sqlf_dbtn_maxfilop
      token4 = sqlf_dbtn_softmax

      errloc = 'GET ADDRESS'
*-->
*******************
*     GET ADDRESS *
*******************
      rc = sqlgaddr (%ref(locklist),    %ref(token1ptr))
*<--
      call checkerr (sqlca, errloc, *999)

*-->
      rc = sqlgaddr (%ref(buff_page),   %ref(token2ptr))
*<--
      call checkerr (sqlca, errloc, *999)

      rc = sqlgaddr (%ref(maxfilop),    %ref(token3ptr))
      call checkerr (sqlca, errloc, *999)

      rc = sqlgaddr (%ref(softmax),     %ref(token4ptr))
      call checkerr (sqlca, errloc, *999)


      print *, 'CREATing the temporary database DBCONF...'
      print *, 'please wait... this will take a while...'
*-->
***********************
*     CREATE DATABASE *
***********************
      rc = sqlgcrea (%val(0),
     +               %val(dbalias_len),
     +               %val(dbname_len),
     +               %ref(sqlca),
     +               %val(0),
     +               %val(0),
     +               %val(0),
     +               %ref(db_desc),
     +               %val(0),
     +               %ref(dbalias),
     +               %ref(dbname))
*<--
      errloc = 'CREATE DATABASE'
      call checkerr (sqlca, errloc, *999)

*-->
**********************************
*     GET DATABASE CONFIGURATION *
**********************************
      rc = sqlgxdb (%val(dbname_len),
     +              %val(listnumber),
     +              %ref(token_list),
     +              %ref(sqlca),
     +              %ref(dbname))
*<--
      errloc = 'GET DB CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the database configuration'
      call printinfo (locklist, buff_page, maxfilop, softmax)


*     Altering the default Database Configuration
      locklist          = 4
      buff_page         = 2000
      maxfilop          = 3
      softmax           = 1

      print *, 'UPDATing the database configuration'
*-->
*************************************
*     UPDATE DATABASE CONFIGURATION *
*************************************
      rc = sqlgeudb (%val(0),
     +               %val(dbname_len),
     +               %val(listnumber),
     +               %ref(item_lengths),
     +               %ref(token_list),
     +               %ref(sqlca),
     +               %val(0),
     +               %ref(dbname))
*<--
      errloc = 'UPDATE DATABASE CONFIGURATION'
      call checkerr (sqlca, errloc, *999)

**********************************
*     GET DATABASE CONFIGURATION *
**********************************
      rc = sqlgxdb (%val(dbname_len),
     +              %val(listnumber),
     +              %ref(token_list),
     +              %ref(sqlca),
     +              %ref(dbname))
      errloc = 'GET DB CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the UPDATEd database configuration'
      call printinfo (locklist, buff_page, maxfilop, softmax)


      print *, 'RESETting the database configuration'
*-->
************************************
*     RESET DATABASE CONFIGURATION *
************************************
      rc = sqlgrdb (%val(dbname_len),
     +              %ref(sqlca),
     +              %ref(dbname))
*<--
      errloc = 'RESET DB CFG'
      call checkerr (sqlca, errloc, *999)


**********************************
*     GET DATABASE CONFIGURATION *
**********************************
      rc = sqlgxdb (%val(dbname_len),
     +              %val(listnumber),
     +              %ref(token_list),
     +              %ref(sqlca),
     +              %ref(dbname))
      errloc = 'GET DB CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the database configuration after the RESET'
      call printinfo (locklist, buff_page, maxfilop, softmax)


      print *, 'DROPping the database DBCONF'
*-->
*********************
*     DROP DATABASE *
*********************
      rc = sqlgdrpd (%val(0),
     +               %val(dbalias_len),
     +               %ref(sqlca),
     +               %val(0),
     +               %ref(dbalias))
*<--
      errloc = 'DROP DATABASE'
      call checkerr (sqlca, errloc, *999)


  999 stop
      end


*******************************************************************************
* SUBROUTINE : printinfo
*
* PURPOSE : This subroutine displays the database configuration.
*
*******************************************************************************
      subroutine printinfo (locklist, buff_page, maxfilop, softmax)
      integer*2         locklist
      integer*4         buff_page
      integer*2         maxfilop
      integer*2         softmax

      print *, 'Max. storage for lost lists (4kb)            :',
     + locklist
      print *, 'Buffer pool size (4kb)                       :',
     + buff_page
      print *, 'Max. DB files open per application           :',
     + maxfilop
      print *, 'percent log reclaimed before soft checkpoint :',
     + softmax

      return
      end
