*******************************************************************************
**
** Source File Name = dbinst.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use DATABASE INSTANCE APIs in order to:
**          - Attach to an instance
**          - Retrieve the instance
**          - Detach from the instance.
**
**    APIs USED :
**       ATTACH TO INSTANCE               sqleatin
**       GET INSTANCE                     sqlegins
**       DETACH FROM INSTANCE             sqledtin
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbinst
      implicit none

*--> sqlb0x08.fortran
      include 'sqlenv.f'
      include 'sqlca_cn.f'
      include 'sql.f'

      integer*4         rc
*<--
      character*80      errloc

*-->
* Variables for the ATTACH to instance API
      character*(sql_dbname_sz+1)       instance
      character*(sql_sh_ident+1)        userid
      character*(sql_lg_ident+1)        passwd
      integer*2         instance_len
      integer*2         userid_len
      integer*2         passwd_len
*<--


* Main Program Body
      print *, 'Sample Fortran program : DBINST.F'

      print *, 'Enter in the instance to attach to :'
      read 100, instance
100   format (a8)
      instance_len = index(instance, ' ') -1
      if (instance_len .lt. 0) instance_len = 8

      print *, 'Enter in your user id :'
      read 100, userid
      userid_len = index(userid, ' ') - 1
      if (userid_len .lt. 0) userid_len = 8

      print *, 'Enter in your password :'
      read 100, passwd
      passwd_len = index(passwd, ' ') - 1
      if (passwd_len .lt. 0) passwd_len = 18


      print *, 'ATTACH TO INSTANCE API called for instance : ', instance
*-->
**************************
*     ATTACH TO INSTANCE *
**************************
      rc = sqlgatin (%val(passwd_len),
     +               %val(userid_len),
     +               %val(instance_len),
     +               %ref(sqlca),
     +               %ref(passwd),
     +               %ref(userid),
     +               %ref(instance))
*<--
      errloc = 'ATTACH'
      call checkerr (sqlca, errloc, *999)


      print *, 'GET INSTANCE API called'
*-->
********************
*     GET INSTANCE *
********************
      rc = sqlggins (%ref(sqlca),
     +               %ref(instance))
*<--
      errloc = 'GET INSTANCE'
      call checkerr (sqlca, errloc, *999)

      print *, ' '
      print *, 'current instance = ', instance
      print *, ' '

      print *, 'DETACH FROM INSTANCE API called'

*-->
****************************
*     DETACH FROM INSTANCE *
****************************
      rc = sqlgdtin (%ref(sqlca))
*<--
      errloc = 'DETACH'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
