*******************************************************************************
**
** Source File Name = dbmconf.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**       CREATE a DATABASE and then GET the CONFIGURATION information from
**       it, then UPDATE the CONFIGURATION, RESET the CONFIGURATION, then
**       DROP the DATABASE.
**       This program only can only be run locally.
**       It can not be run on a remote node.
**
**    APIs USED :
**       CREATE DATABASE                  sqledbcr()
**       DROP DATABASE                    sqledrpd()
**       GET DATABASE CONFIGURATION       sqlfxdb()
**       UPDATE DATABASE CONFIGURATION    sqlfudb()
**       RESET DATABASE CONFIGURATION     sqlfrdb()
**
**
**    STRUCTURES USED :
**       sqledbcinfo
**       sqlfupd
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**          printinfo :       Displays the database configuration
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbmconf
      implicit none

*--> sqlb0x09.fortran
      include 'sqlutil.f'
      include 'sqlenv.f'
      include 'sqlca_cn.f'
      include 'sql.f'
      include 'sqle850b.f'

      integer*4         rc
      integer*2         listnumber      /2/
*<--
      character*80      errloc
      character         option

*-->
* Variables for DATABASE CONFIGURATION API
*     The number "2" comes from the number of items "listnumber" that are
*     to be defined in the token list.  This is hardcoded for FORTRAN on AIX
*     inorder to compile properly.
      integer*2         item_lengths (2)
      character         token_list   (2 * sqlfupd_struct_sz)

      integer*2         token1
      integer*2         token2

      integer*4         token1ptr
      integer*4         token2ptr


      equivalence (token_list(0*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token1)
      equivalence (token_list(1*sqlfupd_struct_sz + sqlfupd_token_ofs),
     +                                                           token2)

      equivalence (token_list(0*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token1ptr)
      equivalence (token_list(1*sqlfupd_struct_sz +
     +                                 sqlfupd_ptrvalue_ofs), token2ptr)

      integer*4         max_agents
      integer*2         numbdb
*<--


* Main Program Body.
      print *, 'Sample Fortran program : DBMCONF.F'

*-->
*     Initializing the SQLFUPD structure for the DATABASE CONFIGURATION APIs
      token1 = sqlf_ktn_maxagents
      token2 = sqlf_ktn_numdb
*<--

      errloc = 'GET ADDRESS'
*-->
*******************
*     GET ADDRESS *
*******************
      rc = sqlgaddr (%ref(max_agents),    %ref(token1ptr))
*<--
      call checkerr (sqlca, errloc, *999)

      rc = sqlgaddr (%ref(numbdb),   %ref(token2ptr))
      call checkerr (sqlca, errloc, *999)

*-->
******************************************
*     GET DATABASE MANAGER CONFIGURATION *
******************************************
      rc = sqlgxsys (%val(listnumber),
     +               %ref(token_list),
     +               %ref(sqlca))
*<--
      errloc = 'GET DBM CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the database manager configuration'
      call printinfo (max_agents, numbdb)

      print *, '                   ******************************'
      print *, '                   ***  IMPORTANT INFORMATION ***'
      print *, '                   ******************************'
      print *, '  In the following steps of the this program, an UPDATE'
      print *, 'and a RESET database manager configuration APIs will be'
      print *, 'called, changing the current database manager config.'
      print *, 'to be reset to the DEFAULT values.'
      print *, ' '
      print *, 'Do you wish to continue? (y/n) <--the default is NO'
      read 200, option
200   format (a8)
      if (option .eq. 'Y') goto 100
      if (option .eq. 'y') goto 100
      goto 999

*     Altering the default Database Configuration
  100 max_agents = 2500
      numbdb     =15

      print *, 'UPDATing the database manager configuration'
*-->
*********************************************
*     UPDATE DATABASE MANAGER CONFIGURATION *
*********************************************
      rc = sqlgusys (%val(listnumber),
     +               %ref(item_lengths),
     +               %ref(token_list),
     +               %ref(sqlca))
*<--
      errloc = 'UPDATE DATABASE MANAGER CONFIGURATION'
      call checkerr (sqlca, errloc, *999)

******************************************
*     GET DATABASE MANAGER CONFIGURATION *
******************************************
      rc = sqlgxsys (%val(listnumber),
     +               %ref(token_list),
     +               %ref(sqlca))
      errloc = 'GET DBM CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the UPDATEd database manager configuration'
      call printinfo (max_agents, numbdb)


      print *, 'RESETting the database manager configuration'
*-->
********************************************
*     RESET DATABASE MANAGER CONFIGURATION *
********************************************
      rc = sqlgrsys (%ref(sqlca))
*<--
      errloc = 'RESET DBM CFG'
      call checkerr (sqlca, errloc, *999)


******************************************
*     GET DATABASE MANAGER CONFIGURATION *
******************************************
      rc = sqlgxsys (%val(listnumber),
     +               %ref(token_list),
     +               %ref(sqlca))
      errloc = 'GET DBM CFG'
      call checkerr (sqlca, errloc, *999)

      print *, 'listing the DBM CFG after the RESET'
      call printinfo (max_agents, numbdb)


  999 stop
      end


*******************************************************************************
* SUBROUTINE : printinfo
*
* PURPOSE : This subroutine displays the database configuration.
*
*******************************************************************************
      subroutine printinfo (max_agents, numbdb)
      integer*4         max_agents
      integer*2         numbdb

      print *, 'Maximum number of agents                :', max_agents
      print *, 'Number of concurrent active DB allowed  :', numbdb
      print *, ' '

      return
      end
