*******************************************************************************
**
** Source File Name = dbstat.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**
**       This program needs the embedded SQL calls in order to connect to
**       an existing database, then to create a temporary table to work with.
**
**    STRUCTURES USED :
**       sqldcol
**       sqlchar
**       sqluexpt_out
**       sqluimp_in
**       sqluimp_out
**       sqlca
**
**    APIs USED :
**       REORGANIZE TABLE           sqlureot()
**       RUN STATISTICS             sqlustat()
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbstat
      implicit none

*--> sqlb0x10.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sql.f'
      EXEC SQL INCLUDE SQLCA
*<--
      character*80      errloc
*-->

      EXEC SQL BEGIN DECLARE SECTION
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

      integer*4         rc
      integer*4         host_var_len

* Variables for the REORGANIZE TABLE API
      integer*2         filepath_len            /0/
      integer*2         qualifier_table_len     /14/
      integer*2         index_name_len          /14/

      character         filepath(sql_path_sz+1)
*     qualifier_table = schema.table_name
*       where "schema" is       8 characters
*             "table_name" is   5 characters
*                               1 character for "." delimeter
*                            = 14 characters
      character*14      qualifier_table
      character*14      index_name              /'sample.testind'/


* Variables for the RUN STATISTICS API
      integer*2         num_indexes             /1/
      integer*2         index_len_list(1)       /14/
      integer*4         index_list(1)

      character statsopt(2)
      integer*2 statsopt_i
      character sharelvl(2)
      integer*2 sharelvl_i

      equivalence(statsopt, statsopt_i)
      equivalence(sharelvl, sharelvl_i)

      rc = sqlgaddr (%ref(index_name),
     +               %ref(index_list(1)))
*<--

* Main Program Body
      print *, 'Sample Fortran Program: DBSTAT.SQF'

*-->
      print *, 'Enter in your user id / schema:'
      read '(A8)', userid
      qualifier_table = userid
      host_var_len = index(userid, ' ')
      userid (host_var_len:host_var_len) = char(0)

      print *, 'Enter in your password :'
      read '(A18)', passwd
      host_var_len = index(passwd, ' ')
      userid (host_var_len:host_var_len) = char(0)


      print *, 'CONNECT TO sample database'
      EXEC SQL CONNECT TO sample USER :userid USING :passwd
*<--
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

      EXEC SQL DROP INDEX sample.testind

      print *, 'CREATE INDEX ', index_name
*-->
      EXEC SQL CREATE INDEX sample.testind ON staff (salary)
*<--
      errloc = 'CREATE INDEX'
      call checkerr (sqlca, errloc, *999)

      print *, 'REORGanizing the TABLE'

      qualifier_table_len = index(qualifier_table, ' ')

*     Add the '.STAFF' table to the qualifier name.
      qualifier_table (qualifier_table_len : qualifier_table_len + 6)
     + = '.STAFF'
      qualifier_table_len = index(qualifier_table, ' ')
      qualifier_table (qualifier_table_len:qualifier_table_len) 
     + = char(0)
*-->
***********************************
*     REORGANIZE TABLE STATISTICS *
***********************************
      rc = sqlgreot (%val(filepath_len),
     +               %val(index_name_len),
     +               %val(qualifier_table_len),
     +               %ref(sqlca),
     +               %ref(filepath),
     +               %ref(index_name),
     +               %ref(qualifier_table))
*<--
      errloc = 'REORGANIZE TABLE STATISTICS'
      call checkerr (sqlca, errloc, *999)


      print *, 'RUNning STATISTICS'
*-->
**********************
*     RUN STATISTICS *
**********************
      statsopt(2) = sql_stats_table
      sharelvl(2) = sql_stats_chg
      rc = sqlgstat (%val(qualifier_table_len),
     +               %val(num_indexes),
     +               %val(statsopt_i),
     +               %val(sharelvl_i),
     +               %ref(index_len_list),
     +               %ref(sqlca),
     +               %ref(index_list),
     +               %ref(qualifier_table))
*<--
      errloc = 'RUN STATISTICS API'
      call checkerr (sqlca, errloc, *999)


      print *, 'CONNECT RESETting'
      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
