*******************************************************************************
**
** Source File Name = dbstop.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use the following APIs in order to:
**          - FORCE USERS off of a database
**          - STOP a DATABASE MANAGER
**       This program will stop further connect to the database and will
**       force the current users off, and shut down the database manager.
**
**    APIs USED :
**       FORCE USERS              sqlefrce()
**       STOP DATABASE MANAGER    sqlestop()
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program dbstop
      implicit none

*--> sqlb0x11.fortran
      include 'sqlenv.f'
      include 'sqlca_cn.f'

      integer*4         rc
*<--
      character*80      errloc

*-->
* Variables for the FORCE APPLICATION API
*     This array is ignored when used in the FORCE APPLICATION API when
*     SQL_ALL_USERS is defined as the "count".  All users are forced off.
      integer*4         agentidarray
*<--

* Main Program Body
      print *, 'Sample Fortran program : DBSTOP.F'

      print *, 'Forcing Users off DB2'
*-->
*************************
*     FORCE APPLICATION *
*************************
      rc = sqlgfrce (%ref(sqlca),
     +               %val(sql_asynch),
     +               %ref(agentidarray),
     +               %val(sql_all_users))
*<--
      if (sqlcode .eq. sqle_rc_nostartg) then
         print *, 'No start database manager command was issued'
         goto 999
      endif
      errloc = 'FORCE APPLICATIONS'
      call checkerr (sqlca, errloc, *999)

      print *, 'Stopping the Database Manager'
*-->
*****************************
*     STOP DATABASE MANAGER *
*****************************
      rc = sqlgstdm (%ref(sqlca))
*<--
      errloc = 'STOP DATABASE MANAGER'
      call checkerr (sqlca, errloc, *999)

      print *, 'Database Manager STOPPED'

  999 stop
      end
