*******************************************************************************
**
** Source File Name = dcscat.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**       access DB/2.  The order of the program is as follows:
**          - create/catalog a DCS database
**          - list a directory of DCS databases (showing what was created)
**          - uncatalog the DCS database
**
**    STRUCTURES USED :
**       "sql_dir_entry" :
**          unsigned short struct_id;
**          unsigned short release;
**          unsigned short codepage;
**          unsigned char  comment[SQL_CMT_SZ];
**          unsigned char  ldb[SQL_DBNAME_SZ];
**          unsigned char  tdb[SQL_LONG_NAME_SZ];
**          unsigned char  ar[SQL_AR_SZ];
**          unsigned char  parm[SQL_PARAMETER_SZ];
**
**    APIs USED :
**       ADD DCS DIRECTORY ENTRY                      sqlegdad()
**       SCAN DCS DIRECTORY                           sqlegdsc()
**       GET DCS DIRECTORY ENTRIES                    sqlegdgt()
**       CLOSE DCS DIRECTORY SCAN                     sqlegdcl()
**       DELETE DCS DIRECTORY ENTRY                   sqlegdel()
**
**    STRUCTURES USED :
**       sqldinfo
**       sqlca
**    OTHER FUNCTIONS USED :
**       internal :
**          list_dcs :        Displays a directory of databases
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************
      program dcscat
      implicit none

*--> sqlb0x12.fortran
      include 'sqlenv.f'
      include 'sqlca_cn.f'

      integer*4         rc
*<--
      character*80      errloc

* Variables for the CATALOG/UNCATALOG DCS DATABASE APIs
*-->
      character         dbdir_entry(sql_dir_entry_struct_sz)
      integer*2         id      /sql_dcs_str_id/
      integer*2         release
      integer*2         codepage
      character*(sql_cmt_sz+1)          comment /'this is a dcs db'/
      character*(sql_dbname_sz+1)       ldb     /'dcsnm'/
      character*(sql_long_name_sz+1)    tdb     /'targetnm'/
      character*(sql_ar_sz+1)           ar      /'arName'/
      character         parm(sql_parameter_sz+1)

      equivalence (id,         dbdir_entry(sql_dir_entry_struct_id_ofs))
      equivalence (release,      dbdir_entry(sql_dir_entry_release_ofs))
      equivalence (codepage,    dbdir_entry(sql_dir_entry_codepage_ofs))
      equivalence (comment,      dbdir_entry(sql_dir_entry_comment_ofs))
      equivalence (ldb,              dbdir_entry(sql_dir_entry_ldb_ofs))
      equivalence (tdb,              dbdir_entry(sql_dir_entry_tdb_ofs))
      equivalence (ar,                dbdir_entry(sql_dir_entry_ar_ofs))
      equivalence (parm,            dbdir_entry(sql_dir_entry_parm_ofs))
*<--

* Main program body.
      print *, 'Sample Fortran Program: DCSCAT.F'

      print *, 'cataloging the DCS database ', tdb
*-->
****************************
*     CATALOG DCS DATABASE *
****************************
      rc = sqlggdad (%ref(sqlca),
     +               %ref(dbdir_entry))
*<--
      errloc = 'CATALOG DCS DATABASE'
      call checkerr (sqlca, errloc, *999)
      print *, 'database ', tdb, 'has been catalogued'

      print *, 'Listing all DCS databases...'
      print *, '============================'
      call list_dcs (*999)

      print *, 'now uncataloging the database :', tdb
*-->
******************************
*     UNCATALOG DCS DATABASE *
******************************
      rc = sqlggdel (%ref(sqlca),
     +               %ref(dbdir_entry))
*<--
      errloc = 'UNCATALOG DCS DATABASE'
      call checkerr (sqlca, errloc, *999)

      print *, 'Listing all databases [after uncatalogued database]'
      print *, '==================================================='
      call list_dcs (*999)

  999 stop
      end


*******************************************************************************
* SUBROUTINE : list_dcs
*
* PURPOSE : This subroutine displays the data contained in each database
*           directory entry, by retrieving the "sql_dir_entry" structure.
*
*******************************************************************************
      subroutine list_dcs (*)

*--> sqlb0x34.fortran
      include 'sqlca_cn.f'
      include 'sqlenv.f'
      include 'sql.f'

      integer*4         rc
*<--
      character*80      errloc
      integer*2         idx
      integer*2         count   /1/


*-->
* Variables declared for the OPEN/CLOSE DCS directory scan APIs
      integer*2         dbCount

* Variables declared for the GET DCS DIRECTORY ENTRIES API.
      character         dbdir_entry(sql_dir_entry_struct_sz)
      integer*2         id
      integer*2         release
      integer*2         codepage
      character*(sql_cmt_sz+1)          comment /'this is a dcs db'/
      character*(sql_dbname_sz+1)       ldb     /'dcsnm'/
      character*(sql_long_name_sz+1)    tdb     /'targetnm'/
      character*(sql_ar_sz+1)           ar      /'arName'/
      character         parm(sql_parameter_sz+1)

      equivalence (id,         dbdir_entry(sql_dir_entry_struct_id_ofs))
      equivalence (release,      dbdir_entry(sql_dir_entry_release_ofs))
      equivalence (codepage,    dbdir_entry(sql_dir_entry_codepage_ofs))
      equivalence (comment,      dbdir_entry(sql_dir_entry_comment_ofs))
      equivalence (ldb,              dbdir_entry(sql_dir_entry_ldb_ofs))
      equivalence (tdb,              dbdir_entry(sql_dir_entry_tdb_ofs))
      equivalence (ar,                dbdir_entry(sql_dir_entry_ar_ofs))
      equivalence (parm,            dbdir_entry(sql_dir_entry_parm_ofs))
*<--

* Subroutine body.

*-->
*******************************
*     OPEN DCS DIRECTORY SCAN *
*******************************
      rc = sqlggdsc (%ref(sqlca),
     +               %ref(dbCount))
*<--
      if (sqlcode .eq. sqle_rc_no_entry) then
         print *, '--- DCS directory is empty ---'
         return
      endif
      errloc = 'OPEN DCS DATABASE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *9999)

      print *, 'number of dcs databases :',  dbCount

      idx = 0
      do 1500 while (idx .lt. dbCount)
         idx = idx + 1

*-->
*******************************
*     GET DCS DIRECTORY ENTRY *
*******************************
      rc = sqlggdgt (%ref(sqlca),
     +               %ref(count),
     +               %ref(dbdir_entry))
*<--
      errloc = 'GET DCS DIRECTORY ENTRY'
      call checkerr (sqlca, errloc, *9999)

      print *, 'Local Database Name :     ', ldb
      print *, 'Target Database Name :    ', tdb
      print *, 'App. Requestor Name :     ', ar
      print *, 'DCS parameters :          ', parm
      print *, 'Comment :                 ', comment
      print *, 'DCS Release Level :      ',  release
      print *, ' '

1500  end do

* Use the last dbdir_entry from previous call
* Normal, only the Local Database Name field would be set
* prior to the call
*-->
********************************************
*     GET DCS DIRECTORY ENTRY FOR DATABASE *
********************************************
      rc = sqlggdge (%ref(sqlca),
     +               %ref(dbdir_entry))
*<--
*-->
********************************
*     CLOSE DCS DIRECTORY SCAN *
********************************
      rc = sqlggdcl (%ref(sqlca))
*<--
      errloc = 'CLOSE DCS DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *9999)

      return
 9999 return 1
      end
