*******************************************************************************
**
** Source File Name = impexp.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       This program is an example of how APIs are implemented in order to
**       export and import tables and table data.  The order of the program
**       is as follows:
**          - export a table to a comma-delimited text file
**          - import the comma-delimited text file to a DB2 table
**       This program needs the embedded SQL calls in order to connect to
**       an existing database, then to create a temporary table to work with.
**
**    STRUCTURES USED :
**       sqldcol
**       sqlchar
**       sqluexpt_out
**       sqluimp_in
**       sqluimp_out
**       sqlca
**
**    APIs USED :
**            IMPORT TO             sqluimpr
**            EXPORT                sqlgexpr
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program impexp
      implicit none

*--> sqlb0x13.fortran
      include 'sqlenv.f'
      include 'sql.f'
      include 'sqlutil.f'
      EXEC SQL INCLUDE SQLCA

      integer*4         rc
*<--
      character*80      errloc


      EXEC SQL BEGIN DECLARE SECTION
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

*-->
* Variables for IMPORT/EXPORT API
      integer*2         msgfile_len
      integer*2         filetype_len
      integer*2         datafile_len
      character*(sql_path_sz+1)         msgfile
      character*(sql_fmt_length+1)      filetype
      character*(sql_path_sz+1)         datafile

      character*(12)    datafile_disp

      integer*2         callerac
      integer*4         reserved


*     FILETMOD is a self-defining string.
*     Replace STRLEN with application_specific bound, assign the FILETMOD
*     string to FILETMODE_STR and assign the length of the the FILETMOD
*     string to FILETMODE_LEN
*      character         filetmod(2+strlen)
*      character*(strlen)        filetmod_str
      character         filetmod(2+12)
      character*12      filetmod_str
      integer*2         filetmod_len
      equivalence(filetmod_len, filetmod(sqlchar_length))
      equivalence(filetmod_str, filetmod(sqlchar_data))

*     TCOLSTRG is a self-defining string.
*     Assign a string containing an SQL statement to TCOLSTRG_STR and assign
*     the length of the statement to TCOLSTRG_LEN.
*     [note: SQL_MAX_STMT_SIZ is rather large, you may wish to replace it
*      with a smaller value]
      character                         tcolstrg(sql_max_stmt_siz+2)
      character*(sql_max_stmt_siz)      tcolstrg_str
      integer*2                         tcolstrg_len
      equivalence(tcolstrg_len, tcolstrg(sqlchar_length))
      equivalence(tcolstrg_str, tcolstrg(sqlchar_data))

*     Replace NUMCOLS with application specific bound
      integer*2         col1
      integer*2         col2
      parameter(col1 = sqldcol_header_sz + 0*sqldcoln_struct_sz)
      parameter(col2 = sqldcol_header_sz + 1*sqldcoln_struct_sz)

*     Replace NUMCOLS with application specific bound
*      character         dcoldata(sqldcol_header_sz +
*     +                           NUMCOLS*sqldcoln_struct_sz)
      character         dcoldata(sqldcol_header_sz +
     +                           2*sqldcoln_struct_sz)
      integer*2         dcolmeth
      integer*2         dcolnum
      integer*2         dcolnlen1, dcolnlen2
      integer*4         dcolnptr1, dcolnptr2

      equivalence (dcolmeth, dcoldata(sqldcol_dcolmeth_ofs))
      equivalence (dcolnum, dcoldata(sqldcol_dcolnum_ofs))
      equivalence (dcolnlen1, dcoldata(col1 + sqldcoln_dcolnlen_ofs))
      equivalence (dcolnptr1, dcoldata(col1 + sqldcoln_dcolnptr_ofs))
      equivalence (dcolnlen2, dcoldata(col2 + sqldcoln_dcolnlen_ofs))
      equivalence (dcolnptr2, dcoldata(col2 + sqldcoln_dcolnptr_ofs))

      character         lobpaths(sqlu_media_list_struct_sz)
      character         lp_media_type
      integer*4         lp_sessions
      integer*4         lp_target
      equivalence (lobpaths(sqlu_media_list_media_type_ofs),
     +                                                    lp_media_type)
      equivalence (lobpaths(sqlu_media_list_sessions_ofs),  lp_sessions)
      equivalence (lobpaths(sqlu_media_list_target_ofs),      lp_target)




* Variables specific to EXPORT
      character         lobfilenames(sqlu_media_list_struct_sz)
      character         lfn_media_type
      integer*4         lfn_sessions
      integer*4         lfn_target
      equivalence (lobfilenames(sqlu_media_list_media_type_ofs),
     +                                                   lfn_media_type)
      equivalence (lobfilenames(sqlu_media_list_sessions_ofs),
     +                                                     lfn_sessions)
      equivalence (lobfilenames(sqlu_media_list_target_ofs),
     +                                                       lfn_target)


      character         expt_out(sqluexpt_out_struct_sz)
      integer*4         sizeof_struct   /sqluexpt_out_struct_sz/
      integer*4         rows_exported
      equivalence(expt_out(sqluexpt_out_sizeofstruct_ofs),
     +            sizeof_struct)
      equivalence(expt_out(sqluexpt_out_rowsexported_ofs),
     +            rows_exported)

* Variables specific to IMPORT
      character         impt_in(sqluimpt_in_struct_sz)
      integer*4         in_sizeof_struct        /sqluimpt_in_struct_sz/
      integer*4         in_commit_count
      integer*4         in_restart_count
      equivalence (impt_in(sqluimpt_in_sizeofstruct_ofs),
     +             in_sizeof_struct)
      equivalence (impt_in(sqluimpt_in_commitcnt_ofs),
     +             in_commit_count)
      equivalence (impt_in(sqluimpt_in_restartcnt_ofs),
     +             in_restart_count)

      character         impt_out(sqluimpt_out_struct_sz)
      integer*4         out_sizeof_struct       /sqluimpt_out_struct_sz/
      integer*4         out_rows_read
      integer*4         out_rows_skipped
      integer*4         out_rows_inserted
      integer*4         out_rows_updated
      integer*4         out_rows_rejected
      integer*4         out_rows_committed
      equivalence (impt_out(sqluimpt_out_sizeofstruct_ofs),
     +             out_sizeof_struct)
      equivalence (impt_out(sqluimpt_out_rowsread_ofs),
     +             out_rows_read)
      equivalence (impt_out(sqluimpt_out_rowsskipped_ofs),
     +             out_rows_skipped)
      equivalence (impt_out(sqluimpt_out_rowsinserted_ofs),
     +             out_rows_inserted)
      equivalence (impt_out(sqluimpt_out_rowsupdated_ofs),
     +             out_rows_updated)
      equivalence (impt_out(sqluimpt_out_rowsrejected_ofs),
     +             out_rows_rejected)
      equivalence (impt_out(sqluimpt_out_rowscommitted_ofs),
     +             out_rows_committed)

      integer*4         nullind
*<--


* Main Program Body
      print *, 'Sample Fortran Program: IMPEXP.SQF'

      print *, 'Enter in your user id :'
      read 100, userid
100   format (a8)      

      print *, 'Enter in your password :'
      read 100, passwd

      EXEC SQL CONNECT TO sample USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)



*     Initialize the EXPORT API variables
      datafile = 'EXPTABLE.DEL'

      datafile_disp = datafile

      datafile_len = 12
      msgfile = 'EXPMSG.TXT'
      msgfile_len = 10
      filetype = 'DEL'
      filetype_len = 3
      tcolstrg_str = 'select name, id from staff'
      tcolstrg_len = 30
      callerac = sqlu_initial
      dcolmeth = sql_meth_d



      print *, 'Exporting NAME and ID from STAFF table into file ',
     + datafile_disp

*-->
**************
*     EXPORT *
**************
      rc = sqlgexpr (%val(datafile_len),
     +               %val(filetype_len),
     +               %val(msgfile_len),
     +               %ref(datafile),
*     +               %ref(lobpaths),
*     +               %ref(lobfilenames),
     +               %val(0),
     +               %val(0),
     +               %ref(dcoldata),
     +               %ref(tcolstrg),
     +               %ref(filetype),
     +               %ref(filetmod),
     +               %ref(msgfile),
     +               %val(callerac),
     +               %ref(expt_out),
     +               %ref(reserved),
     +               %ref(sqlca))
*<--
      errloc = 'EXPORT'
      call checkerr (sqlca, errloc, *999)
      print *, 'rows exported : ', rows_exported


      EXEC SQL DROP TABLE imptable

      print *, 'Creating a temporary table "imptable" to import to'
      EXEC SQL CREATE TABLE imptable (name VARCHAR(15), id INT)
      errloc = 'CREATE TABLE'
      call checkerr (sqlca, errloc, *999)

*     Initialize the IMPORT API variables
      tcolstrg_str = 'insert into imptable (name, id)'
      tcolstrg_len = 36
      msgfile = 'IMPMSG.TXT'
      msgfile_len = 10

*-->
**************
*     IMPORT *
**************
      rc = sqlgimpr (%val(datafile_len),
     +               %val(filetype_len),
     +               %val(msgfile_len),
     +               %ref(datafile),
*     +               %ref(lobpaths),
     +               %val(0),
     +               %ref(dcoldata),
     +               %ref(tcolstrg),
     +               %ref(filetype),
     +               %ref(filetmod),
     +               %ref(msgfile),
     +               %val(callerac),
     +               %ref(impt_in),
     +               %ref(impt_out),
     +               %ref(nullind),
     +               %ref(reserved),
     +               %ref(sqlca))
*<--
      errloc = 'IMPORT'
      call checkerr (sqlca, errloc, *999)

      print *, 'rows inserted :', out_rows_inserted
      print *, 'rows committed : ', out_rows_committed


      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
