*******************************************************************************
**
** Source File Name = inpcli.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: This sample program demonstrates stored procedures.
**
**          There are two parts to this program:
**              - the inpcli executable (placed on the client)
**              - the inpsrv library (placed on the server)
**
**          The inpcli routine will fill in an input SQLDA with 3
**          entries.  The entries are the names of presidents.  The
**          inpcli routine will also place the value "Presidents" in
**          the input-data variable.  It will then call the sqlgproc
**          API passing it the input SQLDA and the input-data
**          variable.
**
**          The inpsrv routine will take the information received
**          and create a table called "Presidents" in the "sample"
**          database.  It will then place the values it received in
**          the input SQLDA into the "Presidents" table.
**
** NOTE:  The SQLDA contains two values, sqldata and sqlind,
**        which contain addresses.  In order to handle this, two
**        API's sqlgaddr() and sqlgdref() are used.
**
*******************************************************************************

      program inpcli
      implicit none

*     Copy Files for Constants and Structures
      include 'sql.f'
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqldact.f'

*     Declare an SQLCA
      EXEC SQL INCLUDE SQLCA

*     Declare host variables.
      EXEC SQL BEGIN DECLARE SECTION
        character*8    dbname
        character*8    userid
        character*18   passwd
        character*11   procname   /'inpsrv'/
        character*10   table_name /'PRESIDENTS'/
        character*20   data_item0 /'Washington'/
        character*20   data_item1 /'Jefferson'/
        character*20   data_item2 /'Lincoln'/
        integer*2      tableind  /0/
        integer*2      dataind0  /0/
        integer*2      dataind1  /0/
        integer*2      dataind2  /0/
      EXEC SQL END DECLARE SECTION


*     Declare Variables Used to Create an SQLDA
      integer*2  sqlvar1
      parameter ( sqlvar1 = sqlda_header_sz + 0*sqlvar_struct_sz )
      integer*2  sqlvar2
      parameter ( sqlvar2 = sqlda_header_sz + 1*sqlvar_struct_sz )
      integer*2  sqlvar3
      parameter ( sqlvar3 = sqlda_header_sz + 2*sqlvar_struct_sz )
      integer*2  sqlvar4
      parameter ( sqlvar4 = sqlda_header_sz + 3*sqlvar_struct_sz )

*     Declare an Input SQLDA Structure -- 4 Variables
      character    io_sqlda(sqlda_header_sz + 4*sqlvar_struct_sz)

      character*8  io_sqldaid     ! Header
      integer*4    io_sqldabc
      integer*2    io_sqln
      integer*2    io_sqld

      integer*2    io_sqltype1    ! First Variable
      integer*2    io_sqllen1
      integer*4    io_sqldata1
      integer*4    io_sqlind1
      integer*2    io_sqlnamel1
      character*30 io_sqlnamec1

      integer*2    io_sqltype2    ! Second Variable
      integer*2    io_sqllen2
      integer*4    io_sqldata2
      integer*4    io_sqlind2
      integer*2    io_sqlnamel2
      character*30 io_sqlnamec2

      integer*2    io_sqltype3    ! Third Variable
      integer*2    io_sqllen3
      integer*4    io_sqldata3
      integer*4    io_sqlind3
      integer*2    io_sqlnamel3
      character*30 io_sqlnamec3

      integer*2    io_sqltype4    ! Fourth Variable
      integer*2    io_sqllen4
      integer*4    io_sqldata4
      integer*4    io_sqlind4
      integer*2    io_sqlnamel4
      character*30 io_sqlnamec4



      equivalence( io_sqlda(sqlda_sqldaid_ofs), io_sqldaid )
      equivalence( io_sqlda(sqlda_sqldabc_ofs), io_sqldabc )
      equivalence( io_sqlda(sqlda_sqln_ofs), io_sqln )
      equivalence( io_sqlda(sqlda_sqld_ofs), io_sqld )

      equivalence( io_sqlda(sqlvar1+sqlvar_type_ofs), io_sqltype1 )
      equivalence( io_sqlda(sqlvar1+sqlvar_len_ofs), io_sqllen1 )
      equivalence( io_sqlda(sqlvar1+sqlvar_data_ofs), io_sqldata1 )
      equivalence( io_sqlda(sqlvar1+sqlvar_ind_ofs), io_sqlind1 )
      equivalence( io_sqlda(sqlvar1+sqlvar_name_length_ofs),
     +             io_sqlnamel1 )
      equivalence( io_sqlda(sqlvar1+sqlvar_name_data_ofs),
     +             io_sqlnamec1 )

      equivalence( io_sqlda(sqlvar2+sqlvar_type_ofs), io_sqltype2 )
      equivalence( io_sqlda(sqlvar2+sqlvar_len_ofs), io_sqllen2 )
      equivalence( io_sqlda(sqlvar2+sqlvar_data_ofs), io_sqldata2 )
      equivalence( io_sqlda(sqlvar2+sqlvar_ind_ofs), io_sqlind2 )
      equivalence( io_sqlda(sqlvar2+sqlvar_name_length_ofs),
     +             io_sqlnamel2 )
      equivalence( io_sqlda(sqlvar2+sqlvar_name_data_ofs),
     +             io_sqlnamec2 )

      equivalence( io_sqlda(sqlvar3+sqlvar_type_ofs), io_sqltype3 )
      equivalence( io_sqlda(sqlvar3+sqlvar_len_ofs), io_sqllen3 )
      equivalence( io_sqlda(sqlvar3+sqlvar_data_ofs), io_sqldata3 )
      equivalence( io_sqlda(sqlvar3+sqlvar_ind_ofs), io_sqlind3 )
      equivalence( io_sqlda(sqlvar3+sqlvar_name_length_ofs),
     +             io_sqlnamel3 )
      equivalence( io_sqlda(sqlvar3+sqlvar_name_data_ofs),
     +             io_sqlnamec3 )

      equivalence( io_sqlda(sqlvar4+sqlvar_type_ofs), io_sqltype4 )
      equivalence( io_sqlda(sqlvar4+sqlvar_len_ofs), io_sqllen4 )
      equivalence( io_sqlda(sqlvar4+sqlvar_data_ofs), io_sqldata4 )
      equivalence( io_sqlda(sqlvar4+sqlvar_ind_ofs), io_sqlind4 )
      equivalence( io_sqlda(sqlvar4+sqlvar_name_length_ofs),
     +             io_sqlnamel4 )
      equivalence( io_sqlda(sqlvar4+sqlvar_name_data_ofs),
     +             io_sqlnamec4 )

      character*80     errloc
      integer*4        rc

*     Program Logic
      print *, 'Enter in the database name :'
      read 100, dbname
100   format (a8)      

      print *, 'Enter in your user id :'
      read 100, userid

      print *, 'Enter in your password :'
      read 100, passwd

*     Connect to Remote Database
      print *,'CONNECT to Remote Database.'
      EXEC SQL CONNECT TO :dbname USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

*     Call the Remote Procedure via CALL with Host Variables
* :rk.2a:erk.
      print *,'Use CALL with Host Variable to invoke the ',
     + 'Server Procedure named inpsrv.'
      EXEC SQL CALL :procname (:table_name:tableind,
     +                         :data_item0:dataind0,
     +                         :data_item1:dataind1,
     +                         :data_item2:dataind2)
      errloc = 'CALL with HOST VARIABLES'
      call checkerr (sqlca, errloc, *999)
      print *,'Server Procedure Complete.'


*     Initialize the Input SQLDA Structure
* :rk.1:erk.
      io_sqldaid   = 'IN_SQLDA'
      io_sqldabc   = sqlda_header_sz + 4*sqlvar_struct_sz
      io_sqln      = 4
      io_sqld      = 4

      io_sqltype1  = SQL_TYP_NCHAR
      io_sqllen1   = 10
      rc = sqlgaddr(%ref(table_name), %ref(io_sqldata1))
      rc = sqlgaddr(%ref(tableind), %ref(io_sqlind1))

      io_sqltype2  = SQL_TYP_NCHAR
      io_sqllen2   = 20
      rc = sqlgaddr(%ref(data_item0), %ref(io_sqldata2))
      rc = sqlgaddr(%ref(dataind0), %ref(io_sqlind2))

      io_sqltype3  = SQL_TYP_NCHAR
      io_sqllen3   = 20
      rc = sqlgaddr(%ref(data_item1), %ref(io_sqldata3))
      rc = sqlgaddr(%ref(dataind1), %ref(io_sqlind3))

      io_sqltype4  = SQL_TYP_NCHAR
      io_sqllen4   = 20
      rc = sqlgaddr(%ref(data_item2), %ref(io_sqldata4))
      rc = sqlgaddr(%ref(dataind2), %ref(io_sqlind4))

*     Call the Remote Procedure via CALL with SQLDA
* :rk.2b:erk.
      print *,'Use CALL with SQLDA to invoke the Server ',
     + 'Procedure named inpsrv.'
      EXEC SQL CALL :procname USING DESCRIPTOR :io_sqlda
      errloc = 'CALL with SQLDA'
      call checkerr (sqlca, errloc, *999)
      print *,'Server Procedure Complete.'

*     Disconnect from Remote Database.
      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)
999   stop
      end
