*******************************************************************************
**
** Source File Name = inpsrv.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: This sample program demonstrates stored procedures.
**
**          There are two parts to this program:
**              - the inpcli executable (placed on the client)
**              - the inpsrv library (placed on the server)
**
**          The inpcli routine will fill in an input SQLDA with 3
**          entries.  The entries are the names of presidents.  The
**          inpcli routine will also place the value "Presidents" in
**          the input-data variable.  It will then call the sqlgproc
**          API passing it the input SQLDA and the input-data
**          variable.
**
**          The sqlgproc API will call the inpsrv routine stored
**          in the inpsrv library.
**
**          The inpsrv routine will take the information received
**          and create a table called "Presidents" in the "sample"
**          database.  It will then place the values it received in
**          the input SQLDA into the "Presidents" table.
**
** NOTE: The SQLDA contains two values, sqldata and sqlind,
**        which contain addresses.  In order to handle this, two
**        API's sqlgaddr() and sqlgdref() are used.
**
*******************************************************************************

      integer*4 function inpsrv( reserved1,
* :rk.1:erk.
     +                           reserved2,
     +                           io_sqlda,
     +                           ca )

      implicit none

*     Include Files for Constants and Structures
      include 'sql.f'
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqldact.f'

*     Declare Output SQLCA
      EXEC SQL INCLUDE SQLCA

*     Declare Dummy Parameters
      integer*4  reserved1
      integer*4  reserved2
      character  io_sqlda(sqlda_header_sz + 4*sqlvar_struct_sz)
      character  ca(sqlca_size)

*     Declare Host Variables
      EXEC SQL BEGIN DECLARE SECTION
        character*20   insert_data
*        character*80   insert_string


        character*12   sqlname        /' '/
        character*200  sql_string     /' '/
      EXEC SQL END DECLARE SECTION


*     Declare Local Variables to Hold Dummy Parameter Values
*     They are in_sqlda, out_sqlda and sqlca

*     Declare Variables Used to Create an SQLDA
      integer*2  sqlvar1
      parameter ( sqlvar1 = sqlda_header_sz + 0*sqlvar_struct_sz )
      integer*2  sqlvar2
      parameter ( sqlvar2 = sqlda_header_sz + 1*sqlvar_struct_sz )
      integer*2  sqlvar3
      parameter ( sqlvar3 = sqlda_header_sz + 2*sqlvar_struct_sz )
      integer*2  sqlvar4
      parameter ( sqlvar4 = sqlda_header_sz + 3*sqlvar_struct_sz )

*     Declare an Input SQLDA Structure -- 4 Variables
      character   in_sqlda(sqlda_header_sz + 4*sqlvar_struct_sz)

      character*8  in_sqldaid     ! Header
      integer*4    in_sqldabc
      integer*2    in_sqln
      integer*2    in_sqld

      integer*2    in_sqltype1    ! First Variable
      integer*2    in_sqllen1
      integer*4    in_sqldata1
      integer*4    in_sqlind1
      integer*2    in_sqlnamel1
      character*30 in_sqlnamec1

      integer*2    in_sqltype2    ! Second Variable
      integer*2    in_sqllen2
      integer*4    in_sqldata2
      integer*4    in_sqlind2
      integer*2    in_sqlnamel2
      character*30 in_sqlnamec2

      integer*2    in_sqltype3    ! Third Variable
      integer*2    in_sqllen3
      integer*4    in_sqldata3
      integer*4    in_sqlind3
      integer*2    in_sqlnamel3
      character*30 in_sqlnamec3

      integer*2    in_sqltype4    ! Fourth Variable
      integer*2    in_sqllen4
      integer*4    in_sqldata4
      integer*4    in_sqlind4
      integer*2    in_sqlnamel4
      character*30 in_sqlnamec4


      equivalence( in_sqlda(sqlda_sqldaid_ofs),        in_sqldaid   )
      equivalence( in_sqlda(sqlda_sqldabc_ofs),        in_sqldabc   )
      equivalence( in_sqlda(sqlda_sqln_ofs),           in_sqln      )
      equivalence( in_sqlda(sqlda_sqld_ofs),           in_sqld      )

      equivalence( in_sqlda(sqlvar1+sqlvar_type_ofs),  in_sqltype1  )
      equivalence( in_sqlda(sqlvar1+sqlvar_len_ofs),   in_sqllen1   )
      equivalence( in_sqlda(sqlvar1+sqlvar_data_ofs),  in_sqldata1  )
      equivalence( in_sqlda(sqlvar1+sqlvar_ind_ofs),   in_sqlind1   )
      equivalence( in_sqlda(sqlvar1+sqlvar_name_length_ofs),
     +             in_sqlnamel1 )
      equivalence( in_sqlda(sqlvar1+sqlvar_name_data_ofs),
     +             in_sqlnamec1 )

      equivalence( in_sqlda(sqlvar2+sqlvar_type_ofs),  in_sqltype2  )
      equivalence( in_sqlda(sqlvar2+sqlvar_len_ofs),   in_sqllen2   )
      equivalence( in_sqlda(sqlvar2+sqlvar_data_ofs),  in_sqldata2  )
      equivalence( in_sqlda(sqlvar2+sqlvar_ind_ofs),   in_sqlind2   )
      equivalence( in_sqlda(sqlvar2+sqlvar_name_length_ofs),
     +             in_sqlnamel2 )
      equivalence( in_sqlda(sqlvar2+sqlvar_name_data_ofs),
     +             in_sqlnamec2 )

      equivalence( in_sqlda(sqlvar3+sqlvar_type_ofs),  in_sqltype3  )
      equivalence( in_sqlda(sqlvar3+sqlvar_len_ofs),   in_sqllen3   )
      equivalence( in_sqlda(sqlvar3+sqlvar_data_ofs),  in_sqldata3  )
      equivalence( in_sqlda(sqlvar3+sqlvar_ind_ofs),   in_sqlind3   )
      equivalence( in_sqlda(sqlvar3+sqlvar_name_length_ofs),
     +             in_sqlnamel3 )
      equivalence( in_sqlda(sqlvar3+sqlvar_name_data_ofs),
     +             in_sqlnamec3 )

      equivalence( in_sqlda(sqlvar4+sqlvar_type_ofs),  in_sqltype4  )
      equivalence( in_sqlda(sqlvar4+sqlvar_len_ofs),   in_sqllen4   )
      equivalence( in_sqlda(sqlvar4+sqlvar_data_ofs),  in_sqldata4  )
      equivalence( in_sqlda(sqlvar4+sqlvar_ind_ofs),   in_sqlind4   )
      equivalence( in_sqlda(sqlvar4+sqlvar_name_length_ofs),
     +             in_sqlnamel4 )
      equivalence( in_sqlda(sqlvar4+sqlvar_name_data_ofs),
     +             in_sqlnamec4 )

*     Declare and Initialize SQL Statement Strings
      character    create_string(39)
      character*39 create_string_tmp
      character*13 stringc1           /'CREATE TABLE '/
      character*10 var_string1
      character*16 stringc2           /' (NAME CHAR(20))'/

      equivalence( create_string(1),  stringc1          )
      equivalence( create_string(14), var_string1       )
      equivalence( create_string(24), stringc2          )
      equivalence( create_string(1),  create_string_tmp )

      character    insert_string(34)
      character*34 insert_string_tmp
      character*12 stringi1           /'INSERT INTO '/
      character*10 var_string2
      character*11 stringi2           /' VALUES (?)'/

      equivalence( insert_string(1),  stringi1          )
      equivalence( insert_string(13), var_string2       )
      equivalence( insert_string(23), stringi2          )
      equivalence( insert_string(1),  insert_string_tmp )

*     Declare Miscellaneous Variables
      integer*2    cntr
      integer*2    rc

*     Copy io_sqlda to in_sqlda
      cntr = 0
      do 20 while ( cntr .lt. (sqlda_header_sz + 4*sqlvar_struct_sz) )
        cntr = cntr + 1
        in_sqlda(cntr) = io_sqlda(cntr)
20    end do

*     Program Logic

      EXEC SQL WHENEVER SQLERROR CONTINUE

*     Create "President" Table
      rc = sqlgdref ( %val(in_sqllen1), %ref(var_string1),
     +     %ref(in_sqldata1) )
      sql_string = create_string_tmp
      EXEC SQL EXECUTE IMMEDIATE :sql_string
* :rk.2:erk.

      EXEC SQL WHENEVER SQLERROR GOTO 100

*     Prepare for Insert
      var_string2 = var_string1
      sql_string = insert_string_tmp
      EXEC SQL PREPARE insertstmt FROM :sql_string
* :rk.3:erk.

*     Insert President Names stored in Input SQLDA into Newly Created Table
      rc = sqlgdref( %val(in_sqllen2),%ref(insert_data),
     +     %ref(in_sqldata2) )
      EXEC SQL EXECUTE insertstmt USING :insert_data
* :rk.4:erk.
      rc = sqlgdref( %val(in_sqllen3),%ref(insert_data),
     +     %ref(in_sqldata3) )
      EXEC SQL EXECUTE insertstmt USING :insert_data
      rc = sqlgdref( %val(in_sqllen4),%ref(insert_data),
     +     %ref(in_sqldata4) )
      EXEC SQL EXECUTE insertstmt USING :insert_data

      EXEC SQL COMMIT

*     Copy Local Variables into Dummy Output Variables
*     Copy sqlca to ca
      cntr = 0
      do 30 while ( cntr .lt. sqlca_size )
        cntr = cntr + 1
        ca(cntr) = sqlca(cntr)
30    end do

      goto 200

100   continue    ! An Error has Occurred
*     Copy Local Variables into Dummy Output Variables
*     Copy sqlca to ca
      cntr = 0
      do 40 while ( cntr .lt. sqlca_size )
        cntr = cntr + 1
        ca(cntr) = sqlca(cntr)
40    end do

      EXEC SQL ROLLBACK

200   continue                                 ! Exit Program
      inpsrv = sqlz_disconnect_proc
      return
* :rk.5:erk.
      end
