*******************************************************************************
**
** Source File Name = lobloc.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: This sample program demonstrates the use of LOB
**          locators.  The program creates a CURSOR, and fetches the
**          contents of the "emp_resume" table (the SAMPLE database
**          must be installed with the "db2sampl" executable), and
**          obtains the information specified to the "Department".
**          This  informations is then copied over to a buffer.
**          After the whole table has been scanned, the program
**          outputs the content of the buffer (information specific
**          to the "department" for all the resumes in the
**          "emp_resume" table.
**
** an external program is linked to, called "util.f".  To compile
** this sample program correctly, use the build scripts that are
** provided ("bldxlf"...) or the use the "makefile" provided
** ("make lobloc" on AIX,  "nmake lobloc" on OS/2 and DOS)
**
** MAKE:  To create an executable, complete the following:
**          1)  ensure the "sample" database is available
**          2)  ensure DBM is started
**          3)  enter "make lobloc"
**
*******************************************************************************

      program lobloc
      implicit none

      include 'sqlenv.f'
      include 'sql.f'
      EXEC SQL INCLUDE SQLCA

      EXEC SQL BEGIN DECLARE SECTION
* :rk.1:erk.
        character*8               userid
        character*18              passwd
        character*6               empnum
        integer*4                 di_begin_loc
        integer*4                 di_end_loc
        SQL TYPE IS CLOB_LOCATOR  resume
        SQL TYPE IS CLOB_LOCATOR  di_buffer
        integer*2                 lobind
        SQL TYPE IS CLOB(1K)      buffer
      EXEC SQL END DECLARE SECTION

      character*80     errloc

      print *, 'Sample Fortran Program: LOBLOC'

      print *, 'Enter in your user id :'
      read 109, userid
109   format (a8)

      print *, 'Enter in your password :'
      read 109, passwd

      EXEC SQL CONNECT TO sample USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

*     Employee A10030 is not included in the following select, because
*     the lobeval program manipulates the record for A10030 so that it is
*     not compatible with lobloc 

      EXEC SQL DECLARE c1 CURSOR FOR
     +         SELECT empno, resume FROM emp_resume
     +         WHERE resume_format = 'ascii'
     +         AND empno <> 'A00130'
      errloc = 'DECLARE CURSOR'
      call checkerr (sqlca, errloc, *999)

      EXEC SQL OPEN c1
      errloc = 'OPEN CURSOR'
      call checkerr (sqlca, errloc, *999)


   10 continue
         EXEC SQL FETCH c1 INTO :empnum, :resume :lobind
* :rk.2:erk.
         if (sqlcode .ne. 0) goto 100
         if (lobind .lt. 0) goto 50

*     The CLOB value exists.
*     Locate the beginning of the "Department Information" section
         EXEC SQL VALUES (POSSTR(:resume, 'Department Information'))
     +            INTO :di_begin_loc
         errloc = 'VALUES1'
         call checkerr (sqlca, errloc, *999)

*     Locate the beginning of the "Education" section (end of Dept.Info)
         EXEC SQL VALUES (POSSTR(:resume, 'Education'))
     +            INTO :di_end_loc
         errloc = 'VALUES2'
         call checkerr (sqlca, errloc, *999)

*     Obtain ONLY the "Department Information" section by using SUBSTR
         EXEC SQL VALUES(SUBSTR(:resume, :di_begin_loc,
     +            :di_end_loc - :di_begin_loc)) INTO :di_buffer
         errloc = 'VALUES3'
         call checkerr (sqlca, errloc, *999)

*     Append the "Department Information" section to the :buffer variable
         EXEC SQL VALUES(:buffer || :di_buffer) INTO :buffer
         errloc = 'VALUES4'
         call checkerr (sqlca, errloc, *999)

      goto 10

   50 print *,'NULL LOB indicated'
      goto 10

  100 print *, buffer

      EXEC SQL FREE LOCATOR :resume, :di_buffer
* :rk.3:erk.
      errloc = 'FREE LOCATOR'
      call checkerr (sqlca, errloc, *999)

      EXEC SQL CLOSE c1
      errloc = 'CLOSE CURSOR'
      call checkerr (sqlca, errloc, *999)

      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
