*******************************************************************************
**
** Source File Name = nodecat.f  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
**    PURPOSE :
**       an example showing how to use NODE CATALOG APIs in order to:
**          - create/catalog a node
**          - list a directory of nodes (showing what was created)
**          - uncatalog the node
**
**    APIs USED :
**       CATALOG NODE                           sqlgctnd()
**       OPEN NODE DIRECTORY SCAN               sqlgnops()
**       GET NEXT NODE DIRECTORY ENTRY          sqlgngne()
**       CLOSE NODE DIRECTORY SCAN              sqlgncls()
**       UNCATALOG NODE                         sqlguncn()
**
**    STRUCTURES USED :
**       sqle_node_struct
**       sqle_node_tcpip
**       sqlca
**
**    OTHER FUNCTIONS DECLARED :
**       'C' COMPILER LIBRARY :
**          stdio.h  -  printf
**
**       internal :
**          list_node :       Displays a directory of catalogued nodes
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************
      program nodecat
      implicit none

*--> sqlb0x17.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqlca_cn.f'

      integer*4 rc
*<--
      character*80     errloc

*-->
* Variables for the CATALOG/UNCATALOG NODE APIs
*     Node Structure (sqle_node_struct)
      character newNode(sqle_node_struct_struct_sz)
      integer*2         id
      integer*2         codepage
      integer*2         nname_len
      character*(sql_nname_sz+1)        nname
      character*(sql_cmt_sz+1)          comment
      character         protocol

      equivalence (id,
     +             newNode(sqle_node_struct_struct_id_ofs))
      equivalence (codepage,
     +             newNode(sqle_node_struct_codepage_ofs))
      equivalence (comment,
     +             newNode(sqle_node_struct_comment_ofs))
      equivalence (nname,
     +             newNode(sqle_node_struct_nodename_ofs))
      equivalence (protocol,
     +             newNode(sqle_node_struct_protocol_ofs))

*     TCP/IP Node Structure (sqle_node_tcpip)
      character protocolTCPIP(sqle_node_tcpip_struct_sz)
      character*(sql_hostname_sz+1)     hostname
      character*(sql_service_name_sz+1) service_name

      equivalence (hostname,
     +             protocolTCPIP(sqle_node_tcpip_hostname_ofs))
      equivalence (service_name,
     +             protocolTCPIP(sqle_node_tcpip_service_name_ofs))
*<--

* Initialize the Node structures
      nname     = 'newnode'
      nname_len = 7
      comment   = 'this is a test node'
      id        = sql_node_str_id
      protocol  = sql_protocol_tcpip

*     for TCP/IP connections, additional information on host and server
*     needs to be entered
      hostname =     'hostname'
      service_name = 'service_name'


* Main program body.
      print *, 'Sample Fortran Program: NODECAT.F'

      print *, 'cataloging the new node...'
*-->
********************
*     CATALOG NODE *
********************
      rc = sqlgctnd (%ref(sqlca),
     +               %ref(newNode),
     +               %ref(protocolTCPIP))
*<--
      errloc = 'CATALOG NODE'
      call checkerr (sqlca, errloc, *999)

      print *, 'Listing all nodes...'
      print *, '===================='
      call list_node (*999)

      print *, 'UNCATALOGing the database that was created'
*-->
**********************
*     UNCATALOG NODE *
**********************
      rc = sqlguncn (%val(nname_len),
     +               %ref(sqlca),
     +               %ref(nname))
*<--
      errloc = 'UNCATALOG NODE'
      call checkerr (sqlca, errloc, *999)

      print *, 'Listing all nodes [after uncatalogued node]'
      print *, '==============================================='
      call list_node (*999)

  999 stop
      end


*******************************************************************************
* SUBROUTINE : list_node
*
* PURPOSE : This subroutine displays the data contained in each node
*           directory entry, by retrieving the "sqleninfo" structure.
*
*******************************************************************************
      subroutine list_node (*)

*--> sqlb0x35.fortran
      include 'sqlca_cn.f'
      include 'sqlenv.f'
      include 'sqlutil.f'

      integer*4         rc
*<--
      character*80      errloc

*-->
* Variables declared for the OPEN/CLOSE node directory scan APIs
      integer*2         nHandle
      integer*2         nCount

* Variables declared for the Node Directory Entries APIs
      integer*4         buffer
*     Node directory entry structure (sqleninfo)
      character nodeBuffer(sqleninfo_struct_sz)
      character*(sql_nname_sz)          nodename
      character*(sql_loclu_sz)          local_lu
      character*(sql_rmtlu_sz)          partner_lu
      character*(sql_mode_sz)           mode
      character*(sql_cmt_sz)            comment
      integer*2         com_codepage
      integer*2         adapter
      character*(sql_netid_sz)          networkid
      character         protocol
      character*(sql_sym_dest_name_sz)  sym_dest_name
      integer*2         security_type
* The "hostname" field of the SQLENINFO structure is truncated to to 50
* characters for display purposes in this program.  The acutal length of
* this field is 255 or "sql_hostname_sz".
      character*50      hostname
      character*(sql_service_name_sz)   service_name

      equivalence (nodename, nodeBuffer(sqleninfo_nodename_ofs))
      equivalence (local_lu, nodebuffer(sqleninfo_local_lu_ofs))
      equivalence (partner_lu, nodebuffer(sqleninfo_partner_lu_ofs))
      equivalence (mode, nodebuffer(sqleninfo_mode_ofs))
      equivalence (comment, nodebuffer(sqleninfo_comment_ofs))
      equivalence (com_codepage, nodebuffer(sqleninfo_com_codepage_ofs))
      equivalence (adapter, nodebuffer(sqleninfo_adapter_ofs))
      equivalence (networkid, nodebuffer(sqleninfo_networkid_ofs))
      equivalence (protocol, nodebuffer(sqleninfo_protocol_ofs))
      equivalence (sym_dest_name,
     +             nodebuffer(sqleninfo_sym_dest_name_ofs))
      equivalence (security_type,
     +             nodebuffer(sqleninfo_security_type_ofs))
      equivalence (hostname, nodebuffer(sqleninfo_hostname_ofs))
      equivalence (service_name, nodebuffer(sqleninfo_service_name_ofs))


********************************
*     OPEN NODE DIRECTORY SCAN *
********************************
      rc = sqlgnops (%ref(nHandle),
     +               %ref(nCount),
     +               %ref(sqlca))
*<--
      errloc = 'OPEN NODE DIRECTORY SCAN'
      if (sqlcode .eq. sqle_rc_node_dir_empty) then
         print *, '--- Node directory is empty ---'
         return
      endif
      call checkerr (sqlca, errloc, *9999)

      idx = 0
      do 1500 while (idx .lt. nCount)
         idx = idx + 1
*-->
*************************************
*     GET NEXT NODE DIRECTORY ENTRY *
*************************************
      rc = sqlgngne (%val(nHandle),
     +               %ref(buffer),
     +               %ref(sqlca))
*<--
      errloc = 'GET NEXT NODE DIRECTORY ENTRY'
      call checkerr (sqlca, errloc, *9999)

*-->
***************************
*     DEREFERENCE ADDRESS *
***************************
      rc = sqlgdref (%val(sqleninfo_struct_sz),
     +               %ref(nodeBuffer),
     +               %ref(buffer))
*<--
      errloc = 'DEREFERENCE ADDRESS API'
      call checkerr (sqlca, errloc, *9999)

* Display the contents of the Node Directory Entry structure
      print *, 'node name             : ', nodename
      print *, 'node comment          : ', comment
      print *, 'node host name        : ', hostname
      print *, 'node service name     : ', service_name
      print *, 'node protocol         : ', protocol

      print *, ' '
1500  end do

*-->
*********************************
*     CLOSE NODE DIRECTORY SCAN *
*********************************
      rc = sqlgncls (%val(nHandle),
     +               %ref(sqlca))
*<--
      errloc = 'CLOSE NODE DIRECTORY SCAN'
      call checkerr (sqlca, errloc, *9999)

      return
 9999 return 1
      end
