*******************************************************************************
**
** Source File Name = outcli.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: This sample program demonstrates stored procedures.
**
**          There are two parts to this program:
**              - the outcli executable (placed on the client)
**              - the outsrv library (placed on the server)
**
**          The outcli routine will allocate and initialize a one
**          variable output SQLDA.  The outcli routine will then
**          call the sqlgproc API passing it the output SQLDA.
**
**          The outsrv routine will obtain the median salary of
**          employees in the "staff" table of the "sample" database.
**          This value will be placed in the output SQLDA and
**          returned to the outcli routine.  The outcli routine will
**          then print out the median salary.
**
** NOTE:  The SQLDA contains two values, sqldata and sqlind,
**        which contain addresses.  In order to handle this, two
**        API's sqlgaddr() and sqlgdref() are used.
**
*******************************************************************************

      program outcli
      implicit none

*     Copy Files for Constants and Structures
      include 'sql.f'
      include 'sqlenv.f'
* :rk.1:erk.
      include 'sqlutil.f'
      include 'sqldact.f'

      EXEC SQL INCLUDE SQLCA

      EXEC SQL BEGIN DECLARE SECTION
* :rk.3:erk.
        character*8    dbname
        character*8    userid
        character*18   passwd
        real*8         salary
        integer*2      sal_ind
        character*19   prog_name
      EXEC SQL END DECLARE SECTION

      integer*4        rc
      character*80     errloc

      integer*2        sqlvar1
      parameter        (sqlvar1 = sqlda_header_sz + 0*sqlvar_struct_sz)

      character        io_sqlda(sqlda_header_sz + 1*sqlvar_struct_sz)
* :rk.2:erk.
      character*8      io_sqldaid
      integer*4        io_sqldabc
      integer*2        io_sqln
      integer*2        io_sqld

      integer*2        io_sqltype1    ! First Variable
      integer*2        io_sqllen1
      integer*4        io_sqldata1
      integer*4        io_sqlind1
      integer*2        io_sqlnamelen1
      character*30     io_sqlnamedata1

      equivalence (io_sqlda(sqlda_sqldaid_ofs), io_sqldaid)
      equivalence (io_sqlda(sqlda_sqldabc_ofs), io_sqldabc)
      equivalence (io_sqlda(sqlda_sqln_ofs), io_sqln)
      equivalence (io_sqlda(sqlda_sqld_ofs), io_sqld)

      equivalence (io_sqlda(sqlvar1+sqlvar_type_ofs), io_sqltype1)
      equivalence (io_sqlda(sqlvar1+sqlvar_len_ofs), io_sqllen1)
      equivalence (io_sqlda(sqlvar1+sqlvar_data_ofs), io_sqldata1)
      equivalence (io_sqlda(sqlvar1+sqlvar_ind_ofs), io_sqlind1)
      equivalence (io_sqlda(sqlvar1+sqlvar_name_length_ofs),
     +             io_sqlnamelen1)
      equivalence (io_sqlda(sqlvar1+sqlvar_name_data_ofs),
     +             io_sqlnamedata1)

      io_sqldaid = 'O_SQLDA'
* :rk.4:erk.
      io_sqldabc = sqlda_header_sz + 1*sqlvar_struct_sz
      io_sqln    = 1
      io_sqld    = 1
      io_sqltype1 = sql_typ_nfloat
      io_sqllen1  = 8
      rc = sqlgaddr (%ref(salary), %ref(io_sqldata1))
      rc = sqlgaddr (%ref(sal_ind), %ref(io_sqlind1))


*     Program Logic

      print *, 'Enter in the remote database to attach to:'
      read 100, dbname
100   format (a8)      

      print *, 'Enter in your user id :'
      read 100, userid

      print *, 'Enter in your password :'
      read 100, passwd

      print *, 'CONNECT TO Remote Database.'
      EXEC SQL CONNECT TO :dbname USER :userid USING :passwd
* :rk.5:erk.
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

      prog_name = 'outsrv'

      print *, ' '
      print *, 'Use CALL with Host Variable to invoke the Server Procedu
     cre named outsrv.'
      EXEC SQL CALL :prog_name (:salary:sal_ind)
* :rk.6a:erk.
      errloc = 'CALL HV'
      call checkerr (sqlca, errloc, *999)
      print *, 'Server Procedure Complete.'

*     Print Salary Returned in OUTPUT SQLDA
      print *, 'Median Salary = ', salary

      print *, ' '
      print *, 'Use CALL with SQLDA to invoke the Server Procedure named
     c outsrv.'
      EXEC SQL CALL :prog_name USING DESCRIPTOR :io_sqlda
* :rk.6b:erk.
      errloc = 'CALL DA'
      call checkerr (sqlca, errloc, *999)
      print *, 'Server Procedure Complete.'

*     Print Salary Returned in OUTPUT SQLDA
      print *, 'Median Salary = ', salary

*     Disconnect from Remote Database.
      EXEC SQL CONNECT RESET
* :rk.7:erk.
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

999   stop
      end
