*******************************************************************************
**
** Source File Name = outsrv.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: This sample program demonstrates stored procedures.
**
**          There are two parts to this program:
**              - the outcli executable (placed on the client)
**              - the outsrv library (placed on the server)
**
**          The outcli routine will allocate and initialize a one
**          variable output SQLDA.  The outcli routine will then
**          call the sqlgproc API passing it the output SQLDA.
**
**          The sqlgproc API will call the outsrv routine stored
**          in the outsrv library.
**
**          The outsrv routine will obtain the median salary of
**          employees in the "staff" table of the "sample" database.
**          This value will be placed in the output SQLDA and
**          returned to the outcli routine.  The outcli routine will
**          then print out the median salary.
**
** NOTE:  The SQLDA contains two values, sqldata and sqlind,
**        which contain addresses.  In order to handle this, two
**        API's sqlgaddr() and sqlgdref() are used.
**
*******************************************************************************

      integer*4 function outsrv( reserved1,
* :rk.2:erk.
     +                           reserved2,
     +                           io_sqlda,
     +                           ca )
      implicit none

*     Include Files for Constants and Structures
      include 'sql.f'
* :rk.1:erk.
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sqldact.f'

*     Declare Input Parameters
      integer*4  reserved1
      integer*4  reserved2
      character  io_sqlda(sqlda_header_sz + 1*sqlvar_struct_sz)
      character  ca(sqlca_size)

*     Declare a Local SQLCA
      EXEC SQL INCLUDE SQLCA

*     Declare Host Variables
      EXEC SQL BEGIN DECLARE SECTION
        integer*4      num_records
        character*50   stmt
      EXEC SQL END DECLARE SECTION

*     Declare Miscellaneous Variables
      integer*2    cntr

*     Program Logic

      EXEC SQL WHENEVER SQLERROR GOTO 100

      EXEC SQL DECLARE c1 CURSOR FOR s1

*     Prepare a Statement to Obtain and Order all Salaries
      stmt = 'SELECT SALARY FROM STAFF ORDER BY SALARY'
      EXEC SQL PREPARE s1 FROM :stmt

*     Determine the Total Number of Records
      EXEC SQL SELECT COUNT(*) INTO :num_records FROM STAFF
* :rk.3:erk.

*     Fetch Salaries until the Median Salary is Obtained
      EXEC SQL OPEN c1
      cntr = 0
      do 10 while ( cntr .lt. (num_records/2 + 1) )
        cntr = cntr + 1
        EXEC SQL FETCH c1 USING DESCRIPTOR :io_sqlda
* :rk.4:erk.
10    end do
      EXEC SQL CLOSE c1

      EXEC SQL COMMIT

*     Copy Local Variables into Dummy Output Variables
*     Copy the sqlca to the ca
      cntr = 0
      do 20 while ( cntr .lt. sqlca_size )
        cntr = cntr + 1
        ca(cntr) = sqlca(cntr)
20    end do

      goto 200

100   continue                                ! An Error has Occurred
*     Copy Local Variables into Dummy Output Variables
*     Copy the sqlca to the ca
      cntr = 0
      do 30 while ( cntr .lt. sqlca_size )
        cntr = cntr + 1
        ca(cntr) = sqlca(cntr)
30    end do

      EXEC SQL ROLLBACK

200   continue                                 ! Exit Program
      outsrv = sqlz_disconnect_proc
      return
* :rk.5:erk.
      end

