*******************************************************************************
**
** Source File Name = tabscont.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use TABLESPACE CONTAINER APIs
**       in order to:
**          - obtain tablespace container information using lower level
**            service APIs (OPEN, FETCH, CLOSE)
**          - obtain tablespace container information using a higher level
**            APIs (TABLESPACE QUERY, SINGLE TABLESPACE QUERY)
**
**    APIs USED :
**        TABLESPACE CONTAINER QUERY             sqlgtcq
**        OPEN TABLESPACE CONTAINER QUERY        sqlgotcq
**        FETCH TABLESPACE CONTAINER QUERY       sqlgftcq
**        CLOSE TABLESPACE CONTAINER QUERY       sqlgctcq
**        SET TABLESPACE CONTAINERS              sqlgstsc
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**          tabspaceContInfo : Displays information on the tablespace
**                             container that is passed through.
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program tabscont
      implicit none

*--> sqlb0x22.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sql.f'
      EXEC SQL INCLUDE SQLCA

      integer*4         rc
      integer*4         idx
*<--
      character*80      errloc

      EXEC SQL BEGIN DECLARE SECTION
        character*8     dbname
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

*-->
* Variables for OPEN TABLESPACE CONTAINER QUERY API
      integer*4         tsc_id          /sqlb_all_tablespaces/
      integer*4         num_tsc

* Variables for FETCH TABLESPACE CONTAINER QUERY API
      character         data(sqlb_tbscq_d_struct_sz)

      integer*4         tsc_count
      integer*4         max_tsc
*<--

      print *, 'Sample Fortran Program: TABSCONT.SQF'

      print *, 'Enter in the database name :'
      read 101, dbname
101   format (a8)
      print *, 'Enter in your user id :'
      read 101, userid
      print *, 'Enter in your password :'
      read 101, passwd

      EXEC SQL CONNECT TO :dbname USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

      print *, 'Using the following APIs:'
      print *, '   OPEN TABLESPACE CONTAINER QUERY'
      print *, '   FETCH TABLESPACE CONTAINER QUERY'
      print *, '   CLOSE TABLESPACE CONTAINER QUERY'
      print *, '========================='

*-->
***************************************
*     OPEN TABLESPACE CONTAINER QUERY *
***************************************
      rc = sqlgotcq (%ref(sqlca),
     +               %val(tsc_id),
     +               %ref(num_tsc))
*<--
      errloc = 'OPEN TABLESPACE CONTAINER QUERY'
      call checkerr (sqlca, errloc, *999)

      print *, 'the number of tablespace containers ', num_tsc


      max_tsc =  1
      tsc_count = num_tsc
      idx = 0
      do 100 while (idx .lt. tsc_count)
*     The FETCH API is called for each tablespace cont. info. record reported
*     by the OPEN API, with the "max_tsc" set to 1.  This is done due to not
*     being able to allocate memory for the number of records, "num_tsc",
*     returned by the OPEN API.
*-->
****************************************
*     FETCH TABLESPACE CONTAINER QUERY *
****************************************
      rc = sqlgftcq (%ref(sqlca),
     +               %val(max_tsc),
     +               %ref(data),
     +               %ref(num_tsc))
*<--
      errloc = 'FETCH TABLESPACE CONTAINER QUERY'
      call checkerr (sqlca, errloc, *999)

      idx = idx + 1
      call tabscont_info (data)
  100 end do

*-->
****************************************
*     CLOSE TABLESPACE CONTAINER QUERY *
****************************************
      rc = sqlgctcq (%ref(sqlca))
*<--
      errloc = 'CLOSE TABLESPACE CONTAINER'
      call checkerr (sqlca, errloc, *999)

*-->
**********************************
*     TABLESPACE CONTAINER QUERY *
**********************************
      rc = sqlgtcq (%ref(sqlca),
     +              %val(tsc_id),
     +              %ref(num_tsc),
     +              %ref(data))
*<--
      errloc = 'TABLESPACE CONTAINER QUERY'
      call checkerr (sqlca, errloc, *999)


      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end


*******************************************************************************
* SUBROUTINE : tabscont_info
*
* PURPOSE : This subroutine displays the tablespace information
*
*******************************************************************************
      subroutine tabscont_info (data)
      include 'sqlenv.f'
      include 'sqlutil.f'
      character         data(sqlb_tbscq_d_struct_sz)


* Variables for the sqlb_tbscq_d_struct
      character         temp_data(sqlb_tbscq_d_struct_sz)
      integer*4         id
      integer*4         name_len
      character*(sqlb_tbscq_d_name_sz+1)  name
      integer*4         conttype

      character*10      ctype

      equivalence (temp_data(sqlb_tbscq_d_id_ofs), id)
      equivalence (temp_data(sqlb_tbscq_d_namelen_ofs), name_len)
      equivalence (temp_data(sqlb_tbscq_d_name_ofs), name)
      equivalence (temp_data(sqlb_tbscq_d_conttype_ofs), conttype)

      rc = sqlgmcpy (%ref(temp_data),
     +               %ref(data),
     +               %val(sqlb_tbscq_d_struct_sz))

      print *, 'Tablespace Container for Tablespace ', id
      print *, 'Container ID        = ', id
      print *, 'Name                = ', name(1:name_len)
      if (conttype .eq. sqlb_cont_path) ctype = 'path'
      if (conttype .eq. sqlb_cont_disk) ctype = 'disk'
      if (conttype .eq. sqlb_cont_file) ctype = 'file'
      print *, 'Type                = ', ctype

      print *, ' '

      return
      end
