*******************************************************************************
**
** Source File Name = tabspace.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE:
**       an example showing how to use TABLESPACE APIs
**       in order to:
**          - obtain tablespace information using lower level service
**            APIs (OPEN, FETCH, CLOSE)
**          - obtain tablespace information using a higher level
**            APIs (TABLESPACE QUERY, SINGLE TABLESPACE QUERY)
**          -
**
**    APIs USED :
**        TABLESPACE QUERY                       sqlgtsq
**        SINGLE TABLESPACE QUERY                sqlgstsq
**        OPEN TABLESPACE QUERY                  sqlgotsq
**        FETCH TABLESPACE QUERY                 sqlgftsq
**        GET TABLESPACE STATISTICS              sqlggtss
**        CLOSE TABLESPACE QUERY                 sqlgctsq
**        FREE MEMORY                            sqlgfmem
**
**    STRUCTURES USED :
**       sqlca
**
**    OTHER FUNCTIONS USED :
**       internal :
**          tabspaceInfo :    Displays information on the tablespace**
**                               container that is passed through.
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program tabspace
      implicit none

*--> sqlb0x23.fortran
      include 'sqlenv.f'
      include 'sqlutil.f'
      include 'sql.f'
      EXEC SQL INCLUDE SQLCA

      integer*4         rc
      integer*4         idx
*<--
      character*80      errloc

      EXEC SQL BEGIN DECLARE SECTION
        character*8     dbname
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

*-->
* Variables for OPEN TABLESPACE QUERY API
      integer*4         option  /sqlb_open_tbs_all/
      integer*4         num_ts
      integer*4         max_ts
      character         data(sqlb_tbsq_d_struct_sz)

      integer*4         ts_count

* Variables for GET TABLESPACE STATISTICS API
      integer*4         tbs_id
      character         tbs_stats(sqlb_tbs_stats_struct_sz)
*<--
      equivalence (tbs_id, data(sqlb_tbsq_d_id_ofs))

      print *, 'Sample Fortran Program: TABSPACE.SQF'

      print *, 'Enter in the database name :'
      read 101, dbname
101   format (a8)
      print *, 'Enter in your user id :'
      read 101, userid
      print *, 'Enter in your password :'
      read 101, passwd

      EXEC SQL CONNECT TO :dbname USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)

      print *, 'Using the following APIs:'
      print *, '   OPEN TABLESPACE QUERY'
      print *, '   FETCH TABLESPACE QUERY'
      print *, '   CLOSE TABLESPACE QUERY'
      print *, '========================='

*-->
*****************************
*     OPEN TABLESPACE QUERY *
*****************************
      rc = sqlgotsq (%ref(sqlca),
     +               %val(option),
     +               %ref(num_ts))
*<--
      errloc = 'OPEN TABLESPACE QUERY'
      call checkerr (sqlca, errloc, *999)

      max_ts =  1
      ts_count = num_ts
      idx = 0
      do 100 while (idx .lt. ts_count)
*     The FETCH API is called for each tablespace information record reported
*     by the OPEN API, with the "max_ts" set to 1.  This is done due to not
*     being able to allocate memory for the number of records, "num_ts",
*     returned by the OPEN API.
*-->
******************************
*     FETCH TABLESPACE QUERY *
******************************
      rc = sqlgftsq (%ref(sqlca),
     +               %val(max_ts),
     +               %ref(data),
     +               %ref(num_ts))
*<--
      errloc = 'FETCH TABLESPACE QUERY'
      call checkerr (sqlca, errloc, *999)



      print *, 'TBS Id ', tbs_id
*-->
*     The "tbs_id" can be obtained from the "id" field of the
*     "sqlb_tbs_stats_struct" structure
*********************************
*     GET TABLESPACE STATISTICS *
*********************************
      rc = sqlggtss (%ref(sqlca),
     +               %val(tbs_id),
     +               %ref(tbs_stats))
*<--
      errloc = 'GET TABLESPACE STATISTICS'
      call checkerr (sqlca, errloc, *999)


      idx = idx + 1
      call tabspace_info (data, tbs_stats)
  100 end do

*-->
******************************
*     CLOSE TABLESPACE QUERY *
******************************
      rc = sqlgctsq (%ref(sqlca))
*<--
      errloc = 'CLOSE TABLESPACE'
      call checkerr (sqlca, errloc, *999)

*-->
*******************************
*     SINGLE TABLESPACE QUERY *
*******************************
      rc = sqlgstsq (%ref(sqlca),
     +               %val(tbs_id),
     +               %ref(data))
*<--
      errloc = 'SINGLE TABLESPACE QUERY'
      call checkerr (sqlca, errloc, *999)

*-->
************************
*     TABLESPACE QUERY *
************************
      rc = sqlgtsq (%ref(sqlca),
     +              %ref(ts_count),
     +              %ref(data))
*<--
      errloc = 'TABLESPACE QUERY'
      call checkerr (sqlca, errloc, *999)


      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end


*******************************************************************************
* SUBROUTINE : tabspace_info
*
* PURPOSE : This subroutine displays the tablespace information
*
*******************************************************************************
      subroutine tabspace_info (data, tbs_stats)
      include 'sqlenv.f'
      include 'sqlutil.f'
      character         data(sqlb_tbsq_d_struct_sz)
      character         tbs_stats(sqlb_tbs_stats_struct_sz)


* Variables for the sqlb_tbsq_d_struct
      character         temp_data(sqlb_tbsq_d_struct_sz)
      integer*4         id
      integer*4         name_len
      character*(sqlb_tbsq_d_name_sz+1)  name
      character*40      tbstype
      character*40      tbscontent
      integer*4         tbsstate
      character*42      tbsstate_string
      integer*4         flags
      integer*4         temp_flags

      equivalence (temp_data(sqlb_tbsq_d_id_ofs), id)
      equivalence (temp_data(sqlb_tbsq_d_namelen_ofs), name_len)
      equivalence (temp_data(sqlb_tbsq_d_name_ofs), name)

      equivalence (temp_data(sqlb_tbsq_d_flags_ofs), flags)
*      equivalence (temp_data(sqlb_tbsq_d_flags_ofs+3), tbstype)
*      equivalence (temp_data(sqlb_tbsq_d_flags_ofs+4), tbscontent)

      equivalence (temp_data(sqlb_tbsq_d_tbsstate_ofs), tbsstate)

* Variables for the sqlb_tbs_stat_struct
      character         temp_tbs_stats(sqlb_tbs_stats_struct_sz)
      integer*4         totalpages
      integer*4         useablepages
      integer*4         usedpages
      integer*4         freepages
      integer*4         highwatermark

      equivalence (temp_tbs_stats(sqlb_tbs_stats_totalpages_ofs),
     +             totalpages)
      equivalence (temp_tbs_stats(sqlb_tbs_stats_useablepages_ofs),
     +             useablepages)
      equivalence (temp_tbs_stats(sqlb_tbs_stats_usedpages_ofs),
     +             usedpages)
      equivalence (temp_tbs_stats(sqlb_tbs_stats_freepages_ofs),
     +             freepages)
      equivalence (temp_tbs_stats(sqlb_tbs_stats_highwatermark_ofs),
     +             highwatermark)



      rc = sqlgmcpy (%ref(temp_data),
     +               %ref(data),
     +               %val(sqlb_tbsq_d_struct_sz))

      rc = sqlgmcpy (%ref(temp_tbs_stats),
     +               %ref(tbs_stats),
     +               %val(sqlb_tbs_stats_struct_sz))

      print *, 'Tablespace ID           = ', id
      print *, 'Tablespace Name         = ', name(1:name_len)

      temp_flags = flags / 16
      temp_flags = flags - (temp_flags * 16)
      tbstype = 'Unknown'
      if (temp_flags .eq. sqlb_tbs_sms)
     +   tbstype = 'System managed space'
      if (temp_flags .eq. sqlb_tbs_dms)
     +   tbstype = 'Database managed space'

      temp_flags = flags / 16
      temp_flags = temp_flags * 16
      tbscontent = 'Unknown'
      if (temp_flags .eq. sqlb_tbs_any)
     +   tbscontent = 'Regular contents'
      if (temp_flags .eq. sqlb_tbs_long)
     +   tbscontent = 'Long field data'
      if (temp_flags .eq. sqlb_tbs_tmp)
     +   tbscontent = 'Temp data'
      if ( tbsstate .eq. SQLB_NORMAL )
     +   tbsstate_string = 'Normal'
      if ( tbsstate .eq. SQLB_QUIESCED_SHARE )
     +   tbsstate_string = 'Quiesced: SHARE'
      if ( tbsstate .eq. SQLB_QUIESCED_UPDATE )
     +   tbsstate_string = 'Quiesced: UPDATE'
      if ( tbsstate .eq. SQLB_QUIESCED_EXCLUSIVE )
     +   tbsstate_string = 'Quiesced: EXCLUSIVE'
      if ( tbsstate .eq. SQLB_LOAD_PENDING )
     +   tbsstate_string = 'Load pending'
      if ( tbsstate .eq. SQLB_DELETE_PENDING )
     +   tbsstate_string = 'Delete pending'
      if ( tbsstate .eq. SQLB_BACKUP_PENDING )
     +   tbsstate_string = 'Backup pending'
      if ( tbsstate .eq. SQLB_ROLLFORWARD_IN_PROGRESS )
     +   tbsstate_string = 'Roll forward in progress'
      if ( tbsstate .eq. SQLB_ROLLFORWARD_PENDING )
     +   tbsstate_string = 'Roll forward pending'
      if ( tbsstate .eq. SQLB_RESTORE_PENDING )
     +   tbsstate_string = 'Restore pending'
      if ( tbsstate .eq. SQLB_DISABLE_PENDING )
     +   tbsstate_string = 'Disable pending'
      if ( tbsstate .eq. SQLB_REORG_IN_PROGRESS )
     +   tbsstate_string = 'Reorg in progress'
      if ( tbsstate .eq. SQLB_BACKUP_IN_PROGRESS )
     +   tbsstate_string = 'Backup in progress'
      if ( tbsstate .eq. SQLB_STORDEF_PENDING )
     +   tbsstate_string = 'storage must be defined'
      if ( tbsstate .eq. SQLB_RESTORE_IN_PROGRESS )
     +   tbsstate_string = 'Restore in progress'
      if ( tbsstate .eq. SQLB_STORDEF_ALLOWED )
     +   tbsstate_string = 'storage may be defined'
      if ( tbsstate .eq. SQLB_STORDEF_FINAL_VERSION )
     +   tbsstate_string = 'storDef is in *final* state'
      if ( tbsstate .eq. SQLB_STORDEF_CHANGED )
     +   tbsstate_string = 'storDef was changed prior to rollforward'
      if ( tbsstate .eq. SQLB_REBAL_IN_PROGRESS )
     +   tbsstate_string = 'dms rebalancer is active'
      if ( tbsstate .eq. SQLB_PSTAT_DELETION )
     +   tbsstate_string = 'TBS deletion in progress'
      if ( tbsstate .eq. SQLB_PSTAT_CREATION )
     +   tbsstate_string = 'TBS creation in progress'

*      tbscontent = flags .and. 'f0'x

      print *, 'Type                    = ', tbstype

      print *, 'Contents                = ', tbscontent

      print *, 'State                   = ', tbsstate_string

      print *, 'Tablespace Statistics'
      print *, 'total pages             = ', totalpages
      print *, 'useable pages           = ', useablepages
      print *, 'used pages              = ', usedpages
      print *, 'free pages              = ', freepages
      print *, 'high water mark         = ', highwatermark


      print *, ' '

      return
      end
