*******************************************************************************
**
** Source File Name = tload.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: to show the usage of LOAD and QUIESCE APIs
**      To show the use of the QUIESCE TABLESPACE and the LOAD APIs.
**        - EXPORT the EMP_RESUME table into a comma delimited file.
**        - create a temporary table ('loadtable').
**        - QUIESCE the TABLESPACES, preparing the temporary table to be 
**          LOADable.
**        - LOAD the comma delimited file into a temporary table ('loadtable').
**
**    APIs :
**       EXPORT                                 sqlgexpr
**       QUIESCE TABLESPACES FOR TABLE          sqlgvqdp
**       LOAD                                   sqlgload
**
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program tload
      implicit none

*--> sqlb0x30.fortran
      include 'sqlenv.f'
      include 'sql.f'
      include 'sqlutil.f'
      EXEC SQL INCLUDE SQLCA

      integer*4         rc
*<--
      character*80      errloc

      EXEC SQL BEGIN DECLARE SECTION
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

* Variables that are common among the APIs
      integer*4         reserved
      integer*2         msgfile_len
      integer*2         filetype_len
      character*(sql_path_sz+1)         msgfile
      character*(sql_fmt_length+1)      filetype
      character*(sql_path_sz+1)         datafile
      integer*2         callerac

*     FILETMOD is a self-defining string.
*     Replace STRLEN with application_specific bound, assign the FILETMOD
*     string to FILETMODE_STR and assign the length of the the FILETMOD
*      character         filetmod(2+strlen)
*      character*(strlen)        filetmod_str
      character         filetmod(2+12)
      character*12      filetmod_str
      integer*2         filetmod_len
      equivalence(filetmod_len, filetmod(sqlchar_length))
      equivalence(filetmod_str, filetmod(sqlchar_data))

*     TCOLSTRG is a self-defining string.
*     Assign a string containing an SQL statement to TCOLSTRG_STR and assign
*     the length of the statement to TCOLSTRG_LEN.
*     [note: SQL_MAX_STMT_SIZ is rather large, you may wish to replace it
*      with a smaller value]
      character                         tcolstrg(sql_max_stmt_siz+2)
      character*(sql_max_stmt_siz)      tcolstrg_str
      integer*2                         tcolstrg_len
      equivalence(tcolstrg_len, tcolstrg(sqlchar_length))
      equivalence(tcolstrg_str, tcolstrg(sqlchar_data))

      integer*2         col1
      integer*2         col2
      parameter(col1 = sqldcol_header_sz + 0*sqldcoln_struct_sz)
      parameter(col2 = sqldcol_header_sz + 1*sqldcoln_struct_sz)

*     Replace NUMCOLS with application specific bound
*      character         dcoldata(sqldcol_header_sz +
*     +                           NUMCOLS*sqldcoln_struct_sz)
      character         dcoldata(sqldcol_header_sz +
     +                           2*sqldcoln_struct_sz)
      integer*2         dcolmeth
      integer*2         dcolnum
      integer*2         dcolnlen1, dcolnlen2
      integer*4         dcolnptr1, dcolnptr2

      equivalence (dcolmeth, dcoldata(sqldcol_dcolmeth_ofs))
      equivalence (dcolnum, dcoldata(sqldcol_dcolnum_ofs))
      equivalence (dcolnlen1, dcoldata(col1 + sqldcoln_dcolnlen_ofs))
      equivalence (dcolnptr1, dcoldata(col1 + sqldcoln_dcolnptr_ofs))
      equivalence (dcolnlen2, dcoldata(col2 + sqldcoln_dcolnlen_ofs))
      equivalence (dcolnptr2, dcoldata(col2 + sqldcoln_dcolnptr_ofs))

      character         lobpaths(sqlu_media_list_struct_sz)
      character         lp_media_type
      integer*4         lp_sessions
      integer*4         lp_target
      equivalence (lobpaths(sqlu_media_list_media_type_ofs),
     +                                                    lp_media_type)
      equivalence (lobpaths(sqlu_media_list_sessions_ofs),  lp_sessions)
      equivalence (lobpaths(sqlu_media_list_target_ofs),      lp_target)


* Variables for EXPORT API
      integer*2         datafile_len

      character         lobfilenames(sqlu_media_list_struct_sz)
      character         lfn_media_type
      integer*4         lfn_sessions
      integer*4         lfn_target
      equivalence (lobfilenames(sqlu_media_list_media_type_ofs),
     +                                                   lfn_media_type)
      equivalence (lobfilenames(sqlu_media_list_sessions_ofs),
     +                                                     lfn_sessions)
      equivalence (lobfilenames(sqlu_media_list_target_ofs),
     +                                                       lfn_target)

      character         expt_out(sqluexpt_out_struct_sz)
      integer*4         sizeof_struct
      integer*4         rows_exported
      equivalence(expt_out(sqluexpt_out_sizeofstruct_ofs),
     +            sizeof_struct)
      equivalence(expt_out(sqluexpt_out_rowsexported_ofs),
     +            rows_exported)


* Variables for the QUIESCE TABLESPACES FOR TABLE API
      integer*2         tname_len
      character*(sqluh_tname_sz+1)      tname
      integer*2         quiesce_mode

* Varaibles for the LOAD API
      integer*2         rmtfile_len
      character         rmtfile
      character         copy_target(sqlu_media_list_struct_sz)
      integer*4         null_ind

      character         load_in(sqluload_in_struct_sz)
      integer*4         load_in_sizeofstruct
      integer*4         load_in_savecnt
      integer*4         load_in_restartcnt
      integer*4         load_in_rowcnt
      integer*4         load_in_warningcnt
      integer*4         load_in_data_buffer_size
      integer*4         load_in_sort_buffer_size
      integer*2         load_in_hold_quiesce
      character         load_in_restartphase
      character         load_in_statsopt
      equivalence (load_in(sqluload_in_sizeofstruct_ofs),
     +                  load_in_sizeofstruct)
      equivalence (load_in(sqluload_in_savecnt_ofs), load_in_savecnt)
      equivalence (load_in(sqluload_in_restartcnt_ofs),
     +                  load_in_restartcnt)
      equivalence (load_in(sqluload_in_rowcnt_ofs), load_in_rowcnt)
      equivalence (load_in(sqluload_in_warningcnt_ofs),
     +                  load_in_warningcnt)
      equivalence (load_in(sqluload_in_data_buffer_size_ofs),
     +                  load_in_data_buffer_size)
      equivalence (load_in(sqluload_in_sort_buffer_size_ofs),
     +                  load_in_sort_buffer_size)
      equivalence (load_in(sqluload_in_hold_quiesce_ofs),
     +                  load_in_hold_quiesce)
      equivalence (load_in(sqluload_in_restartphase_ofs),
     +                  load_in_restartphase)
      equivalence (load_in(sqluload_in_statsopt_ofs),
     +                  load_in_statsopt)

      character         load_out(sqluload_out_struct_sz)
      integer*4         load_out_sizeofstruct
      integer*4         load_out_rowsread
      integer*4         load_out_rowsskipped
      integer*4         load_out_rowsloaded
      integer*4         load_out_rowsrejected
      integer*4         load_out_rowsdeleted
      integer*4         load_out_rowscommitted
      equivalence (load_out(sqluload_out_sizeofstruct_ofs),
     +                  load_out_sizeofstruct)
      equivalence (load_out(sqluload_out_rowsread_ofs),
     +                  load_out_rowsread)
      equivalence (load_out(sqluload_out_rowsskipped_ofs),
     +                  load_out_rowsskipped)
      equivalence (load_out(sqluload_out_rowsloaded_ofs),
     +                  load_out_rowsloaded)
      equivalence (load_out(sqluload_out_rowsrejected_ofs),
     +                  load_out_rowsrejected)
      equivalence (load_out(sqluload_out_rowsdeleted_ofs),
     +                  load_out_rowsdeleted)
      equivalence (load_out(sqluload_out_rowscommitted_ofs),
     +                  load_out_rowscommitted)

      character         work_dir(sqlu_media_list_struct_sz)
      character         wd_media_type
      integer*4         wd_sessions
      integer*4         wd_target
      equivalence (work_dir(sqlu_media_list_media_type_ofs),
     +                  wd_media_type)
      equivalence (work_dir(sqlu_media_list_sessions_ofs),
     +                  wd_sessions)
      equivalence (work_dir(sqlu_media_list_target_ofs),
     +                  wd_target)

      character wd_location_entry (sqlu_location_entry_struct_sz)
      integer*4         wd_location_len
      character*(sqlu_locent_location_entry_sz)
     +                  wd_location_location_entry
      equivalence (wd_location_entry(sqlu_location_len_ofs),
     +                  wd_location_len)
      equivalence (wd_location_entry(sqlu_locent_location_entry_ofs),
     +                  wd_location_location_entry)


      character         datafile_list(sqlu_media_list_struct_sz)
      character         dfl_media_type
      integer*4         dfl_sessions
      integer*4         dfl_target
      equivalence (datafile_list(sqlu_media_list_media_type_ofs),
     +                  dfl_media_type)
      equivalence (datafile_list(sqlu_media_list_sessions_ofs),
     +                  dfl_sessions)
      equivalence (datafile_list(sqlu_media_list_target_ofs),
     +                  dfl_target)

      character dfl_media_entry (sqlu_media_entry_struct_sz)
      integer*4         dfl_media_len
      character*(sqlu_medent_media_entry_sz)
     +                  dfl_media_media_entry
      equivalence (dfl_media_entry(sqlu_medent_len_ofs),
     +                  dfl_media_len)
      equivalence (dfl_media_entry(sqlu_medent_media_entry_ofs),
     +                  dfl_media_media_entry)


* Main Program Body
      print *, 'Sample Fortran Program: TLOAD.SQF'

      print *, 'Enter in your user id :'
      read '(A8)', userid

      print *, 'Enter in your password :'
      read '(A18)', passwd

      EXEC SQL CONNECT TO sample USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)


* Initialize the EXPORT API variables
      sizeof_struct = sqluexpt_out_size
      filetmod_str = 'lobsinfile'
      filetmod_len = 10
      datafile = 'EXPTABLE.DEL'
      datafile_len = 12
      msgfile = 'EXPMSG.TXT'
      msgfile_len = 10
      filetype = 'DEL'
      filetype_len = 3
      tcolstrg_str='SELECT empno,photo_format,picture FROM emp_photo'
      tcolstrg_len = 48
      callerac = sqlu_initial
      dcolmeth = sql_meth_d


      print *, 'Exporting EMP_PHOTO table into file.'
**************
*     EXPORT *
**************
      rc = sqlgexpr (%val(datafile_len),
     +               %val(filetype_len),
     +               %val(msgfile_len),
     +               %ref(datafile),
*     +               %ref(lobpaths),
*     +               %ref(lobfilenames),
     +               %val(0),
     +               %val(0),
     +               %ref(dcoldata),
     +               %ref(tcolstrg),
     +               %ref(filetype),
     +               %ref(filetmod),
     +               %ref(msgfile),
     +               %val(callerac),
     +               %ref(expt_out),
     +               %ref(reserved),
     +               %ref(sqlca))
      errloc = 'EXPORT'
      call checkerr (sqlca, errloc, *999)

*     Drop the table before creating it, just incase it already exists
      EXEC SQL DROP TABLE loadtable
      EXEC SQL CREATE TABLE loadtable (num CHARACTER(6), format
     +         VARCHAR(10), photo BLOB(100K))
      errloc = 'CREATE TABLE'
      call checkerr (sqlca, errloc, *999)
      EXEC SQL COMMIT

*     initialize the QUIESCE TABLESPACE API variables
      tname = 'loadtable'
      tname_len = 9
      quiesce_mode = sqlu_quiescemode_exclusive

      print *, 'Quiescing tablespaces for table LOADTABLE'
*-->
*************************************
*     QUIESCE TABLESPACES FOR TABLE *
*************************************
      rc = sqlgvqdp (%val(tname_len),
     +               %ref(tname),
     +               %val(quiesce_mode),
     +               %ref(reserved),
     +               %ref(sqlca))
*<--
      errloc = 'QUIESCE TABLESPACES FOR TABLE'
      call checkerr (sqlca, errloc, *999)






*     Initialize the LOAD API variables
      msgfile_len=7
      rmtfile_len=8
      msgfile = 'LOADMSG'
      rmtfile = 'RLOADMSG'
      dfl_media_type = sqlu_server_location
      dfl_sessions = 1
      dfl_media_media_entry = datafile
      dfl_media_len = index(datafile, ' ') - 1
      rc = sqlgaddr (dfl_media_entry, dfl_target)

      callerac = sqlu_initial

      load_in_sizeofstruct = sqluload_in_size
      load_in_savecnt = 1
      load_in_restartcnt = 0
      load_in_rowcnt = 0
      load_in_warningcnt = 0
      load_in_data_buffer_size = 0
      load_in_sort_buffer_size = 0
      load_in_hold_quiesce = 0
      load_in_restartphase = ' '
      load_in_statsopt = sqlu_stats_none

      load_out_sizeofstruct = sqluload_out_size

      wd_media_type = sqlu_local_media
      wd_sessions = 1
      wd_location_location_entry = '.'
      wd_location_len = 1
      rc = sqlgaddr (wd_location_entry, wd_target)

      tcolstrg_str='INSERT INTO loadtable (num,format,photo)'
      tcolstrg_len=40



      print *, 'Loading the file into LOADTABLE'
*-->
************
*     LOAD *
************
      rc = sqlgload (%val(filetype_len),
     +               %val(msgfile_len),
     +               %val(rmtfile_len),
     +               %ref(datafile_list),
*     +               %ref(lobpaths),
     +               %val(0),
     +               %ref(dcoldata),
     +               %ref(tcolstrg),
     +               %ref(filetype),
     +               %ref(filetmod),
     +               %ref(msgfile),
     +               %ref(rmtfile),
     +               %val(callerac),
     +               %ref(load_in),
     +               %ref(load_out),
     +               %ref(work_dir),
*     +               %ref(copy_target),
     +               %val(0),
     +               %ref(null_ind),
     +               %ref(reserved),
     +               %ref(sqlca))
*<--
      errloc = 'LOAD'
      call checkerr (sqlca, errloc, *999)


      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end
