*******************************************************************************
**
** Source File Name = tspace.sqf  %I%
**
** Licensed Materials - Property of IBM
**
** (C) COPYRIGHT International Business Machines Corp. 1995
** All Rights Reserved.
**
** US Government Users Restricted Rights - Use, duplication or
** disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
**
**
** PURPOSE: To show the usage of COPY and FREE MEMORY APIs, which are to be
**          used with the TABLESPACE APIs.
**
** APIs USED:
**        COPY MEMORY                      sqlgmcpy
**        FREE MEMORY                      sqlgfmem
**        TABLESPACE QUERY                 sqlgtsq
**        TABLESPACE CONTAINER QUERY       sqlgtcq
**        SINGLE TABLESPACE QUERY          sqlgstsq
**        OPEN TABLESPACE QUERY            sqlgotsq
**        FETCH TABLESPACE QUERY           sqlgftsq
**        CLOSE TABLESPACE QUERY           sqlgctsq
**        OPEN TABLESPACE CONTAINER QUERY  sqlgotcq
**        FETCH TABLESPACE CONTAINER QUERY sqlgftcq
**        CLOSE TABLESPACE CONTAINER QUERY sqlgctcq
**        SET TABLESPACE QUERY             sqlgstsc
**        GET TABLESPACE STATISTICS        sqlggtss
**
**    OTHER FUNCTIONS USED :
**       internal :
**
**       external :
**          check_error :     Checks for SQLCODE error, and prints out any
**          [in UTIL.F]          related information available.
**                               This procedure is located in the UTIL.F file.
**
*******************************************************************************

      program tspace
      implicit none
*--> sqlb0x38.fortran
      include 'sqlenv.f'
      include 'sql.f'
      include 'sqlutil.f'
      EXEC SQL INCLUDE SQLCA
*<--

      EXEC SQL BEGIN DECLARE SECTION
        character*8     dbname
        character*8     userid
        character*18    passwd
      EXEC SQL END DECLARE SECTION

      character*80      errloc
*-->
      integer*4         rc
*<--
      integer*4 i

      integer*4 tbscontqry_pointer
      integer*4 tbscontqry_pointer_save
      integer*4 tblspace_id /2/
      integer*4 option /sqlb_set_cont_final_state/

      integer*4 container_count
      integer*4 tablespace_id /1/
      integer*4 max_tcq /1/
      integer*4 tcq_returned
      integer*4 tbsqry_returned
      integer*4 max_tbsqry /1/
      integer*4 tbsID /0/
*-->
      integer*4 tablespace_count
      integer*4 tbsqry_pointer
      integer*4 tbsqry_pointer_save

      character tbsq(sqlb_tbsq_d_struct_sz)
      integer*4                      id
      integer*4                      name_len
      character*(sqlb_max_tbs_name_sz) name
      integer*4                      total_pages
      integer*4                      useable_pages
      integer*4                      flags
      integer*4                      page_size
      integer*4                      ext_size
      integer*4                      prefetch_size
      integer*4                      number_containers
      integer*4                      tbs_state
      character*6                    life_LSN
      equivalence( tbsq(sqlb_tbsq_d_id_ofs),id )
      equivalence( tbsq(sqlb_tbsq_d_namelen_ofs),name_len )
      equivalence( tbsq(sqlb_tbsq_d_name_ofs),name )
      equivalence( tbsq(sqlb_tbsq_d_totalpages_ofs),total_pages )
      equivalence( tbsq(sqlb_tbsq_d_useablepages_ofs),useable_pages )
      equivalence( tbsq(sqlb_tbsq_d_flags_ofs),flags )
      equivalence( tbsq(sqlb_tbsq_d_pagesize_ofs),page_size )
      equivalence( tbsq(sqlb_tbsq_d_extsize_ofs),ext_size )
      equivalence( tbsq(sqlb_tbsq_d_prefetchsize_ofs),prefetch_size )
      equivalence( tbsq(sqlb_tbsq_d_ncontainers_ofs),
     +   number_containers )
      equivalence( tbsq(sqlb_tbsq_d_tbsstate_ofs),tbs_state )
      equivalence( tbsq(sqlb_tbsq_d_lifelsn_ofs),life_LSN )
*<--

      character tbscq(sqlb_tbscq_d_struct_sz)
      integer*4                      c_id
      integer*4                      n_tbs
      integer*4                      tbs_id
      integer*4                      c_name_len
      character*(sqlb_max_contain_name_sz) c_name
      integer*4                      cont_type
      integer*4                      c_total_pages
      integer*4                      c_useable_pages
      integer*4                      ok
      equivalence( tbscq(sqlb_tbscq_d_id_ofs),c_id )
      equivalence( tbscq(sqlb_tbscq_d_ntbs_ofs),n_tbs )
      equivalence( tbscq(sqlb_tbscq_d_tbsid_ofs),tbs_id )
      equivalence( tbscq(sqlb_tbscq_d_namelen_ofs),c_name_len )
      equivalence( tbscq(sqlb_tbscq_d_name_ofs),c_name )
      equivalence( tbscq(sqlb_tbscq_d_conttype_ofs),cont_type )
      equivalence( tbscq(sqlb_tbscq_d_totalpages_ofs),c_total_pages )
      equivalence( tbscq(sqlb_tbscq_d_useablepages_ofs),
     +   c_useable_pages )
      equivalence( tbscq(sqlb_tbscq_d_ok_ofs),ok )

      character tbss(sqlb_tbs_stats_struct_sz)
      integer*4                      s_total_pages
      integer*4                      s_useable_pages
      integer*4                      used_pages
      integer*4                      free_pages
      integer*4                      highwatermark
      equivalence( tbss(sqlb_tbs_stats_totalpages_ofs),s_total_pages )
      equivalence( tbss(sqlb_tbs_stats_useablepages_ofs),
     +   s_useable_pages )
      equivalence( tbss(sqlb_tbs_stats_usedpages_ofs),used_pages )
      equivalence( tbss(sqlb_tbs_stats_freepages_ofs),free_pages )
      equivalence( tbss(sqlb_tbs_stats_highwatermark_ofs),
     +                  highwatermark )




* Main Program Body
      print *, 'Sample Fortran Program: tspace.sqf'

      print *, 'Enter in the database name :'
      read 100, dbname
100   format (a8)      

      print *, 'Enter in your user id :'
      read 100, userid

      print *, 'Enter in your password :'
      read 100, passwd

      EXEC SQL CONNECT TO sample USER :userid USING :passwd
      errloc = 'CONNECT'
      call checkerr (sqlca, errloc, *999)


      print *, 'Testing sqlgtsq ..............................'
*-->
************************
*     TABLESPACE QUERY *
************************
      rc = sqlgtsq( %ref(sqlca),
     +              %ref(tablespace_count),
     +              %ref(tbsqry_pointer))
*<--
      print *,'tsq sqlcode:         ', sqlcode
      print *,'number of tablespaces:', tablespace_count

*-->
      tbsqry_pointer_save = tbsqry_pointer
*<--

      do 10 i=0,tablespace_count-1,1
*-->
*******************
*     COPY MEMORY *
*******************
        rc = sqlgmcpy(%ref(tbsq),
     +                %val(tbsqry_pointer),
     +                %val(sqlb_tbsq_d_struct_sz))
*<--

        print *,'id:                  ', id
        print *,'name:                ', name(1:name_len)
        print *,'total pages:         ', total_pages
        print *,'useable pages:       ', useable_pages
        print *,'flags:               ', flags
        print *,'page size:           ', page_size
        print *,'extent size:         ', ext_size
        print *,'prefetch size:       ', prefetch_size
        print *,'number of containers:', number_containers
        print *,'tablespace states:   ', tbs_state
        print *,'life LSN:            ', life_LSN
        print *,' '

        tbsqry_pointer = tbsqry_pointer + sqlb_tbsq_d_struct_sz
10    continue

*-->
*******************
*     FREE MEMORY *
*******************
      rc = sqlgfmem (%ref(sqlca),
     +               %val(tbsqry_pointer_save))
*<--
      print *,'fmem sqlcode:        ', sqlcode

      print *, 'Testing sqlgtcq ..............................'
      rc = sqlgtcq( %ref(sqlca),
     +              %val(tablespace_id),
     +              %ref(container_count),
     +              %ref(tbscontqry_pointer) )
      print *,'tcq sqlcode: ', sqlcode
      print *,'number of containers: ', container_count

      tbscontqry_pointer_save = tbscontqry_pointer

      do 20 i=0,container_count-1,1
        rc = sqlgmcpy(%ref(tbscq),%val(tbscontqry_pointer),
     +              %val(sqlb_tbscq_d_struct_sz) )

        print *,'id:            ', c_id
        print *,'# tablespaces: ', n_tbs
        print *,'tablespaces id:', tbs_id
        print *,'name: ', c_name(1:c_name_len)
        print *,'container type:', cont_type
        print *,'total pages:   ', c_total_pages
        print *,'useable pages: ', c_useable_pages
        print *,'ok?:           ', ok

        tbscontqry_pointer = tbscontqry_pointer + sqlb_tbsq_d_struct_sz
20    continue

      rc = sqlgfmem( %ref(sqlca), %val(tbscontqry_pointer_save) )
      print *,'fmem sqlcode: ', sqlcode

      print *, 'Testing sqlgstsq ..............................'
      rc = sqlgstsq( %ref(sqlca),
     +               %val(tbsID),
     +               %ref(tbsq) )
      print *,'stsq sqlcode:         ', sqlcode

      print *,'id:                  ', id
      print *,'name:                ', name(1:name_len)
      print *,'total pages:         ', total_pages
      print *,'useable pages:       ', useable_pages
      print *,'flags:               ', flags
      print *,'page size:           ', page_size
      print *,'extent size:         ', ext_size
      print *,'prefetch size:       ', prefetch_size
      print *,'number of containers:', number_containers
      print *,'tablespace states:   ', tbs_state
      print *,'life LSN:            ', life_LSN
      print *,' '

      print *, 'Testing sqlgotsq ..............................'
      rc = sqlgotsq( %ref(sqlca),
     +               %val(sqlb_open_tbs_all),
     +               %ref(tablespace_count) )
      print *,'otsq sqlcode:         ', sqlcode
      print *,'number of tablespaces:', tablespace_count

      do 30 i=0,tablespace_count-1,1

      rc = sqlgftsq( %ref(sqlca),
     +               %val(max_tbsqry),
     +               %ref(tbsq),
     +               %ref(tbsqry_returned) )
      print *,'ftsq sqlcode:        ', sqlcode
      print *,'tbsqry_returned:     ', tbsqry_returned

      print *,'id:                  ', id
      print *,'name:                ', name(1:name_len)
      print *,'total pages:         ', total_pages
      print *,'useable pages:       ', useable_pages
      print *,'flags:               ', flags
      print *,'page size:           ', page_size
      print *,'extent size:         ', ext_size
      print *,'prefetch size:       ', prefetch_size
      print *,'number of containers:', number_containers
      print *,'tablespace states:   ', tbs_state
      print *,'life LSN:            ', life_LSN
      print *,' '
30    continue

      rc = sqlgctsq( %ref(sqlca) )
      print *,'ctsq sqlcode:         ',sqlcode

      print *, 'Testing sqlgotcq ..............................'
      rc = sqlgotcq( %ref(sqlca),
     +               %val(tablespace_id),
     +               %ref(container_count) )
      print *,'otcq sqlcode:         ', sqlcode
      print *,'number of containers:', container_count

      do 40 i=0,container_count-1,1
      rc = sqlgftcq( %ref(sqlca),
     +               %val(max_tcq),
     +               %ref(tbscq),
     +               %ref(tcq_returned) )
      print *,'id:            ', c_id
      print *,'# tablespaces: ', n_tbs
      print *,'tablespaces id:', tbs_id
      print *,'name: ', c_name(1:c_name_len)
      print *,'container type:', cont_type
      print *,'total pages:   ', c_total_pages
      print *,'useable pages: ', c_useable_pages
      print *,'ok?:           ', ok
40    continue

      rc = sqlgctcq( %ref(sqlca) )
      print *,'ctcq sqlcode:         ',sqlcode

      print *, 'Testing sqlgstsc ..............................'
      rc = sqlgtcq( %ref(sqlca),
     +              %val(tblspace_id),
     +              %ref(container_count),
     +              %ref(tbscontqry_pointer) )
      print *,'tcq sqlcode: ', sqlcode
      print *,'number of containers: ', container_count

      tbscontqry_pointer_save = tbscontqry_pointer

      do 50 i=0,container_count-1,1
        rc = sqlgmcpy(%ref(tbscq),%val(tbscontqry_pointer),
     +              %val(sqlb_tbscq_d_struct_sz) )

        print *,'id:            ', c_id
        print *,'# tablespaces: ', n_tbs
        print *,'tablespaces id:', tbs_id
        print *,'name: ', c_name(1:c_name_len)
        print *,'container type:', cont_type
        print *,'total pages:   ', c_total_pages
        print *,'useable pages: ', c_useable_pages
        print *,'ok?:           ', ok

        tbscontqry_pointer = tbscontqry_pointer + sqlb_tbsq_d_struct_sz
50    continue

      rc = sqlgstsc( %ref(sqlca),
     +               %val(option),
     +               %val(tblspace_id),
     +               %val(container_count),
     +               %val(tbscontqry_pointer_save) )

      print *,'stsc sqlcode: ', sqlcode

      rc = sqlgfmem( %ref(sqlca), %val(tbscontqry_pointer_save) )
      print *,'fmem sqlcode: ', sqlcode

      print *, 'Testing sqlggtss ..............................'
      rc = sqlggtss( %ref(sqlca),
     +               %val(tblspace_id),
     +               %ref(tbss) )
      print *,'gtss sqlcode:        ', sqlcode

      print *,'total pages:         ', s_total_pages
      print *,'useable pages:       ', s_useable_pages
      print *,'used pages:          ', used_pages
      print *,'free pages:          ', free_pages
      print *,' '





      EXEC SQL CONNECT RESET
      errloc = 'CONNECT RESET'
      call checkerr (sqlca, errloc, *999)

  999 stop
      end











